<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Onland
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo( 'charset' ); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="https://gmpg.org/xfn/11">

	<?php
	if (is_page() || is_singular( 'post' ) || onland_custom_post_types() && get_post_meta( $post->ID, 'onland_common_meta', true ) ) {
		$common_meta = get_post_meta( $post->ID, 'onland_common_meta', true );
	} else {
		$common_meta = array();
	}

	if ( is_array( $common_meta ) && array_key_exists( 'header_meta', $common_meta ) && $common_meta['header_meta'] != 'default' ) {
		$selected_header = $common_meta['header_meta'];
	} else {
		$selected_header = onland_option( 'site_default_header', 'header-style-one' );
	}

	$preloader    = onland_option( 'enable_preloader', true );
	
	$toggle_sidebar = onland_option('enable_toggle_sidebar');
	$toggle_overlay = onland_option('enable_toggle_overlay', true);

	wp_head();
	?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site <?php echo esc_attr( $selected_header);?>">

    <!-- Preloader -->
	<?php if($preloader == true) {
		$preloader_image = onland_option('preloader_image'); ?>
        <div class="preloader-wrapper">
            <div class="preloader bounce-active">
                <?php if(!empty($preloader_image['url'])) : ?>
                    <img src="<?php echo esc_url($preloader_image['url']); ?>" alt="<?php echo esc_attr($preloader_image['alt']); ?>">
                <?php else : ?>
                    <img src="<?php echo get_theme_file_uri('assets/images/preloader.png');?>" alt="<?php bloginfo( 'name' ); ?>">
                <?php endif; ?>
            </div>
        </div>
		<?php
	}?>
    <!-- Preloader End -->

    <!-- Mobile Menu -->
    <div class="mobile-menu-container td-secondary-font">
        <div class="mobile-menu-close"></div>
        <div id="mobile-menu-wrap"></div>
    </div>
    <!-- Mobile Menu End -->

    <?php if($toggle_sidebar == true && is_active_sidebar('onland-toggle-sidebar')) : ?>
    <!-- Toggle Sidebar -->
    <?php if($toggle_overlay == true) : ?>
    <div class="toggle-full-bg"></div>
    <?php endif; ?>

    <div class="toggle-sidebar-wrapper td-secondary-bg">
        <div class="toggle-close td-primary-bg">x</div>
	    <div class="toggle-sidebar">
		    <?php dynamic_sidebar( "onland-toggle-sidebar" ) ?>
        </div>
    </div>
    <!-- Toggle Sidebar End -->
    <?php endif; ?>

    <header class="header-area site-header">
		<?php get_template_part( 'template-parts/header/' . $selected_header . '' ); ?>
    </header>

    <div id="content" class="site-content">
        