<?php
// Create header Settings section
CSF::createSection( $onland_theme_option, array(
	'title' => esc_html__( 'Header Settings', 'onland' ),
	'id'    => 'header_options',
	'icon'  => 'fa fa-header',
) );


CSF::createSection( $onland_theme_option, array(
	'parent' => 'header_options',
	'title'  => esc_html__( 'Default Header & Logo', 'onland' ),
	'icon'   => 'fa fa-credit-card',
	'fields' => array(
		array(
			'id'       => 'site_default_header',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Header Style', 'onland' ),
			'options'  => array(
				'header-style-one' => get_theme_file_uri( 'assets/images/header-one.png' ),
				'header-style-two' => get_theme_file_uri( 'assets/images/header-two.png' ),
				'header-style-three' => get_theme_file_uri( 'assets/images/header-three.png' ),
				'header-style-four' => get_theme_file_uri( 'assets/images/header-four.jpg' ),
			),
			'default'  => 'header-style-one',
			'subtitle' => esc_html__( 'Select site default header style. You can override this settings on individual page / Posts.', 'onland' ),
		),


		array(
			'id'       => 'sticky_header',
			'type'     => 'switcher',
			'title'    => esc_html__( 'Enable Sticky Header', 'onland' ),
			'default'  => true,
			'text_on'  => esc_html__( 'Yes', 'onland' ),
			'text_off' => esc_html__( 'No', 'onland' ),
			'desc'     => esc_html__( 'Enable / Disable sticky header.', 'onland' ),
		),

		array(
			'id'           => 'header_default_logo',
			'type'         => 'media',
			'title'        => esc_html__( 'Header Logo', 'onland' ),
			'library'      => 'image',
			'url'          => false,
			'button_title' => esc_html__( 'Upload Logo', 'onland' ),
			'desc'         => esc_html__( 'Upload logo image', 'onland' ),

		),

		array(
			'id'            => 'logo_image_size',
			'type'          => 'dimensions',
			'title'         => esc_html__( 'Logo Image Size', 'onland' ),
			'output'        => '.site-branding img',
			'width'         => true,
			'height'        => true,
			'desc'          => esc_html__( 'Select logo image size.', 'onland' ),
		),
	)
) );

CSF::createSection( $onland_theme_option, array(
	'parent' => 'header_options',
	'title'  => esc_html__( 'Header Top', 'onland' ),
	'icon'   => 'fas fa-level-up-alt',
	'fields' => array(

		array(
			'type'       => 'notice',
			'style'      => 'info',
			'content'    => esc_html__( 'Header top not available with selected header style', 'onland' ),
			'dependency' => array( 'site_default_header', 'any', 'header-style-one,header-style-four', 'all' ),
		),

		array(
			'id'         => 'enable_header_top',
			'type'       => 'switcher',
			'title'      => esc_html__( 'Enable Header Top', 'onland' ),
			'default'    => true,
			'text_on'    => esc_html__( 'Yes', 'onland' ),
			'text_off'   => esc_html__( 'No', 'onland' ),
			'desc'       => esc_html__( 'Enable / Disable header top info.', 'onland' ),
			'dependency' => array( 'site_default_header', 'any', 'header-style-two,header-style-three', 'all' ),
		),

		array(
			'id'           => 'header_top_info_text',
			'type'         => 'group',
			'title'        => esc_html__( 'Top Info Text', 'onland' ),
			'subtitle'     => esc_html__( 'Add / edit header top info text from here.', 'onland' ),
			'desc'         => esc_html__( 'Click "Add Info" button to add new Information.', 'onland' ),
			'button_title' => esc_html__( 'Add Info', 'onland' ),
			'fields'       => array(

				array(
					'id'            => 'info_text',
					'type'          => 'wp_editor',
					'media_buttons' => false,
					'height'        => '80px',
					'title'         => esc_html__( 'Info Text', 'onland' ),
					'desc'          => esc_html__( 'Type top left text here.', 'onland' ),
				),

				array(
					'id'    => 'info_icon',
					'type'  => 'icon',
					'title' => esc_html__( 'Icon', 'onland' ),
					'desc'  => esc_html__( 'Select icon', 'onland' ),
				),


			),
			'default'      => array(
				array(
					'info_text' => esc_html__( 'Obere Haltenstrasse Switzerland', 'onland' ),
					'info_icon' => 'flaticon-place',
				),
			),

			'dependency' => array(
				'site_default_header|enable_header_top',
				'any|==',
				'header-style-two,header-style-three|true',
				'all|all'
			),
		),

		array(
			'id'          => 'header_top_menu',
			'type'        => 'select',
			'title'       => esc_html__('Top Menu', 'onland'),
			'options'     => 'menus',
			'placeholder' => esc_html__('Select Menu', 'onland'),
			'desc'        => esc_html__('Select header top menu.', 'onland'),
			'dependency' => array(
				'site_default_header|enable_header_top',
				'any|==',
				'header-style-two,header-style-three|true',
				'all|all'
			),
		),
	)
) );


// Header Button

CSF::createSection( $onland_theme_option, array(
	'parent' => 'header_options',
	'title'  => esc_html__( 'Header CTA Button', 'onland' ),
	'icon'   => 'far fa-hand-pointer',
	'fields' => array(
		array(
			'id'         => 'header_cta_button',
			'type'       => 'switcher',
			'title'      => esc_html__( 'Enable CTA Button', 'onland' ),
			'default'    => false,
			'text_on'    => esc_html__( 'Yes', 'onland' ),
			'text_off'   => esc_html__( 'No', 'onland' ),
			'desc'       => esc_html__( 'Enable / Disable header CTA button.', 'onland' ),
		),

		array(
			'id'    => 'cta_text',
			'type'  => 'text',
			'title' => esc_html__( 'Button Text', 'onland' ),
			'default'  => esc_html__( 'Call Now', 'onland' ),
			'desc'  => esc_html__( 'CTA button text here.', 'onland' ),
			'dependency'   => array( 'header_cta_button', '==', 'true' ),
		),

		array(
			'id'    => 'cta_url',
			'type'  => 'text',
			'title' => esc_html__( 'URL', 'onland' ),
			'default'  => 'tel:123456789',
			'desc'  => esc_html__( 'CTA button URL here.', 'onland' ),
			'dependency'   => array( 'header_cta_button', '==', 'true' ),
		),

		array(
			'id'    => 'cta_icon',
			'type'  => 'icon',
			'title' => esc_html__( 'Icon', 'onland' ),
			'desc'  => esc_html__( 'Select button icon', 'onland' ),
			'default'  => 'flaticon-phone-call',
			'dependency'   => array( 'header_cta_button', '==', 'true' ),
		),

		array(
			'id'          => 'cta_btn_bg',
			'type'        => 'color',
			'title'       => esc_html__( 'Background Color', 'onland' ),
			'desc'        => esc_html__( 'Select header CTA background color.', 'onland' ),
			'output'   => array(
				'background-color' => '.header-buttons-area .td-button,.header-buttons-area .cart-product-count',
				'border-color' => '.header-buttons-area .td-button',
			),
			'dependency'   => array( 'header_cta_button', '==', 'true' ),
		),

		array(
			'id'          => 'cta_btn_text_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Text Color', 'onland' ),
			'desc'        => esc_html__( 'Select header CTA text color.', 'onland' ),
			'output'   => array(
				'color' => '.header-buttons-area .td-button,.header-buttons-area .cart-product-count',
			),
			'dependency'   => array( 'header_cta_button', '==', 'true' ),
		),

		array(
			'id'          => 'cta_btn_bg_on_hover',
			'type'        => 'color',
			'title'       => esc_html__( 'Hover Background Color', 'onland' ),
			'desc'        => esc_html__( 'Select header CTA background color on hover.', 'onland' ),
			'output'   => array(
				'background-color' => '.header-buttons-area .td-button:hover,.header-style-three .header-button .td-button:hover',
				'border-color' => '.header-buttons-area .td-button:hover,.header-style-three .header-button .td-button:hover',
			),
			'dependency'   => array( 'header_cta_button', '==', 'true' ),
		),

		array(
			'id'          => 'cta_btn_text_color_on_hover',
			'type'        => 'color',
			'title'       => esc_html__( 'Text Color On Hover', 'onland' ),
			'desc'        => esc_html__( 'Select header CTA text color on hover.', 'onland' ),
			'output'   => array(
				'color' => '.header-buttons-area .td-button:hover',
			),
			'dependency'   => array( 'header_cta_button', '==', 'true' ),
		),
	)
) );

// Header Color

CSF::createSection( $onland_theme_option, array(
	'parent' => 'header_options',
	'title'  => esc_html__( 'Header Colors', 'onland' ),
	'icon'   => 'fas fa-paint-brush',
	'fields' => array(

		array(
			'id'          => 'ht_bg_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Top Background Color', 'onland' ),
			'desc'        => esc_html__( 'Select header top background color.', 'onland' ),
			'output'      => '.header-top-area,.header-style-three .header-top-area',
			'output_mode' => 'background-color',
			'dependency' => array( 'site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three|true', 'all|all' ),
		),

		array(
			'id'          => 'ht_text_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Top Text Color', 'onland' ),
			'desc'        => esc_html__( 'Select header top text color.', 'onland' ),
			'output'      => '.header-top-area, .header-top-area a',
			'output_mode' => 'color',
			'dependency' => array( 'site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three|true', 'all|all' ),
		),

		array(
			'id'          => 'ht_icon_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Top Text Hover & Icon Color', 'onland' ),
			'desc'        => esc_html__( 'Select header top text hover & icon color.', 'onland' ),
			'output'   => array(
				'background-color' => '.header-top-area .cart-product-count',
				'color' => '.top-info li i,.header-top-area li a:hover',
			),
			'dependency' => array( 'site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three|true', 'all|all' ),
		),

		array(
			'id'          => 'header_bg_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Header Background Color', 'onland' ),
			'desc'        => esc_html__( 'Select header background.', 'onland' ),
			'output'   => array(
				'background-color' => '.main-menu-area,.header-style-three .main-menu-area,.header-style-four .main-menu-area.uk-sticky.uk-sticky-fixed',
			),
		),


		array(
			'id'          => 'header_left_shape_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Header Left Shape Color', 'onland' ),
			'desc'        => esc_html__( 'Select header left shape color.', 'onland' ),
			'output'   => array(
				'background-color' => '.header-style-three .header-area:before',
			),
			'dependency' => array( 'site_default_header', '==', 'header-style-three', 'all' ),
		),

		array(
			'id'          => 'header_right_shape_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Header Right Shape Color', 'onland' ),
			'desc'        => esc_html__( 'Select header right shape color.', 'onland' ),
			'output'   => array(
				'background-color' => '.header-style-three .header-area:after',
			),
			'dependency' => array( 'site_default_header', '==', 'header-style-three', 'all' ),
		),


		array(
			'id'          => 'header_text_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Header Menu Text Color', 'onland' ),
			'desc'        => esc_html__( 'Select header menu text color.', 'onland' ),
			'output'   => array(
				'color' => '.main-navigation ul li a,.header-style-two .header-buttons-area .header-toggle-icon,.header-toggle-icon',
				'background-color' => '.mobile-menu-trigger span',
			),
		),

		array(
			'id'          => 'header_active_menu_text_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Header Active Menu Text Color', 'onland' ),
			'desc'        => esc_html__( 'Select header active menu text color.', 'onland' ),
			'output'   => array(
				'color' => '.main-navigation ul li a:hover, .main-navigation ul li.current-menu-item > a, .main-navigation ul li.current_page_item > a, .main-navigation ul li.current-menu-ancestor > a, .main-navigation ul li.current_page_ancestor > a,.header-style-three .main-navigation ul li:hover > a,.header-style-three .main-navigation ul li.current-menu-item a, .header-style-three .main-navigation ul li.current-menu-ancestor > a',
			),
		),

		array(
			'id'          => 'header_active_menu_bg_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Header Active Menu Background Color', 'onland' ),
			'desc'        => esc_html__( 'Select header active menu background color.', 'onland' ),
			'output'   => array(
				'background-color' => '.main-navigation ul li a:before,.header-style-three .main-navigation ul li a:before',
			),
		),

		array(
			'id'          => 'dropdown_menu_bg_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Dropdown Menu Background Color', 'onland' ),
			'desc'        => esc_html__( 'Select dropdown menu background color.', 'onland' ),
			'output'   => array(
				'background-color' => '.main-navigation ul li ul',
			),
		),

		array(
			'id'          => 'dropdown_menu_text_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Dropdown Menu Text Color', 'onland' ),
			'desc'        => esc_html__( 'Select dropdown menu text color.', 'onland' ),
			'output'   => array(
				'color' => '.main-navigation ul li ul a',
			),
		),

		array(
			'id'          => 'dropdown_active_menu_bg_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Dropdown Active Menu Background Color', 'onland' ),
			'desc'        => esc_html__( 'Select dropdown active menu background color.', 'onland' ),
			'output'   => array(
				'background-color' => '.main-navigation ul ul li a:hover, .main-navigation ul ul li.current-menu-item > a, .main-navigation ul ul li.current_page_item > a, .main-navigation ul ul li.current-menu-ancestor > a, .main-navigation ul ul li.current_page_ancestor > a',
			),
		),

		array(
			'id'          => 'dropdown_active_menu_text_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Dropdown Active Menu Text Color', 'onland' ),
			'desc'        => esc_html__( 'Select dropdown active menu text color.', 'onland' ),
			'output'   => array(
				'color' => '.main-navigation ul ul li a:hover, .main-navigation ul ul li.current-menu-item > a, .main-navigation ul ul li.current_page_item > a, .main-navigation ul ul li.current-menu-ancestor > a, .main-navigation ul ul li.current_page_ancestor > a,.header-style-three .main-navigation ul ul li:hover > a, .header-style-three .main-navigation ul ul li.current-menu-item a, .header-style-three .main-navigation ul ul li.current-menu-ancestor > a',
			),
		),

		array(
			'id'          => 'dropdown_border_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Dropdown Border Color', 'onland' ),
			'desc'        => esc_html__( 'Select dropdown menu border color.', 'onland' ),
			'output'   => array(
				'border-color' => '.main-navigation ul li ul li',
			),
		),
	)
) );