<?php
namespace Elementor;

class ThemeDraft_Accordion_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_accordion';
	}

	public function get_title() {
		return esc_html__( 'Accordion', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-accordion';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'accordion_content_options',
			[
				'label' => esc_html__( 'Accordion', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'title',
			[
				'label'       => esc_html__( 'Accordion Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default' => 'Accordion Title Here',
				'placeholder' => esc_html__( 'Type Accordion Title Here', 'themedraft-core' ),
			]
		);

		$repeater->add_control(
			'content_text', [
				'label' => esc_html__( 'Accordion Content', 'themedraft-core' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => 'Accordion content here',
				'label_block' => true,
			]
		);

		$this->add_control(
			'accordion_list',
			[
				'label' => __( 'Accordion Lists', 'themedraft-core' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => 'Accordion Title Here',
						'content_text' => 'Accordion content here',
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->add_control(
			'open_by_default',
			[
				'label'       => esc_html__('Open By Default', 'themedraft-core'),
				'type'        => Controls_Manager::NUMBER,
				'min'         => 1,
				'max'         => 1000,
				'step'        => 1,
				'default'     => 1,
				'separator'     => 'before',
				'description' => esc_html__('Which accordion you want to open by default.', 'themedraft-core'),
			]
		);

		$this->add_control(
			'show_accordion_number',
			[
				'label'     => esc_html__( 'Show Number', 'themedraft-core' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
				'label_off' => esc_html__( 'No', 'themedraft-core' ),
				'default'   => 'yes',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'wrapper_options',
		    [
		        'label' => esc_html__( 'Wrapper', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		    ]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
			]
		);

		$this->add_control(
			'ac_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'accordion_style',
		    [
		        'label' => esc_html__( 'Accordion', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Title Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-accordion-wrapper .accordion-button,{{WRAPPER}} .td-accordion-wrapper .accordion-button:not(.collapsed)' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'text_color',
		    [
		        'label'       => esc_html__('Text Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .accordion-button:not(.collapsed),{{WRAPPER}} .td-accordion-wrapper .accordion-body' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'background_color',
		    [
		        'label'       => esc_html__('Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-accordion-wrapper .accordion-button:not(.collapsed),
		            {{WRAPPER}} .td-accordion-wrapper .accordion-button,{{WRAPPER}}  .td-accordion-wrapper .accordion-body' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'border_color',
		    [
		        'label'       => esc_html__('Border Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-accordion-wrapper .accordion-body' => 'border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'icon_bg',
		    [
		        'label'       => esc_html__('Icon Background', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-accordion-wrapper .accordion-button:after' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'icon_color',
			[
				'label'       => esc_html__('Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-accordion-wrapper .accordion-button:after' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_bg_on_expand',
			[
				'label'       => esc_html__('Expand Icon Background', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-accordion-wrapper .accordion-button:not(.collapsed):after' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_color_on_expand',
			[
				'label'       => esc_html__('Expand Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-accordion-wrapper .accordion-button:not(.collapsed):after' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'wrapper_style',
		    [
		        'label' => esc_html__( 'Wrapper', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_responsive_control(
		    'wrapper_margin',
		    [
		        'label'      => esc_html__( 'Wrapper Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-accordion-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$td_id = rand(10, 100000);
		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['ac_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>
		<div class="td-accordion-wrapper <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>

			<div class="accordion" id="td-accordion-<?php echo $td_id;?>">

				<?php
				if ( $settings['accordion_list'] ) {
					$i = 0;
					foreach ( $settings['accordion_list'] as $accordion ) {
						$i ++;

						if ( $i < 10 ) {
							$numb = '0' . $i;
						} else {
							$numb = $i;
						}

						if($i == $settings['open_by_default']){
							$collapsed = '';
							$show = 'show';
							$expand = 'true';
						}else{
							$collapsed = 'collapsed';
							$show = '';
							$expand = 'false';
						}
                ?>

                        <div class="accordion-item">

                            <button class="accordion-button <?php echo esc_attr($collapsed);?>" type="button" data-bs-toggle="collapse" data-bs-target="#collapse-<?php echo $td_id.$i;?>" aria-expanded="<?php echo esc_attr($expand);?>" aria-controls="collapse-<?php echo $td_id.$i;?>">
	                            <?php
	                            if($settings['show_accordion_number'] == 'yes'){
		                            echo $numb .'. ' .$accordion['title'];
	                            }else{
		                            echo $accordion['title'];
	                            }
	                            ?>
                            </button>


                            <div id="collapse-<?php echo $td_id.$i;?>" class="accordion-collapse collapse <?php echo esc_attr($show);?>" data-bs-parent="#td-accordion-<?php echo $td_id;?>">
                                <div class="accordion-body">
	                                <?php echo wp_kses_post( $accordion['content_text']) ?>
                                </div>
                            </div>
                        </div>
						<?php
					}
				}
				?>
			</div>
		</div>
		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Accordion_Widget );