<?php
namespace Elementor;

class ThemeDraft_Button_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_button_widget';
	}

	public function get_title() {
		return esc_html__( 'ThemeDraft Button', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-button';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'button_one_option',
			[
				'label' => esc_html__( 'Button One', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'btn_one_text',
		    [
		        'label'       => __( 'Text', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		        'default'     => 'Click Here'
		    ]
		);

		$this->add_control(
		    'btn_one_url',
		    [
		        'label'         => __( 'URL', 'themedraft-core' ),
		        'type'          => Controls_Manager::URL,
		        'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
		        'show_external' => true,
		        'default'       => [
		            'url'         => '#',
		            'is_external' => false,
		            'nofollow'    => false,
		        ],
		    ]
		);

		$this->add_control(
			'btn_one_icon_type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'none'  => [
						'title' => __( 'None', 'themedraft-core' ),
						'icon'  => 'eicon-ban',
					],

					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],

					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$this->add_control(
			'btn_one_selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-phone-call',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'btn_one_icon_type' => 'icon'
				]
			]
		);

		$this->add_control(
			'btn_one_image_icon',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'btn_one_icon_type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'button_one_style_options',
		    [
		        'label' => esc_html__( 'Button One', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'btn_one_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .themedraft-button.themedraft-button-one',
		    ]
		);

        $this->start_controls_tabs('td_btn_one_style_tabs');

        //Default style tab start
        $this->start_controls_tab(
            'td_btn_one_style_default',
            [
                'label' => esc_html__('Normal', 'themedraft-core'),
            ]
        );

        $this->add_control(
            'btn_one_default_bg',
            [
                'label'     => esc_html__('Background Color', 'themedraft-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themedraft-button.themedraft-button-one' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'btn_one_default_text_color',
            [
                'label'     => esc_html__('Text Color', 'themedraft-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themedraft-button.themedraft-button-one' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .themedraft-button.themedraft-button-one svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();//Default style tab end

        //Hover style tab start
        $this->start_controls_tab(
            'td_btn_one_style_hover',
            [
                'label' => esc_html__('Hover', 'themedraft-core'),
            ]
        );

        $this->add_control(
            'btn_one_hover_bg',
            [
                'label'     => esc_html__('Background Color', 'themedraft-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themedraft-button.themedraft-button-one:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'btn_one_hover_text_color',
            [
                'label'     => esc_html__('Text Color', 'themedraft-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
	                '{{WRAPPER}} a.themedraft-button.themedraft-button-one:hover' => 'color: {{VALUE}};',
	                '{{WRAPPER}} a.themedraft-button.themedraft-button-one:hover svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			'btn_one_hover_border_color',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-one:hover' => 'border-color: {{VALUE}}',
				],
			]
		);

        $this->end_controls_tabs();//Hover style tab end

		$this->add_responsive_control(
		    'btn_one_padding',
		    [
		        'label'      => esc_html__( 'Padding', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .themedraft-button.themedraft-button-one' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
                'separator' => 'before',
		    ]
		);

		$this->add_responsive_control(
			'btn_one_margin',
			[
				'label'      => esc_html__( 'Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-one' => 'Margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'btn_one_border',
				'label' => __( 'Border', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .themedraft-button.themedraft-button-one',
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'btn_one_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-one' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'btn_one_icon_size',
			[
				'label' => esc_html__( 'Icon Size ( px )', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 20,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-one svg,{{WRAPPER}} .themedraft-button.themedraft-button-one img' => 'width: {{SIZE}}px;height: {{SIZE}}px;',
					'{{WRAPPER}} .themedraft-button.themedraft-button-one i' => 'font-size: {{SIZE}}px;',
				],
                'condition' => [
                    'btn_one_icon_type!' => 'none',
                ],

                'separator' => 'before',
			]
		);

		$this->add_responsive_control(
		    'btn_one_icon_margin',
		    [
		        'label'      => esc_html__( 'Icon Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .themedraft-button.themedraft-button-one svg,{{WRAPPER}} .themedraft-button.themedraft-button-one img,{{WRAPPER}} .themedraft-button.themedraft-button-one i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		        'condition' => [
			        'btn_one_icon_type!' => 'none',
		        ],
		    ]
		);

		$this->end_controls_section();


		// Button two

		$this->start_controls_section(
			'button_two_option',
			[
				'label' => esc_html__( 'Button Two', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'btn_two_text',
			[
				'label'       => __( 'Text', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'btn_two_url',
			[
				'label'         => __( 'URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->add_control(
			'btn_two_icon_type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'none'  => [
						'title' => __( 'None', 'themedraft-core' ),
						'icon'  => 'eicon-ban',
					],

					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],

					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$this->add_control(
			'btn_two_selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-phone-call',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'btn_two_icon_type' => 'icon'
				]
			]
		);

		$this->add_control(
			'btn_two_image_icon',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'btn_two_icon_type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'button_two_style_options',
			[
				'label' => esc_html__( 'Button Two', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'btn_two_text!' => '',
                ],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btn_two_typo',
				'label' => esc_html__( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .themedraft-button.themedraft-button-two',
			]
		);

		$this->start_controls_tabs('td_btn_two_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
			'td_btn_two_style_default',
			[
				'label' => esc_html__('Normal', 'themedraft-core'),
			]
		);

		$this->add_control(
			'btn_two_default_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-two' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'btn_two_default_text_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.themedraft-button.themedraft-button-two' => 'color: {{VALUE}};',
					'{{WRAPPER}} a.themedraft-button.themedraft-button-two svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
			'td_btn_two_style_hover',
			[
				'label' => esc_html__('Hover', 'themedraft-core'),
			]
		);

		$this->add_control(
			'btn_two_hover_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-two:hover' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'btn_two_hover_text_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.themedraft-button.themedraft-button-two:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} a.themedraft-button.themedraft-button-two:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'btn_two_hover_border_color',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-two:hover' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->add_responsive_control(
			'btn_two_padding',
			[
				'label'      => esc_html__( 'Padding', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'btn_two_margin',
			[
				'label'      => esc_html__( 'Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-two' => 'Margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'btn_two_border',
				'label' => __( 'Border', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .themedraft-button.themedraft-button-two',
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'btn_two_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-two' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'btn_two_icon_size',
			[
				'label' => esc_html__( 'Icon Size ( px )', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 20,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-two svg,{{WRAPPER}} .themedraft-button.themedraft-button-two img' => 'width: {{SIZE}}px;height: {{SIZE}}px;',
					'{{WRAPPER}} .themedraft-button.themedraft-button-two i' => 'font-size: {{SIZE}}px;',
				],
				'condition' => [
					'btn_two_icon_type!' => 'none',
				],

				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'btn_two_icon_margin',
			[
				'label'      => esc_html__( 'Icon Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .themedraft-button.themedraft-button-two svg,{{WRAPPER}} .themedraft-button.themedraft-button-two img,{{WRAPPER}} .themedraft-button.themedraft-button-two i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'btn_one_icon_type!' => 'none',
				],
			]
		);

		$this->end_controls_section();

		// Wrapper
		$this->start_controls_section(
		    'wrapper_options',
		    [
		        'label' => esc_html__( 'Wrapper', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		    ]
		);

		$this->add_responsive_control(
		    'text_align',
		    [
		        'label'       => esc_html__('Alignment', 'themedraft-core'),
		        'type'        => Controls_Manager::CHOOSE,
		        'label_block' => false,

		        'options' => [
		            'left' => [
		                'title' => __('Left', 'themedraft-core'),
		                'icon'  => 'fa fa-align-left',
		            ],

		            'center' => [
		                'title' => __('Center', 'themedraft-core'),
		                'icon'  => 'fa fa-align-center',
		            ],

		            'right' => [
		                'title' => __('Right', 'themedraft-core'),
		                'icon'  => 'fa fa-align-right',
		            ],
		        ],

		        'devices' => ['desktop', 'tablet', 'mobile'],

		        'selectors' => [
		            '{{WRAPPER}} .themedraft-button-wrapper' => 'text-align: {{VALUE}};',
		        ],

		    ]
		);

		$this->add_responsive_control(
		    'wrapper_margin',
		    [
		        'label'      => esc_html__( 'Wrapper Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .themedraft-button-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$this->add_control(
			'btn_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();

		$btn_one_text = $settings['btn_one_text'];
		$btn_one_url   = $settings['btn_one_url']['url'];
		$btn_one_target   = $settings['btn_one_url']['is_external'] ? ' target="_blank"' : '';
		$btn_one_nofollow = $settings['btn_one_url']['nofollow'] ? ' rel="nofollow"' : '';

		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['btn_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}

		?>

		<div class="themedraft-button-wrapper <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>
            <a href="<?php echo esc_url($btn_one_url);?>" class="themedraft-button themedraft-button-one" <?php echo $btn_one_target . $btn_one_nofollow?>><?php echo esc_html($btn_one_text);?>
                <?php if ( $settings['btn_one_icon_type'] === 'image' ) :
                    if ( $settings['btn_one_image_icon']['url'] || $settings['btn_one_image_icon']['id'] ) :
                        ?>
                        <img src="<?php echo $settings['btn_one_image_icon']['url']; ?>" alt="<?php echo get_post_meta( $settings['btn_one_image_icon']['id'], '_wp_attachment_image_alt', true ); ?>">
                    <?php endif;
                elseif ( ! empty( $settings['icon'] ) || ! empty( $settings['btn_one_selected_icon'] ) ) : ?>
                    <?php themedraft_custom_icon_render( $settings, 'icon', 'btn_one_selected_icon' ); ?>
                <?php endif; ?>
            </a>

            <?php if($settings['btn_two_text']) :
                $btn_two_text = $settings['btn_two_text'];
                $btn_two_url   = $settings['btn_two_url']['url'];
                $btn_two_target   = $settings['btn_two_url']['is_external'] ? ' target="_blank"' : '';
                $btn_two_nofollow = $settings['btn_two_url']['nofollow'] ? ' rel="nofollow"' : '';
            ?>
                <a href="<?php echo esc_url($btn_two_url);?>" class="themedraft-button themedraft-button-two" <?php echo $btn_two_target . $btn_two_nofollow?>><?php echo esc_html($btn_two_text);?>
                    <?php if ( $settings['btn_two_icon_type'] === 'image' ) :
                        if ( $settings['btn_two_image_icon']['url'] || $settings['btn_two_image_icon']['id'] ) :
                            ?>
                            <img src="<?php echo $settings['btn_two_image_icon']['url']; ?>" alt="<?php echo get_post_meta( $settings['btn_two_image_icon']['id'], '_wp_attachment_image_alt', true ); ?>">
                        <?php endif;
                    elseif ( ! empty( $settings['icon'] ) || ! empty( $settings['btn_two_selected_icon'] ) ) : ?>
                        <?php themedraft_custom_icon_render( $settings, 'icon', 'btn_two_selected_icon' ); ?>
                    <?php endif; ?>
                </a>
            <?php endif; ?>
		</div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Button_Widget );