<?php
namespace Elementor;

class ThemeDraft_Button_With_Image_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_buttton_with_image';
	}

	public function get_title() {
		return esc_html__( 'Button With Image', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-button';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'button_with_image_option',
			[
				'label' => esc_html__( 'Image Button', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'button_image',
		    [
		        'label'       => __( 'Image', 'themedraft-core' ),
		        'type'        => Controls_Manager::MEDIA,
		        'label_block' => true,
		        'default'     => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		    ]
		);

		$this->add_control(
		    'btn_text',
		    [
		        'label'       => __( 'Button Text', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		        'default'     => 'Call Now',
		    ]
		);

		$this->add_control(
		    'btn_url',
		    [
		        'label'         => __( 'Button Url', 'themedraft-core' ),
		        'type'          => Controls_Manager::URL,
		        'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
		        'show_external' => true,
		        'default'       => [
		            'url'         => '',
		            'is_external' => false,
		            'nofollow'    => false,
		        ],
		    ]
		);

		$this->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$this->add_control(
			'selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-phone-call',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$this->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$this->add_control(
			'btn_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'button_style_option',
		    [
		        'label' => esc_html__( 'Button Style', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'button_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-button',
		    ]
		);

		$this->add_responsive_control(
		    'icon_size',
		    [
		        'label' => esc_html__( 'Icon Size ( px )', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['px'],
		        'range' => [
		            'px' => [
		                'min' => 20,
		                'max' => 100,
		            ],
		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],
		        'selectors' => [
		            '{{WRAPPER}} .td-button.td-call-button svg,{{WRAPPER}} .td-button.td-call-button img' => 'width: {{SIZE}}px;height: {{SIZE}}px;',
		            '{{WRAPPER}} .td-button.td-call-button i' => 'font-size: {{SIZE}}px;',
		        ],
		    ]
		);

		$this->add_responsive_control(
			'btn_position_from_bottom',
			[
				'label' => esc_html__( 'Position From Bottom', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => -800,
						'max' => 800,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .td-image-button' => 'bottom: {{SIZE}}px',
				],
			]
		);

		$this->add_responsive_control(
		    'button_padding',
		    [
		        'label'      => esc_html__( 'Padding', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->start_controls_tabs('td_button_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
		    'td_btn_style_default',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_default_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_default_text_color',
		    [
		        'label'     => esc_html__('Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button' => 'color: {{VALUE}};',
		            '{{WRAPPER}} .td-button svg' => 'fill: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_btn_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_hover_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button:hover' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_hover_text_color',
		    [
		        'label'     => esc_html__('Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button:hover' => 'color: {{VALUE}};',
		            '{{WRAPPER}} .td-button:hover svg' => 'fill: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();

		$this->start_controls_section(
		    'content_style',
		    [
		        'label' => esc_html__( 'Content', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_responsive_control(
		    'image_align',
		    [
		        'label'       => esc_html__('Image Align', 'themedraft-core'),
		        'type'        => Controls_Manager::CHOOSE,
		        'label_block' => false,
		        'options' => [
		            'left' => [
		                'title' => __('Left', 'themedraft-core'),
		                'icon'  => 'fa fa-align-left',
		            ],

		            'center' => [
		                'title' => __('Center', 'themedraft-core'),
		                'icon'  => 'fa fa-align-center',
		            ],

		            'right' => [
		                'title' => __('Right', 'themedraft-core'),
		                'icon'  => 'fa fa-align-right',
		            ],
		        ],

		        'devices' => ['desktop', 'tablet', 'mobile'],

		        'selectors' => [
		            '{{WRAPPER}} .td-button-with-image-wrapper' => 'text-align: {{VALUE}};',
		        ],

		    ]
		);

		$this->add_responsive_control(
		    'wrapper_margin',
		    [
		        'label'      => esc_html__( 'Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-button-with-image-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$image_src = $settings['button_image']['url'];
		$image_alt = get_post_meta( $settings['button_image']['id'], '_wp_attachment_image_alt', true );
		$image_title = get_the_title( $settings['button_image']['id']);
		$btn_text = $settings['btn_text'];

		$url   = $settings['btn_url']['url'];
		$target   = $settings['btn_url']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['btn_url']['nofollow'] ? ' rel="nofollow"' : '';

		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['btn_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>

		<div class="td-button-with-image-wrapper <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>
			<div class="td-button-with-image">
				<img src="<?php echo esc_url($image_src);?>" alt="<?php echo esc_attr($image_alt);?>" title="<?php echo esc_attr($image_title);?>">
				<div class="td-image-button">
					<a href="<?php echo esc_url($url);?>" class="td-button td-call-button" <?php echo $target . $nofollow?>><?php echo esc_html($btn_text);?>

                        <?php if ( $settings['type'] === 'image' ) :
                            if ( $settings['image']['url'] || $settings['image']['id'] ) :
                                ?>
                                <img src="<?php echo $settings['image']['url']; ?>" alt="<?php echo get_post_meta( $settings['image']['id'], '_wp_attachment_image_alt', true ); ?>">
                            <?php endif;
                        elseif ( ! empty( $settings['icon'] ) || ! empty( $settings['selected_icon'] ) ) : ?>
                            <?php themedraft_custom_icon_render( $settings, 'icon', 'selected_icon' ); ?>
                        <?php endif; ?>
                    </a>
				</div>
			</div>
		</div>
		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Button_With_Image_Widget );