<?php

namespace Elementor;
class ThemeDraft_CountUp_Widget extends Widget_Base {

	public function get_name() {

		return "themedraft_count_up";
	}

	public function get_title() {
		return "Count Up";
	}

	public function get_icon() {

		return "eicon-counter";
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}

	public function get_script_depends() {
		return ['counterup'];
	}

	protected function register_controls() {
		//Start Control Section
		$this->start_controls_section(
			'count_up_options',
			[
				'label' => __( 'Count Up Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'counter_image',
		    [
		        'label'       => __( 'Image', 'themedraft-core' ),
		        'type'        => Controls_Manager::MEDIA,
		        'label_block' => true,
		        'default'     => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		    ]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'count_number',
			[
				'label'   => __( 'Count Number', 'themedraft-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => '100',
			]
		);

		$repeater->add_control(
			'count_unit',
			[
				'label'   => 'Counter Unit',
				'type'    => Controls_Manager::TEXT,
				'default' => '+',
			]
		);

		$repeater->add_control(
			'count_title',
			[
				'label'       => __( 'Count Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Counter Title',
				'label_block' => true,
			]
		);

		$this->add_control(
			'count_boxes',
			[
				'label'       => __('Count Box List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'count_title'        => 'Counter Title',
						'count_unit' => '+',
						'count_number' => '100',
					],
				],
				'title_field' => '{{{ count_title }}}',
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label'        => esc_html__( 'Entrance Animation', 'themedraft-core' ),
				'type'         => Controls_Manager::ANIMATION,
			]
		);

		$this->add_control(
			'wrapper_animation_duration',
			[
				'label'     => esc_html__( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();//End Control Section


        $this->start_controls_section(
            'counter_style_option',
            [
                'label' => esc_html__( 'Counter', 'themedraft-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'box_sixe',
            [
                'label' => esc_html__( 'Box Size', 'themedraft-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 300,
                        'max' => 1000,
                    ],
                ],

                'selectors' => [
                    '{{WRAPPER}} .td-counter-with-image' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'counter_bg',
            [
                'label'       => esc_html__('Counter Background Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-counter-with-image .td-counter-box' => 'background-color: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			'counter_border',
			[
				'label'       => esc_html__('Counter Border Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-counter-with-image .td-counter-box' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'number_color',
		    [
		        'label'       => esc_html__('Number Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-primary-color' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'title_color',
			[
				'label'       => esc_html__('Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-counter-with-image .td-count-title' => 'color: {{VALUE}};',
				],
			]
		);

        $this->end_controls_section();

	}

	//Render In HTML
	protected function render() {
		$settings = $this->get_settings_for_display();
		$count_id = rand(100, 100000);
		$img_src = $settings['counter_image']['url'];
		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['wrapper_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>

        <div class="td-counter-box-wrapper td-counter-box-<?php echo esc_attr($count_id);?> <?php echo esc_attr( $td_animation ); ?>" <?php echo esc_attr( $td_animation_duration ); ?>>
            <div class="row">
                <div class="td-counter-with-image-wrapper text-center">
                    <div class="td-counter-with-image td-cover-bg" style="background-image: url(<?php echo esc_url($img_src);?>)">

	                    <?php if ( $settings['count_boxes'] ) {
	                        $i = 0;
		                    foreach ( $settings['count_boxes'] as $count_box ) {
			                    $i++;
			                    ?>

                                <div class="td-counter-box td-counter-box-<?php echo $i;?>">
                                    <div class="td-table">
                                        <div class="td-table-cell">
                                            <div class="td-count-number-unit td-secondary-font td-primary-color">
                                                <span class="td-count-number"><?php echo esc_html( $count_box['count_number'] ) ?></span>
                                                <sup class="td-count-unit"><?php echo esc_html( $count_box['count_unit'] ) ?></sup>
                                            </div>
                                            <span class="td-count-title"><?php echo esc_html( $count_box['count_title'] ) ?></span>
                                        </div>
                                    </div>
                                </div>
			                    <?php

		                    }
	                    } ?>
                    </div>
                </div>
            </div>
        </div>
        <script>
            (function ($) {
                "use strict";
                /*====  Document Ready Function =====*/
                jQuery(document).ready(function($){
                    $(".td-counter-box-<?php echo esc_attr($count_id);?> .td-count-number").counterUp({
                        delay: 10,
                        time: 2000
                    });
                });
            }(jQuery));
        </script>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_CountUp_Widget );