<?php
namespace Elementor;

class ThemeDraft_CTA_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_cta';
	}

	public function get_title() {
		return esc_html__( 'CTA Widget', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-button';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'cta_title_options',
			[
				'label' => esc_html__( 'Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'title',
		    [
		        'label'       => __( 'Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => 'We Have Solutions For Your Garden.',
		        'label_block' => true,
		    ]
		);

		$this->add_control(
			'title_entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
			]
		);

		$this->add_control(
			'title_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'title_entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'cta_button_options',
			[
				'label' => esc_html__( 'Button', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'btn_text',
			[
				'label'       => __( 'Button Text', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Contact Now',
			]
		);

		$this->add_control(
			'btn_url',
			[
				'label'         => __( 'Button URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$this->add_control(
			'selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-farmer',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$this->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$this->add_control(
			'btn_entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
			]
		);

		$this->add_control(
			'btn_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'btn_entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'title_style',
		    [
		        'label' => esc_html__( 'Title', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-cta-text',
		    ]
		);

		$this->add_control(
		    'cta_color',
		    [
		        'label'       => esc_html__('Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-cta-text' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		// Start Button section
		$this->start_controls_section(
		    'td_button_style_options',
		    [
		        'label' => esc_html__('Button', 'themedraft-core'),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->start_controls_tabs('td_button_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
		    'td_btn_style_default',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_default_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-cta-button' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_default_text_color',
		    [
		        'label'     => esc_html__('Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-cta-button' => 'color: {{VALUE}};',
		            '{{WRAPPER}} .td-cta-button svg' => 'fill: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_btn_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_hover_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-cta-button:hover' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_hover_text_color',
		    [
		        'label'     => esc_html__('Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-cta-button:hover' => 'color: {{VALUE}};',
		            '{{WRAPPER}} .td-cta-button:hover svg' => 'fill: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();// End Button section

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$title = $settings['title'];

		$btn_text = $settings['btn_text'];
		$btn_url = $settings['btn_url']['url'];
		$target   = $settings['btn_url']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['btn_url']['nofollow'] ? ' rel="nofollow"' : '';

		if($settings['title_entrance_animation']){
			$title_animation = 'wow'.' ' . $settings['title_entrance_animation'];
			$title_animation_duration = $settings['title_animation_duration'];
		}else{
			$title_animation ='';
			$title_animation_duration ='';
		}

		if($settings['btn_entrance_animation']){
			$btn_animation = 'wow'.' ' . $settings['btn_entrance_animation'];
			$btn_animation_duration = $settings['btn_animation_duration'];
		}else{
			$btn_animation ='';
			$btn_animation_duration ='';
		}
		?>
		<div class="cta-section-wrapper td-cover-bg">
            <div class="row">
                <div class="col-xl-6 col-lg-8 <?php echo $title_animation;?>" <?php echo $title_animation_duration;?>>
                    <h3 class="td-cta-text"><?php echo nl2br($title);?></h3>
                </div>

                <div class="col-xl-4 offset-xl-2 col-lg-4 my-auto text-center <?php echo $btn_animation;?>" <?php echo $btn_animation_duration;?>>
                    <a href="<?php echo esc_url($btn_url);?>" class="td-cta-button"><?php echo esc_html($btn_text);?>

                        <?php if ( $settings['type'] === 'image' ) :
                            if ( $settings['image']['url'] || $settings['image']['id'] ) :
                                ?>

                                <img src="<?php echo $settings['image']['url']; ?>" alt="<?php echo get_post_meta( $settings['image']['id'], '_wp_attachment_image_alt', true ); ?>">

                            <?php endif;
                        elseif ( ! empty( $settings['icon'] ) || ! empty( $settings['selected_icon'] ) ) :

                            themedraft_custom_icon_render( $settings, 'icon', 'selected_icon' );
                        endif; ?>

                    </a>
                </div>
            </div>

		</div>
		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_CTA_Widget );