<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once( 'controls/icons.php' );
require_once( 'controls/elementor-section-image/elementor-section-images.php' );

class ThemeDraft_Elementor_Scripts {

	public function __construct() {
		add_action( 'elementor/frontend/after_register_scripts', array( $this, 'themedraft_core_register_scripts' ) );
		add_action( 'elementor/editor/after_enqueue_styles', array( $this, 'themedraft_core_editor_scripts' ) );
	}

	public function themedraft_core_editor_scripts() {
		wp_register_script( 'isotope', plugins_url( '/', __FILE__ ) . 'assets/js/isotope.min.js', array(
			'jquery',
			'imagesloaded'
		), '1.0', true );
	}

	public function themedraft_core_register_scripts() {
		if ( function_exists( 'onland_option' ) ) {
			$td_map_api_key = onland_option( 'google_map_api_key' );
			if ( $td_map_api_key ) {
				wp_register_script( 'google-maps-script', 'https://maps.googleapis.com/maps/api/js?key=' . $td_map_api_key . '', array(), '1.0', false );
				wp_register_script( 'google-map-js', plugins_url( '/', __FILE__ ) . 'assets/js/gmap.js', array( 'jquery' ), '1.0', true );
			}
		}

		wp_register_script( 'counterup', plugins_url( '/', __FILE__ ) . 'assets/js/counterup.min.js', array( 'jquery' ), '1.0', true );
		wp_register_script( 'appear', plugins_url( '/', __FILE__ ) . 'assets/js/appear.js', array( 'jquery' ), '1.0', true );
		wp_register_script( 'isotope', plugins_url( '/', __FILE__ ) . 'assets/js/isotope.min.js', array(
			'jquery',
			'imagesloaded'
		), '1.0', true );
	}
}

new ThemeDraft_Elementor_Scripts();


class ThemeDraft_Elementor_Custom_Widget {

	private static $instance = null;

	public static function get_instance() {
		if ( ! self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	public function themedraft_add_elementor_custom_widgets() {
		require_once( 'accordion-widget.php' );
		require_once( 'brand-slider-widget.php' );
		require_once( 'button-widget.php' );
		require_once( 'button-with-image-widget.php' );
		require_once( 'contact-form7-widget.php' );
		require_once( 'counter-up-widget.php' );
		require_once( 'cta-widget.php' );
		require_once( 'google-map-widget.php' );
		require_once( 'home-slider-one-widget.php' );
		require_once( 'home-slider-two-widget.php' );
		require_once( 'home-slider-three-widget.php' );
		require_once( 'image-widget.php' );
		require_once( 'list-widget.php' );
		require_once( 'popup-video-widget.php' );
		require_once( 'pricing-table-widget.php' );
		require_once( 'project-details-slider-widget.php' );
		require_once( 'project-gallery-widget.php' );
		require_once( 'project-slider-widget.php' );
		require_once( 'promo-box-widget.php' );
		require_once( 'recent-post-widget.php' );
		require_once( 'section-title-widget.php' );
		require_once( 'service-box-one-widget.php' );
		require_once( 'service-box-three-widget.php' );
		require_once( 'service-box-two-widget.php' );
		require_once( 'service-gallery-slider-widget.php' );
		require_once( 'skill-progress-bar-widget.php' );
		require_once( 'tabs-one-widget.php' );
		require_once( 'tabs-two-widget.php' );
		require_once( 'tabs-three-widget.php' );
		require_once( 'team-details-widget.php' );
		require_once( 'team-one-widget.php' );
		require_once( 'testimonial-one-widget.php' );
		require_once( 'testimonial-two-widget.php' );
		require_once( 'title-with-border-text-widget.php' );
	}

	public function init() {
		add_action( 'elementor/widgets/register', array( $this, 'themedraft_add_elementor_custom_widgets' ) );
	}
}

ThemeDraft_Elementor_Custom_Widget::get_instance()->init();

// Add New Category In Elementor Widget

function themedraft_elementor_widget_categories( $elements_manager ) {

	$elements_manager->add_category(
		'themedraft_elements',
		[
			'title' => __( 'ThemeDraft Elements', 'themedraft-core' ),
		]
	);

}

add_action( 'elementor/elements/categories_registered', 'themedraft_elementor_widget_categories' );