<?php

namespace Elementor;

if (!defined('ABSPATH')) exit; // If this file is called directly, abort.

class ThemeDraft_Google_Map extends Widget_Base {
	public function get_name() {
		return 'themedraft-map';
	}

	public function is_reload_preview_required() {
		return true;
	}

	public function get_title() {
		return esc_html__('Google Map', 'themedraft-core');
	}

	public function get_icon() {
		return 'eicon-google-maps';
	}

	public function get_categories() {
		return ['themedraft_elements'];
	}

	public function get_script_depends() {
		return ['google-map-js', 'google-maps-script'];
	}


	protected function register_controls() {

		$this->start_controls_section('map_marker_section_accordion',
			[
				'label' => esc_html__('Map Markers', 'themedraft-core'),
			]
		);

		if(function_exists('onland_option')){
			$map_api_key = onland_option('google_map_api_key');

			if(empty($map_api_key)){
				$this->add_control('td_maps_api_url',
					[
						'label'         => '<span style="line-height: 22px;">Map Required an API key.To generate your own API key follow <a target="_blank" href="https://developers.google.com/maps/documentation/javascript/get-api-key">this</a> and after generate add it to Dashboard -> Onland Options -> General -> Google Map Api Key</span>',
						'type'          => Controls_Manager::RAW_HTML,
						'separator' => 'after'
					]
				);
			}
        }

		$repeater = new Repeater();


		$repeater->add_control(
			'map_latitude', [
				'label' => esc_html__( 'Latitude', 'themedraft-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => 55.8674395,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'map_longitude', [
				'label' => esc_html__( 'Longitude', 'themedraft-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => -4.2499492,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'marker_title', [
				'label' => esc_html__( 'Title', 'themedraft-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Onland UK',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'marker_dsc', [
				'label' => esc_html__( 'Marker Description', 'themedraft-core' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => 'Marker Description Here.',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'marker_icon', [
				'label' => esc_html__( 'Marker Icon', 'themedraft-core' ),
				'type' => Controls_Manager::MEDIA,
				'label_block' => true,
			]
		);

		$this->add_control(
			'marker_list',
			[
				'label' => esc_html__( 'Marker List', 'themedraft-core' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'map_latitude' => 55.8674395,
						'map_longitude' => -4.2499492,
						'marker_title' => 'Onland UK',
						'marker_dsc' => 'Marker Description Here.',
					],
				],
				'title_field' => '{{{ marker_title }}} : {{{map_latitude}}}, {{{map_longitude}}}',
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
		    'map_center_option',
		    [
		        'label' => esc_html__( 'Map Center', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		    ]
		);

		$this->add_control('td_center_text',
			[
				'label'         => '<span style="line-height: 22px;">By default first marker position is set as map center. But you can change that from here.</span>',
				'type'          => Controls_Manager::RAW_HTML,
				'separator' => 'after'
			]
		);

		$this->add_control(
		    'map_center_lat',
		    [
		        'label'       => esc_html__( 'Center Latitude', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		    ]
		);

		$this->add_control(
			'map_center_long',
			[
				'label'       => esc_html__( 'Center Longitude', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
			]
		);

		$this->end_controls_section();




		$this->start_controls_section('map_control_section_accordion',
			[
				'label' => esc_html__('Map Controls', 'themedraft-core'),
			]
		);

		$this->add_responsive_control(
			'map_height',
			[
				'label' => esc_html__( 'Map Height (px)', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 200,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .td-gmap' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control('map_type',
			[
				'label'   => esc_html__('Map Type', 'themedraft-core'),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'roadmap'   => esc_html__('Road Map', 'themedraft-core'),
					'satellite' => esc_html__('Satellite', 'themedraft-core'),
					'hybrid'    => esc_html__('Hybrid', 'themedraft-core'),
					'terrain'   => esc_html__('Terrain', 'themedraft-core'),
				],
				'default' => 'roadmap',
			]
		);


		$this->add_control('map_zoom',
			[
				'label'   => esc_html__('Map Zoom', 'themedraft-core'),
				'type'    => Controls_Manager::SLIDER,
				'default' => [
					'size' => 9,
				],
				'range'   => [
					'px' => [
						'min' => 0,
						'max' => 23,
					],
				],
			]
		);

		$this->add_control('enable_map_type_control',
			[
				'label' => esc_html__('Enable Map Type Controls?', 'themedraft-core'),
				'type'  => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);

		$this->add_control('enable_zoom_controls',
			[
				'label' => esc_html__('Enable Zoom Controls?', 'themedraft-core'),
				'type'  => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control('enable_street_control',
			[
				'label' => esc_html__('Enable Street Control?', 'themedraft-core'),
				'type'  => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);


		$this->add_control('enable_fullscreen_control',
			[
				'label' => esc_html__('Enable Fullscreen Control?', 'themedraft-core'),
				'type'  => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control('zoom_on_scroll',
			[
				'label' => esc_html__('Zoom On Scroll?', 'themedraft-core'),
				'type'  => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);

		$this->add_control('info_window_always_open',
			[
				'label' => esc_html__('Info Window Always Open?', 'themedraft-core'),
				'type'  => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);

		$this->add_control('info_window_hover_open',
			[
				'label' => esc_html__('Info Window Open On Hover?', 'themedraft-core'),
				'type'  => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);

		$this->add_control('info_window_hide_mouseout',
			[
				'label'     => esc_html__('Info Window Hide When Mouse Out?', 'themedraft-core'),
				'type'      => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'condition' => [
					'info_window_hover_open' => 'yes'
				]
			]
		);

		$this->end_controls_section();



		$this->start_controls_section('map_custom_style_accordion',
			[
				'label' => esc_html__('Map Style', 'themedraft-core'),
			]
		);

		$this->add_control('map_custom_style',
			[
				'label'       => __('JSON Code', 'themedraft-core'),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => 'Get your custom styling from <a href="https://snazzymaps.com/" target="_blank">here</a>',
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'map_contact_details',
		    [
		        'label' => esc_html__( 'Contact Details', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		    ]
		);

		$this->add_control(
		    'enable_contact_details',
		    [
		        'label'     => esc_html__( 'Enable Contact Details', 'themedraft-core' ),
		        'type'      => Controls_Manager::SWITCHER,
		        'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
		        'label_off' => esc_html__( 'No', 'themedraft-core' ),
		        'default'   => 'yes',
		    ]
		);

		$repeater = new Repeater();

		$repeater->add_control(
		    'title',
		    [
		        'label'       => __( 'Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXT,
		        'default'     => 'Phone:',
		        'label_block' => true,
		    ]
		);

		$repeater->add_control(
		    'details_text',
		    [
		        'label'       => __( 'Details', 'themedraft-core' ),
		        'type'        => Controls_Manager::WYSIWYG,
		        'default'     => '<ul>
                                        <li><a href="tel:1234567890">+410 123 456 789</a></li>
                                        <li><a href="tel:1234567890">+410 987 654 321</a></li>
                                    </ul>',
		        'label_block' => true,
		    ]
		);

		$repeater->add_control(
		    'type',
		    [
		        'label'       => esc_html__( 'Icon Type', 'themedraft-core' ),
		        'type'        => Controls_Manager::CHOOSE,
		        'label_block' => false,
		        'options'     => [
		            'icon'  => [
		                'title' => esc_html__( 'Icon', 'themedraft-core' ),
		                'icon'  => 'fa fa-smile-o',
		            ],
		            'image' => [
		                'title' => esc_html__( 'Image', 'themedraft-core' ),
		                'icon'  => 'fa fa-image',
		            ],
		        ],
		        'default'     => 'icon',
		        'toggle'      => false,
		    ]
		);

		$repeater->add_control(
		    'selected_icon',
		    [
		        'label'            => esc_html__( 'Select Icon', 'themedraft-core' ),
		        'type'             => Controls_Manager::ICONS,
		        'fa4compatibility' => 'icon',
		        'label_block'      => true,
		        'default'          => [
		            'value'   => 'flaticon-phone-call',
		            'library' => 'themedraft-garden-icon',
		        ],
		        'condition'        => [
		            'type' => 'icon'
		        ]
		    ]
		);

		$repeater->add_control(
		    'image',
		    [
		        'label'     => esc_html__( 'Image', 'themedraft-core' ),
		        'type'      => Controls_Manager::MEDIA,
		        'default'   => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		        'condition' => [
		            'type' => 'image'
		        ],
		        'dynamic'   => [
		            'active' => true,
		        ]
		    ]
		);

		$this->add_control(
		    'contacts',
		    [
		        'label'       => __( 'Contact List', 'themedraft-core' ),
		        'type'        => Controls_Manager::REPEATER,
		        'fields'      => $repeater->get_controls(),
		        'default'     => [
		            [
		                'title' => 'Phone:',
		                'details_text' => '<ul>
                                        <li><a href="tel:1234567890">+410 123 456 789</a></li>
                                        <li><a href="tel:1234567890">+410 987 654 321</a></li>
                                    </ul>',
		            ],
		        ],
		        'title_field' => '{{{ title }}}',
		    ]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'info_title_color_accordion',
			[
				'label' => esc_html__( 'Info Window Style', 'themedraft-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'info_window_title_color',
			[
				'label' => esc_html__( 'Title Color', 'themedraft-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-map-info-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'info_window_text_color',
			[
				'label' => __( 'Description Color', 'themedraft-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-map-info-desc' => 'color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_section();
	}

	protected function render($instance = []) {
		// get our input from the widget settings.
		$settings = $this->get_settings_for_display();

		$map_markers = $settings['marker_list'];

		if ($settings['enable_zoom_controls'] == 'yes') {
			$enable_zoom_control = 'true';
		} else {
			$enable_zoom_control = 'false';
		}

		if ($settings['enable_map_type_control'] == 'yes') {
			$map_type_control = 'true';
		} else {
			$map_type_control = 'false';
		}

		if ($settings['enable_street_control'] == 'yes') {
			$enable_street_control = 'true';
		} else {
			$enable_street_control = 'false';
		}

		if ($settings['enable_fullscreen_control'] == 'yes') {
			$enable_fullscreen_control = 'true';
		} else {
			$enable_fullscreen_control = 'false';
		}

		if ($settings['zoom_on_scroll'] == 'yes') {
			$zoom_on_scroll = 'true';
		} else {
			$zoom_on_scroll = 'false';
		}

		if ($settings['info_window_always_open'] == 'yes') {
			$automatic_open = 'true';
		} else {
			$automatic_open = 'false';
		}

		if ($settings['info_window_hover_open'] == 'yes') {
			$hover_open = 'true';
		} else {
			$hover_open = 'false';
		}

		if ($settings['info_window_hide_mouseout'] == 'yes') {
			$hover_close = 'true';
		} else {
			$hover_close = 'false';
		}

		if (!empty($settings['map_custom_style'])) {
			$map_custom_style = $settings['map_custom_style'];
		} else {
			$map_custom_style = '';
		}

        if($settings['map_center_lat'] && $settings['map_center_long']){
	        $centerlat = $settings['map_center_lat'];
	        $centerlong = $settings['map_center_long'];
        }else{
	        foreach($map_markers as $index => $value) {
		        if ($index == 0) {
			        $centerlat= $map_markers[0]['map_latitude'];
			        $centerlong= $map_markers[0]['map_longitude'];
		        }
	        }
        }


		$map_settings = [
			'zoom'              => $settings['map_zoom']['size'],
			'maptype'           => $settings['map_type'],
			'streetViewControl' => $enable_street_control,
			'centerlat'         => $centerlat,
			'centerlong'        => $centerlong,
			'scrollwheel'       => $zoom_on_scroll,
			'fullScreen'        => $enable_fullscreen_control,
			'zoomControl'       => $enable_zoom_control,
			'typeControl'       => $map_type_control,
			'automaticOpen'     => $automatic_open,
			'hoverOpen'         => $hover_open,
			'hoverClose'        => $hover_close,
		];

		$this->add_render_attribute('style_wrapper', 'data-style', $settings['map_custom_style']);
		?>


		<div class="td-map-wrapper" id="td-map-wrapper">
            <?php if($settings['enable_contact_details'] == 'yes') : ?>
            <div class="contact-details">
                <div class="container">
                    <div class="row">
	                    <?php if ( $settings['contacts'] ) {
		                    foreach ( $settings['contacts'] as $contact ) { ?>
                                <div class="col-xl-4 col-lg-6 col-md-6">
                                    <div class="td-contact-details-box">
                                        <div class="td-contact-details-box-icon td-primary-color">
                                            <?php if ( $contact['type'] === 'image' ) :
                                                if ( $contact['image']['url'] || $contact['image']['id'] ) :
                                                    ?>

                                                    <img src="<?php echo $contact['image']['url']; ?>"
                                                             alt="<?php echo get_post_meta( $contact['image']['id'], '_wp_attachment_image_alt', true ); ?>">

                                                <?php endif;
                                            elseif ( ! empty( $contact['icon'] ) || ! empty( $contact['selected_icon'] ) ) : ?>

                                                <?php themedraft_custom_icon_render( $contact, 'icon', 'selected_icon' ); ?>

                                            <?php endif; ?>
                                        </div>
                                        <h4 class="td-contact-box-title"><?php echo $contact['title']; ?></h4>

					                    <?php echo $contact['details_text']; ?>
                                    </div>
                                </div>
		                    <?php }
	                    } ?>
                    </div>
                </div>
            </div>
            <?php endif; ?>

			<?php if (count($map_markers)) {
				?>
				<div class="td-gmap"
				     data-settings='<?php echo wp_json_encode($map_settings); ?>' <?php echo $this->get_render_attribute_string('style_wrapper'); ?>>
					<?php
					foreach ( $map_markers as $marker ) {
						?>
						<div class="td-map-marker" data-lng="<?php echo esc_html($marker['map_longitude']); ?>"
						     data-lat="<?php echo esc_html($marker['map_latitude']); ?>"
						     data-icon="<?php echo esc_url($marker['marker_icon']['url']); ?>">
							<?php if (!empty($marker['marker_title']) || !empty($marker['marker_dsc'])): ?>

								<div class='td-map-info-wrapper'>
									<h6 class='td-map-info-title'><?php echo esc_html($marker['marker_title']); ?></h6>
									<div class='td-map-info-desc'><?php echo wp_kses_post($marker['marker_dsc']); ?></div>
								</div>
							<?php endif; ?>
						</div>
						<?php
					}
					?>
				</div>
				<?php
			} ?>
		</div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register(new ThemeDraft_Google_Map());
