<?php
namespace Elementor;

class ThemeDraft_List_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_list';
	}

	public function get_title() {
		return esc_html__( 'TD List', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-bullet-list';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'td_list_options',
			[
				'label' => esc_html__( 'List', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'title',
		    [
		        'label'       => __( 'List Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => 'Why Choose Us?',
		    ]
		);

		$this->add_control(
			'list_layout',
			[
				'label'       => esc_html__('Layout', 'themedraft-core'),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,

				'options' => [
					'default_layout' => [
						'title' => __('Default', 'themedraft-core'),
						'icon'  => 'eicon-editor-list-ul',
					],

					'inline_layout' => [
						'title' => __('Inline', 'themedraft-core'),
						'icon'  => 'eicon-ellipsis-h',
					],

				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
		    'text',
		    [
		        'label'       => __( 'Text', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => 'List Item Text',
		    ]
		);

		$repeater->add_control(
		    'type',
		    [
		        'label'       => esc_html__( 'Icon Type', 'themedraft-core' ),
		        'type'        => Controls_Manager::CHOOSE,
		        'label_block' => false,
		        'options'     => [
		            'icon'  => [
		                'title' => esc_html__( 'Icon', 'themedraft-core' ),
		                'icon'  => 'fa fa-smile-o',
		            ],
		            'image' => [
		                'title' => esc_html__( 'Image', 'themedraft-core' ),
		                'icon'  => 'fa fa-image',
		            ],
		        ],
		        'default'     => 'icon',
		        'toggle'      => false,
		    ]
		);

		$repeater->add_control(
		    'selected_icon',
		    [
		        'label'            => esc_html__( 'Select Icon', 'themedraft-core' ),
		        'type'             => Controls_Manager::ICONS,
		        'fa4compatibility' => 'icon',
		        'label_block'      => true,
		        'default'          => [
		            'value'   => 'fas fa-check',
		            'library' => 'solid',
		        ],
		        'condition'        => [
		            'type' => 'icon'
		        ]
		    ]
		);

		$repeater->add_control(
		    'image',
		    [
		        'label'     => esc_html__( 'Image', 'themedraft-core' ),
		        'type'      => Controls_Manager::MEDIA,
		        'default'   => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		        'condition' => [
		            'type' => 'image'
		        ],
		        'dynamic'   => [
		            'active' => true,
		        ]
		    ]
		);

		$repeater->add_control(
			'item_link',
			[
				'label'         => __( 'Link', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->add_control(
			'list_items',
			[
				'label'       => __('List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'text'        => 'List Item Text',
					],
				],
				'title_field' => '{{{ text }}}',
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$this->add_control(
			'list_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'title_style',
		    [
		        'label' => esc_html__( 'Title', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'title!' => '',
                ],
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typography',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-icon-list-title',
		    ]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-icon-list-title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_responsive_control(
		    'title_margin',
		    [
		        'label'      => esc_html__( 'Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-icon-list-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'td_icon_list_list_style',
			[
				'label' => esc_html__( 'List', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'space_between',
			[
				'label' => __( 'Space Between', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-icon-list-wrapper .td-list-default-layout li' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .td-icon-list-wrapper .td-list-inline-layout li' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrapper_margin',
			[
				'label'      => esc_html__( 'List Wrapper Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-icon-list-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'td_icon_list_icon_style',
			[
				'label' => esc_html__( 'Icon', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
		    'icon_bg_color',
		    [
		        'label'       => esc_html__('Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-icon-list-icon' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'icon_bg_color_on_hover',
			[
				'label'       => esc_html__('Background Color On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-icon-list-item:hover .td-icon-list-icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_default_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-icon-list-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-icon-list-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_hover_color',
			[
				'label'       => esc_html__('Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-icon-list-item:hover .td-icon-list-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-icon-list-item:hover .td-icon-list-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_bg_size',
			[
				'label' => __( 'Icon Background Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 30,
						'max' => 150,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-icon-list-icon' => 'height: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}};line-height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => __( 'Icon Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 16,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-icon-list-icon' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .td-icon-list-icon svg,{{WRAPPER}} .td-icon-list-icon img' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'td_icon_list_text_style',
			[
				'label' => esc_html__( 'Text', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typo',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-icon-list-text',
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-icon-list-text' => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-icon-list-text a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'text_hover_color',
			[
				'label'       => esc_html__('Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-icon-list-text a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
		    'space_from_icon',
		    [
		        'label'      => esc_html__( 'Space From Icon', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-icon-list-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		if($settings['list_layout'] == 'inline_layout' ){
			$list_layout = 'td-list-inline-layout';
		}else{
			$list_layout = 'td-list-default-layout';
		}

		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['list_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>

		<div class="td-icon-list-wrapper <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>

            <?php if ($settings['title']) : ?>
            <h3 class="td-icon-list-title"><?php echo $settings['title'];?></h3>
            <?php endif; ?>

			<ul class="<?php echo $list_layout;?>">
				<?php
				if($settings['list_items']){
					foreach ($settings['list_items'] as $list_item){ ?>
						<li class="td-icon-list-item">
                                <span class="td-icon-list-icon td-primary-color">
                                    <?php if ( $list_item['type'] === 'image' ) :
                                        if ( $list_item['image']['url'] || $list_item['image']['id'] ) :
                                            ?>

                                                <img src="<?php echo $list_item['image']['url']; ?>"
                                                     alt="<?php echo get_post_meta( $list_item['image']['id'], '_wp_attachment_image_alt', true ); ?>">
                                        <?php endif;
                                    elseif ( ! empty( $list_item['icon'] ) || ! empty( $list_item['selected_icon'] ) ) : ?>
                                        <?php themedraft_custom_icon_render( $list_item, 'icon', 'selected_icon' ); ?>
                                    <?php endif; ?>
                                </span>
							<span class="td-icon-list-text">
	                            <?php if(!empty($list_item['item_link']['url'])) :
	                            $target   = $list_item['item_link']['is_external'] ? ' target="_blank"' : '';
	                            $nofollow = $list_item['item_link']['nofollow'] ? ' rel="nofollow"' : '';
	                            ?>
                                <a href="<?php echo $list_item['item_link']['url'];?>" <?php echo $target . $nofollow;?>>
                                <?php endif;?>
                                <?php echo $list_item['text'];?>
                                <?php if(!empty($list_item['item_link']['url'])) : ?>
                                </a>
                                <?php endif;?>
                                </span>
						</li>
						<?php
					}
				}
				?>
			</ul>
		</div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_List_Widget );