<?php
namespace Elementor;

class ThemeDraft_Video_Popup_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_video_popup';
	}

	public function get_title() {
		return esc_html__( 'Video Popup', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-youtube';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'video_popup_settings',
			[
				'label' => esc_html__( 'Video Popup', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'video_image',
		    [
		        'label'       => __( 'Image', 'themedraft-core' ),
		        'type'        => Controls_Manager::MEDIA,
		        'label_block' => true,
		        'default'     => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		    ]
		);

		$this->add_control(
			'video_url',
			[
				'label'       => esc_html__( 'Video Url', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block'        => true,
				'default'     => 'https://vimeo.com/100902001',
			]
		);

		$this->add_control(
		    'caption',
		    [
		        'label'       => __( 'Caption', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => 'Intro Video.',
		    ]
		);

		$this->add_control(
			'overlay',
			[
				'label'     => esc_html__( 'Enable Overlay', 'themedraft-core' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
				'label_off' => esc_html__( 'No', 'themedraft-core' ),
				'default'   => 'yes',
			]
		);

		$this->add_responsive_control(
			'button_size',
			[
				'label' => esc_html__( 'Button Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 200,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-video-popup-wrapper .td-video-button:before, {{WRAPPER}} .td-video-popup-wrapper .td-video-button:after' => 'height: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'video_height',
			[
				'label' => esc_html__( 'Wrapper Height', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 200,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .td-video-popup-wrapper .td-video-popup-image' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'video_bg_height',
			[
				'label' => esc_html__( 'Background Height', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['%'],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .td-video-wrapper-bg' => 'height: {{SIZE}}%;',
				],
			]
		);


		$this->add_control(
			'entrance_animation',
			[
				'label' => esc_html__( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
			]
		);

		$this->add_control(
			'video_animation_duration',
			[
				'label'     => esc_html__( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => esc_html__( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => esc_html__( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => esc_html__( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();


		//Style tab start
		$this->start_controls_section(
			'video_popup_style',
			[
				'label' => esc_html__( 'Video Popup', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'caption_typo',
		        'label' => esc_html__( 'Caption Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-video-caption.td-secondary-font',
		    ]
		);

		$this->add_control(
		    'caption_color',
		    [
		        'label'       => esc_html__('Caption Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-video-popup-wrapper .td-video-caption' => '-webkit-text-stroke-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'button_bg_color',
			[
				'label'       => esc_html__('Button Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-video-popup-wrapper .td-video-button:before, {{WRAPPER}} .td-video-popup-wrapper .td-video-button:after' => 'background-color: {{VALUE}};',
				],
                'separator' => 'before',
			]
		);

		$this->add_control(
			'button_icon_color',
			[
				'label'       => esc_html__('Button Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-video-popup-wrapper .td-video-button i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'overlay_color',
			[
				'label'       => esc_html__('Overlay Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-video-popup-overlay' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'overlay' => 'yes',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label'       => esc_html__('Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-video-wrapper-bg' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		if($settings['entrance_animation']){
			$td_animation = 'wow'.' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['video_animation_duration'];
		}else{
			$td_animation ='';
			$td_animation_duration ='';
		}
		?>

        <div class="td-video-popup-wrapper <?php echo esc_attr($td_animation);?>" <?php echo esc_attr($td_animation_duration);?>>
            <div class="td-video-wrapper-bg"></div>
            <div class="container">
                <div class="row">
                    <div class="col-lg-12">
                        <div class="td-video-popup-image td-cover-bg" style="background-image: url(<?php echo $settings['video_image']['url'];?>)">
                            <?php if ($settings['overlay'] == 'yes') : ?>
                                <div class="td-video-popup-overlay"></div>
                            <?php endif; ?>
                            <a href="<?php echo esc_url($settings['video_url']);?>" class="td-video-button mfp-iframe">
                                <i class="fa fa-play"></i>
                            </a>

                            <div class="td-video-caption td-secondary-font"><?php echo $settings['caption'];?></div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <script>
            jQuery(document).ready(function ($) {
                $(".td-video-button").magnificPopup({
                    type: 'video',
                });
            });
        </script>

		<?php

	}

	//Template
	protected function content_template() { ?>

        <div class="td-video-popup-wrapper">
            <div class="td-video-wrapper-bg"></div>
            <div class="container">
                <div class="row">
                    <div class="col-lg-12">
                        <div class="td-video-popup-image td-cover-bg" style="background-image: url({{ settings.video_image.url }})">
                            <# if ( settings.overlay == 'yes' ) { #>
                            <div class="td-video-popup-overlay"></div>
                            <# } #>
                            <a href="{{{settings.video_url}}}" class="td-video-button mfp-iframe">
                                <i class="fa fa-play"></i>
                            </a>

                            <div class="td-video-caption td-secondary-font">{{{settings.caption}}}</div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <script>
            jQuery(document).ready(function ($) {
                $(".td-video-button").magnificPopup({
                    type: 'video',
                });
            });
        </script>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Video_Popup_Widget );