<?php

namespace Elementor;

class ThemeDraft_Pricing_Table_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_pricing_table';
	}

	public function get_title() {
		return esc_html__( 'Pricing Table', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-price-table';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'pricing_table_options',
			[
				'label' => esc_html__( 'Pricing Table', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'layout',
		    [
		        'label'   => __( 'Layout', 'themedraft-core' ),
		        'type'    => Controls_Manager::SELECT,
		        'default' => 'td-pricing-one',
		        'options' => [
		            'td-pricing-one' => __( 'Layout One', 'themedraft-core' ),
		            'td-pricing-two'  => __( 'Layout Two', 'themedraft-core' ),
		        ],
		    ]
		);

		$this->add_control(
		    'thumbnail',
		    [
		        'label'       => __( 'Image', 'themedraft-core' ),
		        'type'        => Controls_Manager::MEDIA,
		        'label_block' => true,
		        'default'     => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
                'condition' => [
                    'layout' => 'td-pricing-two',
                ],
		    ]
		);


		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Basic',
				'label_block' => true,
			]
		);

		$this->add_control(
			'price',
			[
				'label'   => __( 'Price', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( '$99', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'time_period',
			[
				'label'   => __( 'Time Period', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => 'Monthly',
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'text',
			[
				'label'       => __( 'Text', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'List Item Text',
				'label_block' => true,
			]
		);


		$repeater->add_control(
			'selected_icon',
			[
				'label'            => __( 'Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-double-right-arrow',
					'library' => 'themedraft-garden-icon',
				],
			]
		);

		$repeater->add_control(
			'item_link',
			[
				'label'         => __( 'Link', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->add_control(
			'list_items',
			[
				'label'       => __( 'List', 'themedraft-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'text' => 'List Item Text',
					],
				],
				'title_field' => '{{{ text }}}',
			]
		);

		$this->add_control(
			'btn_text',
			[
				'label'   => __( 'Button Text', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => 'Order Now',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_link',
			[
				'label'         => __( 'Button Link', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$this->add_control(
			'box_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'pricing_style',
		    [
		        'label' => esc_html__( 'Pricing Table', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typo',
		        'label' => esc_html__( 'Title Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-pricing-two .td-table-title,{{WRAPPER}} .td-table-title',
		    ]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'price_typo',
				'label' => esc_html__( 'Price Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-price',
			]
		);

		$this->start_controls_tabs('td_table_style_tabs');

		//Default style start
		$this->start_controls_tab(
			'table_normal_style',
			[
				'label' => esc_html__('Normal', 'themedraft-core'),
			]
		);

		$this->add_control(
		    'table_background_color',
		    [
		        'label'       => esc_html__('Table Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-pricing-table' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'shape_color_one',
		    [
		        'label'       => esc_html__('Shape Color One', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-pricing-shape-one' => 'border-color: {{VALUE}};',
		            '{{WRAPPER}} .td-pricing-shape-three' => 'background-color: {{VALUE}};',
		        ],
                'condition' => [
                    'layout' => 'td-pricing-one',
                ],
		    ]
		);

		$this->add_control(
			'shape_color_two',
			[
				'label'       => esc_html__('Shape Color Two', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-shape-two' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .td-pricing-shape-four' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'layout' => 'td-pricing-one',
				],
			]
		);

		$this->add_control(
			'image_bg_color',
			[
				'label'       => esc_html__('Image Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-two .td-pricing-image' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'layout' => 'td-pricing-two',
				],
			]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Title Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-table-title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'price_color',
		    [
		        'label'       => esc_html__('Price Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-price' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'duration_color',
		    [
		        'label'       => esc_html__('Duration Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-duration' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'features_color',
		    [
		        'label'       => esc_html__('Features Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-pricing-features li,{{WRAPPER}} .td-pricing-features li a' => 'color: {{VALUE}};',
		            '{{WRAPPER}} .td-pricing-features li svg' => 'fill: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
			'table_hover_style',
			[
				'label' => esc_html__('Hover', 'themedraft-core'),
			]
		);

		$this->add_control(
			'table_hover_background_color',
			[
				'label'       => esc_html__('Table Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-table:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'shape_color_one_hover',
			[
				'label'       => esc_html__('Shape Color One', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-table:hover .td-pricing-shape-one' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .td-pricing-table:hover .td-pricing-shape-three' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'layout' => 'td-pricing-one',
				],
			]
		);

		$this->add_control(
			'shape_color_two_hover',
			[
				'label'       => esc_html__('Shape Color Two', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-table:hover .td-pricing-shape-two' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .td-pricing-table:hover .td-pricing-shape-four' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'layout' => 'td-pricing-one',
				],
			]
		);

		$this->add_control(
			'image_bg_hover_color',
			[
				'label'       => esc_html__('Image Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-two .td-pricing-table:hover .td-pricing-image' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'layout' => 'td-pricing-two',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label'       => esc_html__('Title Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-table:hover .td-table-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'price_hover_color',
			[
				'label'       => esc_html__('Price Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-table:hover .td-price' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'duration_hover_color',
			[
				'label'       => esc_html__('Duration Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-table:hover .td-duration' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'features_hover_color',
			[
				'label'       => esc_html__('Features Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-table:hover .td-pricing-features li, {{WRAPPER}} .td-pricing-table:hover .td-pricing-features li a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-pricing-table:hover .td-pricing-features li svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();


		// Button Style
		$this->start_controls_section(
			'pricing_button_style',
			[
				'label' => esc_html__( 'Button', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'button_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-button.td-pricing-button',
		    ]
		);


		$this->start_controls_tabs('td_button_style_tabs');

		//Default style start
		$this->start_controls_tab(
			'btn_normal_style',
			[
				'label' => esc_html__('Normal', 'themedraft-core'),
			]
		);

		$this->add_control(
			'button_normal_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-button.td-pricing-button' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_normal_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-button.td-pricing-button' => 'color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
			'btn_hover_style',
			[
				'label' => esc_html__('Hover', 'themedraft-core'),
			]
		);

		$this->add_control(
		    'btn_bg_on_table_hover',
		    [
		        'label'       => esc_html__('Background Color On Table Hover', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-pricing-table:hover .td-button.td-pricing-button' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'button_hover_bg',
			[
				'label'     => esc_html__('Background Color On Button Hover', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .td-pricing-table:hover .td-button.td-pricing-button:hover' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-button.td-pricing-button:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();


	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['box_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>

		<div class="td-pricing-table-wrapper <?php echo $settings['layout'].' '. $td_animation;?>" <?php echo $td_animation_duration;?>>
            <div class="td-pricing-table">
                <?php if($settings['layout'] == 'td-pricing-one') : ?>
                <div class="td-pricing-shape-one"></div>
                <div class="td-pricing-shape-two"></div>
                <div class="td-pricing-shape-three"></div>
                <div class="td-pricing-shape-four"></div>
                <?php endif; ?>

	            <?php if($settings['layout'] == 'td-pricing-two') :
		            $img_src = $settings['thumbnail']['url'];
		            ?>
                    <div class="td-pricing-image td-transition">
                        <img src="<?php echo esc_url($img_src);?>" alt="Pricing">
                    </div>
	            <?php endif; ?>

                <div class="td-pricing-top">
                    <h6 class="td-table-title"><?php echo $settings['title']; ?></h6>
                    <h6 class="td-price"><?php echo $settings['price']; ?></h6>
                    <span class="td-duration"><?php echo $settings['time_period']; ?></span>
                </div>

                <div class="td-pricing-features">
                    <div class="td-price-list-wrapper">
                        <ul class="td-list-default-layout">
			                <?php
			                if ( $settings['list_items'] ) {
				                foreach ( $settings['list_items'] as $list_item ) { ?>
                                    <li class="td-price-list-item">
                                    <span class="td-price-list-icon">
                                        <?php ThemeDraft_Custom_Icon_Render( $list_item, 'icon', 'selected_icon' ); ?>
                                    </span>
                                        <span class="td-price-list-text">
                                    <?php if ( ! empty( $list_item['item_link']['url'] ) ) :
                                    $target = $list_item['item_link']['is_external'] ? ' target="_blank"' : '';
                                    $nofollow = $list_item['item_link']['nofollow'] ? ' rel="nofollow"' : '';
                                    ?>
                                    <a href="<?php echo $list_item['item_link']['url']; ?>" <?php echo $target . $nofollow; ?>>
                                    <?php endif;
                                    ?>
                                    <?php echo $list_item['text']; ?>
                                    <?php if ( ! empty( $list_item['item_link']['url'] ) ) : ?>
                                    </a>
                                    <?php endif;
                                    ?>
                                    </span>
                                    </li>
					                <?php
				                }
			                }
			                ?>
                        </ul>
                    </div>
                </div>

	            <?php if ( ! empty( $settings['btn_text'] ) ) :
		            $btn_target = $settings['button_link']['is_external'] ? ' target="_blank"' : '';
		            $btn_nofollow = $settings['button_link']['nofollow'] ? ' rel="nofollow"' : '';
		            ?>

                    <div class="td-pricing-button">
                        <a href="<?php echo $settings['button_link']['url']; ?>  <?php echo $btn_target . $btn_nofollow; ?>"
                           class="td-button td-pricing-button"><?php echo $settings['btn_text']; ?><i class="flaticon-double-right-arrow"></i></a>
                    </div>
	            <?php endif; ?>
            </div>
		</div>

		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Pricing_Table_Widget );