<?php
namespace Elementor;

class ThemeDraft_Project_Details_Slider_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_project_details_slider';
	}

	public function get_title() {
		return esc_html__( 'Project Info Slider', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-slider-push';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'project_details_slider_options',
			[
				'label' => esc_html__( 'Project Images', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'slide_images',
			[
				'label'   => __('Slider Images', 'themedraft-core'),
				'type'    => Controls_Manager::GALLERY,
				'default' => [],
			]
		);

		$this->add_control(
		    'enable_slider',
		    [
		        'label'     => esc_html__( 'Enable Slider', 'themedraft-core' ),
		        'type'      => Controls_Manager::SWITCHER,
		        'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
		        'label_off' => esc_html__( 'No', 'themedraft-core' ),
		        'default'   => 'yes',
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'project_info_option',
		    [
		        'label' => esc_html__( 'Project Information', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		    ]
		);

		$this->add_control(
		    'enable_info',
		    [
		        'label'     => esc_html__( 'Enable Information', 'themedraft-core' ),
		        'type'      => Controls_Manager::SWITCHER,
		        'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
		        'label_off' => esc_html__( 'No', 'themedraft-core' ),
		        'default'   => 'yes',
		    ]
		);

		$this->add_control(
			'info_title',
			[
				'label'       => __( 'Info Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => 'Project Information',
                'condition' => [
                    'enable_info' => 'yes',
                ],
			]
		);

		$this->add_control(
			'info_list',
			[
				'label'       => __( 'Info List', 'themedraft-core' ),
				'type'        => Controls_Manager::WYSIWYG,
				'default'     => '<ul>
									<li><strong>Start Date</strong>  01 Jan 2021</li>
									<li><strong>End Date</strong>20 May 2021</li>
									<li><strong>Duration</strong>06 Months</li>
									<li><strong>Client</strong>ThemeDraft</li>
									<li><strong>Location</strong>New York, USA.</li>
									<li><strong>Budget</strong>$1000</li>
									<li><strong>Website</strong><a href="https://themedraft.net/">themedraft.net</a></li>
								</ul>
                ',
				'label_block' => true,
				'description' => __('Create an unordered list. Wrap with Bold/strong for bold text', 'themedraft-core'),
				'condition' => [
					'enable_info' => 'yes',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'slider_option',
		    [
		        'label' => esc_html__( 'Slider', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'enable_slider' => 'yes',
                ],
		    ]
		);

		$this->add_responsive_control(
		    'main_slider_height',
		    [
		        'label' => esc_html__( 'Slider Height', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['px'],
		        'range' => [
		            'px' => [
		                'min' => 200,
		                'max' => 1000,
		            ],
		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],

		        'selectors' => [
		            '{{WRAPPER}} .td-project-details-main-slider-item.slick-slide' => 'height: {{SIZE}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_control(
			'desktop_count',
			[
				'label'   => __( 'Nav Column On Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 3,
				'options' => [
					1  => __( '1 Column', 'themedraft-core' ),
					2  => __( '2 Column', 'themedraft-core' ),
					3  => __( '3 Column', 'themedraft-core' ),
					4  => __( '4 Column', 'themedraft-core' ),
					5  => __( '5 Column', 'themedraft-core' ),
					6  => __( '6 Column', 'themedraft-core' ),
					7  => __( '7 Column', 'themedraft-core' ),
					8  => __( '8 Column', 'themedraft-core' ),
					9  => __( '9 Column', 'themedraft-core' ),
					10 => __( '10 Column', 'themedraft-core' ),
					11 => __( '11 Column', 'themedraft-core' ),
					12 => __( '12 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'tab_count',
			[
				'label'   => __( 'Nav Column On Tablet', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 3,
				'options' => [
					1  => __( '1 Column', 'themedraft-core' ),
					2  => __( '2 Column', 'themedraft-core' ),
					3  => __( '3 Column', 'themedraft-core' ),
					4  => __( '4 Column', 'themedraft-core' ),
					5  => __( '5 Column', 'themedraft-core' ),
					6  => __( '6 Column', 'themedraft-core' ),
					7  => __( '7 Column', 'themedraft-core' ),
					8  => __( '8 Column', 'themedraft-core' ),
					9  => __( '9 Column', 'themedraft-core' ),
					10 => __( '10 Column', 'themedraft-core' ),
					11 => __( '11 Column', 'themedraft-core' ),
					12 => __( '12 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'mobile_count',
			[
				'label'   => __( 'Nav Column On Mobile', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 3,
				'options' => [
					1  => __( '1 Column', 'themedraft-core' ),
					2  => __( '2 Column', 'themedraft-core' ),
					3  => __( '3 Column', 'themedraft-core' ),
					4  => __( '4 Column', 'themedraft-core' ),
					5  => __( '5 Column', 'themedraft-core' ),
					6  => __( '6 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'project_info_style',
		    [
		        'label' => esc_html__( 'Info', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		        'condition' => [
			        'enable_info' => 'yes',
		        ],
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typo',
		        'label' => esc_html__( 'Title Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-project-info-title',
		    ]
		);

		$this->add_control(
		    'box_bg_color',
		    [
		        'label'       => esc_html__('Box Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-project-info' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'item_bg_color',
			[
				'label'       => esc_html__('Item Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-project-info-list li' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_border_color',
			[
				'label'       => esc_html__('Item Border Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-project-info-list li' => 'border-bottom-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();

		if($settings['enable_info'] == 'yes'){
			$slide_col = 'col-xl-8 col-lg-7';
		}else{
			$slide_col = 'col-xl-12';
		}

		if($settings['enable_slider'] == 'yes'){
		    $info_col = 'col-xl-4 col-lg-5';
        }else{
			$info_col = 'col-xl-12';
        }

		?>
		<div class="td-project-details-content">
			<div class="td-project-info-slider-wrapper">
				<div class="row">

                    <?php if($settings['enable_slider'] == 'yes') : ?>
					<div class="<?php echo $slide_col;?>">
						<div class="td-project-details-main-slider">
							<?php
							if ($settings['slide_images']) {
								foreach ( $settings['slide_images'] as $image ) { ?>
                                    <div class="td-project-details-main-slider-item td-cover-bg" style="background-image: url(<?php echo esc_url($image['url']); ?>)"></div>
									<?php

								}
							}
							?>
						</div>

						<div class="td-project-details-slider-nav">
							<?php
							if ($settings['slide_images']) {
								foreach ( $settings['slide_images'] as $image ) {
									$image_alt = get_post_meta( $image['id'], '_wp_attachment_image_alt', true );
									$image_title = get_the_title( $image['id']);
									?>
                                    <img src="<?php echo esc_url($image['url']); ?>" alt="<?php echo esc_attr($image_alt);?>" title="<?php echo esc_attr($image_title);?>">
									<?php

								}
							}
							?>
						</div>
					</div>
                    <?php endif; ?>

                    <?php if($settings['enable_info'] == 'yes') :?>
					<div class="<?php echo $info_col;?>">
						<div class="td-project-info">
							<h4 class="td-project-info-title"><?php echo $settings['info_title'];?></h4>
							<div class="td-project-info-list td-list-style">
                            <?php echo $settings['info_list'];?>
							</div>
						</div>
					</div>
                    <?php endif; ?>
				</div>
			</div>
		</div>
        
		<?php if($settings['enable_slider'] == 'yes') : ?>
        <script>
            (function ($) {
                'use strict';
                $(document).ready(function () {
                    $(".td-project-details-main-slider").slick({
                        slidesToShow: 1,
                        slidesToScroll: 1,
                        autoplay: true,
                        autoplaySpeed: 4000, //interval
                        speed: 1500, // slide speed
                        dots: false,
                        arrows: false,
                        infinite: true,
                        fade: true,
                        pauseOnHover: false,
                        centerMode: false,
                        asNavFor: '.td-project-details-slider-nav'
                    });

                    $(".td-project-details-slider-nav").slick({
                        slidesToShow:  <?php echo json_encode( $settings['desktop_count'] )?>,
                        slidesToScroll: 1,
                        autoplay: true,
                        autoplaySpeed: 4000, //interval
                        speed: 1500, // slide speed
                        dots: false,
                        arrows: false,
                        infinite: true,
                        pauseOnHover: false,
                        centerMode: true,
                        centerPadding: '0px',
                        asNavFor: '.td-project-details-main-slider',
                        focusOnSelect: true,
                        responsive: [
                            {
                                breakpoint: 992,
                                settings: {
                                    slidesToShow: <?php echo json_encode( $settings['tab_count'] )?>, //768-991
                                }
                            },
                            {
                                breakpoint: 768,
                                settings: {
                                    slidesToShow: <?php echo json_encode( $settings['mobile_count'] )?>, // 0 -767
                                }
                            }
                        ]
                    });
                });
            })(jQuery);
        </script>
        <?php endif; ?>
		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Project_Details_Slider_Widget );