<?php
namespace Elementor;

class ThemeDraft_Project_Gallery_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_project_gallery';
	}

	public function get_title() {
		return esc_html__( 'Project Gallery', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-posts-grid';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}

	public function get_script_depends() {
		return ['isotope'];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'project_gallery_option',
			[
				'label' => esc_html__( 'Project Gallery', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'image',
			[
				'label'   => esc_html__( 'Image', 'themedraft-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => 'Garden Care',
			]
		);

		$repeater->add_control(
		    'description',
		    [
		        'label'       => __( 'Description', 'themedraft-core' ),
		        'type'        => Controls_Manager::WYSIWYG,
		        'default'     => 'It is a long established fact that reader will the readable content',
		        'label_block' => true,
		    ]
		);

		$repeater->add_control(
			'details_url',
			[
				'label'         => __( 'Details URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$repeater->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$repeater->add_control(
			'gallery_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->add_control(
			'gallery_items',
			[
				'label'       => esc_html__( 'Gallery Lists', 'themedraft-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'title' => 'Garden Care',
						'description' => 'It is a long established fact that reader will the readable content',
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'gallery_style_options',
		    [
		        'label' => esc_html__( 'Item Style', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typography',
		        'label' => esc_html__( 'Title Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-gallery-title',
		    ]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Title Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-gallery-title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'description_typo',
		        'label' => esc_html__( 'Description Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-gallery-description',
                'separator' => 'before',
		    ]
		);

		$this->add_control(
		    'description_color',
		    [
		        'label'       => esc_html__('Description Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-gallery-description' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'arrow_color',
		    [
		        'label'       => esc_html__('Arrow Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-gallery-url' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'arrow_color_on_hover',
			[
				'label'       => esc_html__('Arrow Color On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-gallery-url:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'overlay_color',
		    [
		        'label'       => esc_html__('Overlay Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-gallery-content-wrapper:before' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'wrapper_style',
		    [
		        'label' => esc_html__( 'Wrapper Style', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_responsive_control(
		    'wrapper_margin',
		    [
		        'label'      => esc_html__( 'Wrapper Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-gallery-item-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_responsive_control(
			'wrapper_padding',
			[
				'label'      => esc_html__( 'Wrapper Padding', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-gallery-item-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
		    'wrapper_max_width',
		    [
		        'label' => esc_html__( 'Max Width', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['%', 'px'],
		        'range' => [
		            '%' => [
		                'min' => 0,
		                'max' => 100,
		            ],

		            'px' => [
			            'min' => 1170,
			            'max' => 1500,
		            ],
		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],
		        'selectors' => [
		            '{{WRAPPER}} .td-gallery-item-wrapper' => 'max-width: {{SIZE}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$td_id = rand(100, 100000);
		?>

		<div id="td-gallery-<?php echo esc_attr($td_id);?>" class="td-gallery-item-wrapper">
			<div class="row">
				<?php
				if ( $settings['gallery_items'] ) {
					foreach ( $settings['gallery_items'] as $gallery_item ) {
					    $img_src = $gallery_item['image']['url'];
					    $title = $gallery_item['title'];
					    $description = $gallery_item['description'];

						$target   = $gallery_item['details_url']['is_external'] ? ' target="_blank"' : '';
						$nofollow = $gallery_item['details_url']['nofollow'] ? ' rel="nofollow"' : '';
						$details_url = $gallery_item['details_url']['url'];

						if ( $gallery_item['entrance_animation'] ) {
							$td_animation          = 'wow' . ' ' . $gallery_item['entrance_animation'];
							$td_animation_duration = $gallery_item['gallery_animation_duration'];
						} else {
							$td_animation          = '';
							$td_animation_duration = '';
						}

					    ?>

                        <div class="td-gallery-item col-xl-3 <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>
                            <div class="td-gallery-content-wrapper td-cover-bg"
                                 style="background-image: url(<?php echo esc_url($img_src);?>)">
                                <div class="td-gallery-content">
                                    <div class="td-table-cell">
                                        <a href="<?php echo esc_url($details_url);?>" <?php echo $target . $nofollow?>>
                                            <h4 class="td-gallery-title"><?php echo esc_html($title);?></h4>
                                        </a>

                                        <div class="td-gallery-description">
                                            <?php echo $description;?>
                                        </div>

                                        <a href="<?php echo esc_url($details_url);?>" class="td-gallery-url" <?php echo $target . $nofollow?>>
                                            <i class="flaticon-right"></i>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </div>

						<?php
					}
				}
				?>
			</div>
		</div>


        <script>
            jQuery(window).on('load',function ($) {
                jQuery('#td-gallery-<?php echo esc_attr($td_id);?>').imagesLoaded(function () {
                    jQuery('#td-gallery-<?php echo esc_attr($td_id);?>').isotope({
                        itemSelector: '.td-gallery-item',
                        percentPosition: true,
                        transitionDuration: '.8s',
                        masonry: {columnWidth: 1,}
                    });
                });
            });
        </script>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Project_Gallery_Widget );