<?php
namespace Elementor;

class ThemeDraft_Project_Slider_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_project_slider';
	}

	public function get_title() {
		return esc_html__( 'Project Slider', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-slider-push';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'project_slider_option',
			[
				'label' => esc_html__( 'Projects', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'image',
			[
				'label'       => __( 'Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
                'description' => __('Use 540x540 image for better user experience.', 'themedraft-core'),
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => 'Garden Care',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'details_url',
			[
				'label'         => __( 'Details URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->add_control(
			'projects',
			[
				'label'       => __('Project List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'title'        => 'Garden Care',
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->add_control(
		    'button_text',
		    [
		        'label'       => __( 'Button Text', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		        'default'     => 'View Details',
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_options',
			[
				'label' => esc_html__( 'Slider Options', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'       => __( 'Autoplay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'autoplay_interval',
			[
				'label'       => __( 'Autoplay Interval', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					2000  => __( '2 seconds', 'themedraft-core' ),
					3000  => __( '3 seconds', 'themedraft-core' ),
					4000  => __( '4 seconds', 'themedraft-core' ),
					5000  => __( '5 seconds', 'themedraft-core' ),
					6000  => __( '6 seconds', 'themedraft-core' ),
					7000  => __( '7 seconds', 'themedraft-core' ),
					8000  => __( '8 seconds', 'themedraft-core' ),
					9000  => __( '9 seconds', 'themedraft-core' ),
					10000 => __( '10 seconds', 'themedraft-core' ),
				],
				'default'     => 4000,
				'condition'   => [
					'autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'infinity_loop',
			[
				'label'       => __( 'Loop', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'arrow',
			[
				'label'       => __( 'Nav Arrow', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'arrow_position',
			[
				'label'   => __( 'Arrow Position', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'arrow-top-right',
				'options' => [
					'arrow-top-right' => __( 'Top Right ', 'themedraft-core' ),
					'arrow-middle' => __( 'Middle', 'themedraft-core' ),
					'arrow-bottom-right' => __( 'Bottom Right', 'themedraft-core' ),
				],
				'condition' => [
					'arrow' => 'yes',
				],
			]
		);

		$this->add_control(
			'xl_count',
			[
				'label'   => __( 'Columns On Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 3,
				'options' => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'lg_count',
			[
				'label'   => __( 'Columns On Ipad Pro', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 2,
				'options' => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'md_count',
			[
				'label'   => __( 'Columns On Tablet', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 2,
				'options' => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
		    'td_project_style_options',
		    [
		        'label' => esc_html__('Project', 'themedraft-core'),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typography',
		        'label' => esc_html__( 'Title Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .project-slide-item .title',
		    ]
		);

		$this->start_controls_tabs('td_project_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
		    'td_project_style_default',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Title Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .project-slide-item .title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

        $this->add_control(
            'title_bg_color',
            [
                'label'       => esc_html__('Title Background', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .project-slide-item .title' => 'background-color: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			'button_color',
			[
				'label'       => esc_html__('Button Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-project-button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bg_color',
			[
				'label'       => esc_html__('Button Background', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-project-button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_project_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label'       => esc_html__('Title Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .project-slide-item:hover .title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_hover_bg_color',
			[
				'label'       => esc_html__('Title Background', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .project-slide-item:hover .title' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label'       => esc_html__('Button Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .project-slide-item:hover .td-project-button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_bg_color',
			[
				'label'       => esc_html__('Button Background', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .project-slide-item:hover .td-project-button' => 'background-color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();// End Button section

        $this->start_controls_section(
            'wrapper_style',
            [
                'label' => esc_html__( 'Wrapper', 'themedraft-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'wrapper_margin',
            [
                'label'      => esc_html__( 'Wrapper Margin', 'themedraft-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .td-project-slider-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
			'wrapper_padding',
			[
				'label'      => esc_html__( 'Wrapper Padding', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-project-slider' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'project_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
			]
		);

		$this->add_control(
			'project_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'project_animation!' => '',
				]
			]
		);

        $this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$slider_id = rand(10,1000000);

		if ( $settings['project_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['project_animation'];
			$td_animation_duration = $settings['project_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}

		?>

		<div class="td-project-slider-wrapper <?php echo $settings['arrow_position'].' '. $td_animation;?>" <?php echo $td_animation_duration;?>>
			<div class="container-fluid">
				<div id="td-project-slider-<?php echo $slider_id;?>" class="row td-project-slider">
					<?php if ( $settings['projects'] ) {

					    $project_number = 0;

						foreach ( $settings['projects'] as $project ) {

							$project_number++;

							$image_src   = $project['image']['url'];
							$image_alt   = get_post_meta( $project['image']['id'], '_wp_attachment_image_alt', true );
							$image_title = get_the_title( $project['image']['id'] );

							$title = $project['title'];
							$btn_text = $settings['button_text'];
							$details_url = $project['details_url']['url'];
							$target   = $project['details_url']['is_external'] ? ' target="_blank"' : '';
							$nofollow = $project['details_url']['nofollow'] ? ' rel="nofollow"' : '';
						    ?>

                            <div class="col-lg-4">
                                <div class="project-slide-item">
                                    <a href="<?php echo esc_url($details_url);?>" class="project-image" <?php echo $target . $nofollow?>>
                                        <img src="<?php echo esc_url($image_src);?>" alt="<?php echo esc_attr($image_alt);?>" title="<?php echo esc_attr($image_title);?>">
                                        <h3 class="title td-transition"><?php echo esc_html($title);?></h3>
                                    </a>

                                    <a href="<?php echo esc_url($details_url);?>" class="td-project-button" <?php echo $target . $nofollow?>><?php echo esc_html($btn_text);?>
                                        <i class="flaticon-right"></i>
                                    </a>

                                    <span class="project-number td-secondary-font"><?php echo $project_number?></span>
                                </div>
                            </div>

						<?php }
					} ?>
				</div>
			</div>
		</div>

        <script>
            (function ($) {
                'use strict';
                $(document).ready(function () {
                    $('#td-project-slider-<?php echo $slider_id;?>').slick({
                        slidesToShow: <?php echo $settings['xl_count'];?>,
                        autoplay: <?php echo json_encode( $settings['autoplay'] == 'yes' ? true : false ); ?>,
                        autoplaySpeed: <?php echo $settings['autoplay_interval'] == '' ? 4000:$settings['autoplay_interval'];?>,
                        speed: 1500, // slide speed
                        dots: false,
                        arrows: <?php echo json_encode( $settings['arrow'] == 'yes' ? true : false ); ?>,
                        prevArrow: '<i class="slick-arrow slick-prev flaticon-double-left-chevron"></i>',
                        nextArrow: '<i class="slick-arrow slick-next flaticon-double-left-chevron"></i>',
                        infinite: <?php echo json_encode( $settings['infinity_loop'] == 'yes' ? true : false ); ?>,
                        pauseOnHover: false,
                        centerMode: false,
                        responsive: [
                            {
                                breakpoint: 1025,
                                settings: {
                                    slidesToShow: <?php echo $settings['lg_count'];?>, //1024
                                }
                            },
                            {
                                breakpoint: 992,
                                settings: {
                                    slidesToShow: <?php echo $settings['md_count'];?>, //768-991
                                }
                            },
                            {
                                breakpoint: 768,
                                settings: {
                                    slidesToShow: 1, // 0 -767
                                    arrows: false,
                                }
                            }
                        ]
                    });
                });
            })(jQuery);
        </script>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Project_Slider_Widget );