<?php
namespace Elementor;

class ThemeDraft_Promo_Box_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_promo_box';
	}

	public function get_title() {
		return esc_html__( 'Promo Box', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-wordpress';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'promo_box_settings',
			[
				'label' => esc_html__( 'Promo Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'title',
		    [
		        'label'       => __( 'Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => 'Mission'
		    ]
		);

		$this->add_control(
		    'description',
		    [
		        'label'       => __( 'Description', 'themedraft-core' ),
		        'type'        => Controls_Manager::WYSIWYG,
		        'default'     => '<p>Lorem Ipsum is simply dummy text the printing to the type of setting has been the industry standard dummy text ever since the 1,50 unknown on printer took a galley of type and scrambled and many other things.</p>',
		    ]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label'        => esc_html__( 'Entrance Animation', 'themedraft-core' ),
				'type'         => Controls_Manager::ANIMATION,
			]
		);

		$this->add_control(
			'wrapper_animation_duration',
			[
				'label'     => esc_html__( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'promo_style_option',
		    [
		        'label' => esc_html__( 'Promo Box', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typo',
		        'label' => esc_html__( 'Title Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-promo-title',
		    ]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Title Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-promo-title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'title_bg',
		    [
		        'label'       => esc_html__('Title Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-promo-title' => 'background-color: {{VALUE}};',
		        ],
		        'separator' => 'after',
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'desc_typo',
		        'label' => esc_html__( 'Description Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-promo-box',
		    ]
		);

		$this->add_control(
		    'desc_color',
		    [
		        'label'       => esc_html__('Description Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-promo-box' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'desc_hover_color',
			[
				'label'       => esc_html__('Description Color On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-promo-box:hover' => 'color: {{VALUE}};',
				],
				'separator' => 'after',
			]
		);

		$this->add_control(
		    'box_bg',
		    [
		        'label'       => esc_html__('Box Background', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-promo-box' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'box_bg_hover',
			[
				'label'       => esc_html__('Box Background On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-promo-box:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['wrapper_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>

		<div class="td-promo-box td-transition <?php echo esc_attr( $td_animation ); ?>" <?php echo esc_attr( $td_animation_duration ); ?>>
			<h6 class="td-promo-title td-primary-bg"><?php echo $settings['title'];?></h6>
            <?php echo $settings['description'];?>
		</div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Promo_Box_Widget );