<?php
namespace Elementor;
use WP_Query;
class ThemeDraft_Recent_Post_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_recent_post';
	}

	public function get_title() {
		return esc_html__( 'Recent Posts', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-post-excerpt';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'recent_post_settings',
			[
				'label' => __( 'Post Settings', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'post_count',
			[
				'label'   => __( 'Number Of Post To Show', 'themedraft-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => - 1,
				'max'     => '',
				'step'    => 1,
				'default' => 3,
			]
		);

		$this->add_control(
			'category',
			[
				'label'       => __( 'Categories', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple'    => true,
				'options'     => themedraft_post_categories(),
			]
		);

		$this->add_control(
			'exclude_post',
			[
				'label'       => __( 'Exclude Posts', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple'    => true,
				'description' => __( 'Select post id.', 'themedraft-core' ),
				'options'     => themedraft_get_post_title_as_list(),
			]
		);

		$this->add_control(
			'post_offset',
			[
				'label'   => __( 'Post Offset', 'themedraft-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => '',
				'step'    => 1,
				'default' => 0,
			]
		);

		$this->add_control(
			'post_orderby',
			[
				'label'   => __( 'Order By', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => themedraft_post_orderby_options(),
				'default' => 'date',

			]
		);

		$this->add_control(
			'post_order',
			[
				'label'   => __( 'Order', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'asc'  => 'Ascending',
					'desc' => 'Descending'
				],
				'default' => 'desc',

			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => __( 'Button Text', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Read More',
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$this->add_control(
			'post_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'recent_post_layout_settings',
			[
				'label' => __( 'Post Layout', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'post_layout',
			[
				'label'   => __( 'Layout', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'td-post-layout-one',
				'options' => [
					'td-post-layout-one' => __( 'layout One', 'themedraft-core' ),
					'td-post-layout-two' => __( 'layout Two', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'columns_desktop',
			[
				'label'   => __( 'Columns On Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-12' => __( '1 Column', 'themedraft-core' ),
					'col-lg-6'  => __( '2 Column', 'themedraft-core' ),
					'col-lg-4'  => __( '3 Column', 'themedraft-core' ),
					'col-lg-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'columns_tab',
			[
				'label'   => __( 'Columns On Tablet', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-sm-6',
				'options' => [
					'col-sm-12' => __( '1 Column', 'themedraft-core' ),
					'col-sm-6'  => __( '2 Column', 'themedraft-core' ),
					'col-sm-4'  => __( '3 Column', 'themedraft-core' ),
					'col-sm-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'title_word',
			[
				'label'   => __( 'Title Word Count', 'themedraft-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => '',
				'step'    => 1,
				'default' => 8,
			]
		);

		$this->add_control(
			'show_author_name',
			[
				'label'   => __( 'Show Author Name', 'themedraft-core' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_date',
			[
				'label'   => __( 'Show Date', 'themedraft-core' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_category',
			[
				'label'   => __( 'Show First Category Name', 'themedraft-core' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);

		$this->add_control(
			'show_comment_count',
			[
				'label'   => __( 'Show Comment Count', 'themedraft-core' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'slider_option',
		    [
		        'label' => esc_html__( 'Slider Options', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		    ]
		);

		$this->add_control(
			'enable_slider',
			[
				'label'     => esc_html__( 'Enable Slider', 'themedraft-core' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
				'label_off' => esc_html__( 'No', 'themedraft-core' ),
				'default'   => 'no',
			]
		);

		$this->add_control(
			'desktop_slide_column',
			[
				'label'   => __( 'Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 3,
				'options' => [
					1   => __( '1 Column', 'themedraft-core' ),
					2    => __( '2 Column', 'themedraft-core' ),
					3    => __( '3 Column', 'themedraft-core' ),
					4    => __( '4 Column', 'themedraft-core' ),
					5    => __( '5 Column', 'themedraft-core' ),
				],
                'condition' => [
                    'enable_slider' => 'yes',
                ],
			]
		);

		$this->add_control(
			'ipad_pro_slide_column',
			[
				'label'   => __( 'iPad Pro', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 2,
				'options' => [
					1   => __( '1 Column', 'themedraft-core' ),
					2    => __( '2 Column', 'themedraft-core' ),
					3    => __( '3 Column', 'themedraft-core' ),
					4    => __( '4 Column', 'themedraft-core' ),
					5    => __( '5 Column', 'themedraft-core' ),
				],
				'condition' => [
					'enable_slider' => 'yes',
				],
			]
		);

		$this->add_control(
			'ipad_slide_column',
			[
				'label'   => __( 'iPad', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 2,
				'options' => [
					1   => __( '1 Column', 'themedraft-core' ),
					2    => __( '2 Column', 'themedraft-core' ),
					3    => __( '3 Column', 'themedraft-core' ),
					4    => __( '4 Column', 'themedraft-core' ),
					5    => __( '5 Column', 'themedraft-core' ),
				],
				'condition' => [
					'enable_slider' => 'yes',
				],
			]
		);
		$this->add_control(
			'autoplay',
			[
				'label'       => __( 'Autoplay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
				'condition' => [
					'enable_slider' => 'yes',
				],
			]
		);

		$this->add_control(
			'autoplay_interval',
			[
				'label'       => __( 'Autoplay Interval', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					2000  => __( '2 seconds', 'themedraft-core' ),
					3000  => __( '3 seconds', 'themedraft-core' ),
					4000  => __( '4 seconds', 'themedraft-core' ),
					5000  => __( '5 seconds', 'themedraft-core' ),
					6000  => __( '6 seconds', 'themedraft-core' ),
					7000  => __( '7 seconds', 'themedraft-core' ),
					8000  => __( '8 seconds', 'themedraft-core' ),
					9000  => __( '9 seconds', 'themedraft-core' ),
					10000 => __( '10 seconds', 'themedraft-core' ),
				],
				'default'     => 4000,
				'condition'   => [
					'autoplay' => 'yes',
					'enable_slider' => 'yes',
				],
			]
		);

		$this->add_control(
			'infinity_loop',
			[
				'label'       => __( 'Loop', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
				'condition' => [
					'enable_slider' => 'yes',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'title_style_option',
		    [
		        'label' => esc_html__( 'Title', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-recent-post-title,{{WRAPPER}} .td-post-layout-two .td-recent-post-title',
		    ]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-recent-post-title,{{WRAPPER}} .td-post-layout-two .td-recent-post-title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'title_color_on_hover',
			[
				'label'       => esc_html__('Color On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-recent-post-title:hover,{{WRAPPER}} .td-post-layout-two .td-recent-post-content:hover .td-recent-post-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
		    'title_margin',
		    [
		        'label'      => esc_html__( 'Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-recent-post-title,{{WRAPPER}} .td-post-layout-two .td-recent-post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();


		$this->start_controls_section(
		    'meta_style_option',
		    [
		        'label' => esc_html__( 'Post Meta', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'post_meta_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-recent-post-mata ul li',
		    ]
		);

		$this->add_control(
		    'meta_color',
		    [
		        'label'       => esc_html__('Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-recent-post-mata ul li,{{WRAPPER}} .td-recent-post-mata ul li a' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'meta_hover_color',
			[
				'label'     => esc_html__( 'Hover Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-recent-post-mata ul li a:hover,
					{{WRAPPER}} .td-post-layout-two .td-recent-post-content:hover .td-recent-post-mata ul li,
{{WRAPPER}} .td-post-layout-two .td-recent-post-content:hover .td-recent-post-mata ul li a' =>
                        'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
		    'meta_margin',
		    [
		        'label'      => esc_html__( 'Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-recent-post-mata, {{WRAPPER}} .td-post-layout-two .td-recent-post-mata' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		// Start Button section
		$this->start_controls_section(
		    'td_button_style_options',
		    [
		        'label' => esc_html__('Button', 'themedraft-core'),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->start_controls_tabs('td_button_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
		    'td_btn_style_default',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_default_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'button_default_border',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-button' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'button_default_text_color',
		    [
		        'label'     => esc_html__('Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_btn_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_hover_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button:hover' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'button_hover_border',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-button:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'button_hover_text_color',
		    [
		        'label'     => esc_html__('Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button:hover' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();// End Button section

        $this->start_controls_section(
            'item_style',
            [
                'label' => esc_html__( 'Item', 'themedraft-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'post_layout' => 'td-post-layout-two',
                ],
            ]
        );

        $this->add_control(
            'background_color',
            [
                'label'       => esc_html__('Background Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-post-layout-two .td-recent-post-content' => 'background-color: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			'background_hover_color',
			[
				'label'       => esc_html__('Background On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-post-layout-two .td-recent-post-content:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
		    'item_padding',
		    [
		        'label'      => esc_html__( 'Padding', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-post-layout-two .td-recent-post-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

        $this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$td_id = rand(10, 100000);

		if($settings['enable_slider'] == 'yes'){
			$td_column = 'col-12';
		}else{
			$td_column = $settings['columns_desktop'] .' '. $settings['columns_tab'];
		}

		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['post_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}

		?>
		<div class="td-recent-post-el-widget <?php echo $settings['post_layout'];?> <?php if($settings['enable_slider'] == 'yes'){echo 'td-slider-enable';}?>">
			<div id="td-post-wrapper-<?php echo $td_id;?>" class="row">

				<?php
				if ( ! empty( $settings['category'] ) ) {
					$post_query = new WP_Query( array(
						'post_type'           => 'post',
						'posts_per_page'      => $settings['post_count'],
						'ignore_sticky_posts' => 1,
						'offset'              => $settings['post_offset'],
						'orderby'             => $settings['post_orderby'],
						'order'               => $settings['post_order'],
						'post__not_in'        => $settings['exclude_post'],
						'tax_query'           => array(
							array(
								'taxonomy' => 'category',
								'terms'    => $settings['category'],
								'field'    => 'slug',
							)
						)
					) );
				} else {

					$post_query = new WP_Query(
						array(
							'posts_per_page'      => $settings['post_count'],
							'post_type'           => 'post',
							'ignore_sticky_posts' => 1,
							'offset'              => $settings['post_offset'],
							'orderby'             => $settings['post_orderby'],
							'order'               => $settings['post_order'],
							'post__not_in'        => $settings['exclude_post'],
						)
					);
				}

				while ( $post_query->have_posts() ) : $post_query->the_post(); ?>
					<div class="td-recent-post-item <?php echo $td_column . ' ' . $td_animation;?>" <?php echo $td_animation_duration;?>>

                        <div class="td-recent-post-content">
                            <?php if($settings['post_layout'] == 'td-post-layout-two') :?>
                                <a href="<?php echo esc_url( get_the_permalink() );?>">
                                    <h4 class="td-recent-post-title"><?php echo wp_trim_words(get_the_title(), $settings['title_word'], ' ...');?></h4>
                                </a>
                            <?php endif;?>

                            <a href="<?php echo esc_url( get_the_permalink() );?>" class="td-recent-post-thumbnail">
                                <img src="<?php the_post_thumbnail_url('large'); ?>" alt="<?php echo get_post_meta(get_post_thumbnail_id(), '_wp_attachment_image_alt', true); ?>">
                            </a>

	                        <?php if($settings['post_layout'] == 'td-post-layout-one') :?>
                                <a href="<?php echo esc_url( get_the_permalink() );?>">
                                    <h4 class="td-recent-post-title"><?php echo wp_trim_words(get_the_title(), $settings['title_word'], ' ...');?></h4>
                                </a>
	                        <?php endif;?>

                            <div class="td-recent-post-meta-read-more">
                                <div class="td-recent-post-mata td-list-style">
                                    <ul>
	                                    <?php if($settings['show_author_name'] == 'yes' && function_exists('onland_posted_by')) : ?>
                                            <li><?php onland_posted_by(); ?></li>
	                                    <?php endif;?>

	                                    <?php if($settings['show_date'] == 'yes' && function_exists('onland_posted_on')) : ?>
                                            <li><?php onland_posted_on(); ?></li>
	                                    <?php endif;?>

                                        <?php if($settings['show_category'] == 'yes' && function_exists('onland_post_first_category')) : ?>
                                            <li><?php onland_post_first_category(); ?></li>
                                        <?php endif;?>

                                        <?php if($settings['show_comment_count'] == 'yes' && function_exists('onland_comment_count') && get_comments_number() != 0) : ?>
                                            <li><?php onland_comment_count(); ?></li>
                                        <?php endif;?>
                                    </ul>
                                </div>

                                <?php if ( !empty($settings['button_text']) ): ?>
                                    <div class="td-recent-post-read-more">
                                        <a class="td-button" href="<?php echo esc_url( get_the_permalink() ) ?>">
                                            <?php echo esc_html( $settings['button_text'] ); ?>
                                            <i class="flaticon-double-right-arrow"></i>
                                        </a>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
					</div>
				<?php
				endwhile;
				wp_reset_query();
				?>
			</div>
			<?php if($settings['enable_slider'] == 'yes') : ?>
                <script>
                    (function ($) {
                        "use strict";
                        $(document).ready(function () {
                            $("#td-post-wrapper-<?php echo $td_id;?>").slick({
                                slidesToShow: <?php echo json_encode( $settings['desktop_slide_column'] )?>,
                                autoplay: <?php echo json_encode( $settings['autoplay'] == 'yes' ? true : false ); ?>,
                                autoplaySpeed: <?php echo json_encode( $settings['autoplay_interval'] )?>, //interval
                                speed: 1500, // slide speed
                                dots: false,
                                arrows: false,
                                infinite: <?php echo json_encode( $settings['infinity_loop'] == 'yes' ? true : false ); ?>,
                                pauseOnHover: false,
                                centerMode: false,
                                responsive: [
                                    {
                                        breakpoint: 1025,
                                        settings: {
                                            slidesToShow: <?php echo json_encode( $settings['ipad_pro_slide_column'] )?>,
                                        }
                                    },

                                    {
                                        breakpoint: 992,
                                        settings: {
                                            slidesToShow: <?php echo json_encode( $settings['ipad_slide_column'] )?>,
                                        }
                                    },

                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 1,
                                        }
                                    }
                                ]
                            });
                        });
                    })(jQuery);
                </script>
			<?php endif; ?>
		</div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Recent_Post_Widget );