<?php
namespace Elementor;

class ThemeDraft_Service_Box_One_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_service_box_one';
	}

	public function get_title() {
		return esc_html__( 'Service One', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-posts-grid';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'service_box_one_settings',
			[
				'label' => esc_html__( 'Service Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
		    'thumbnail',
		    [
		        'label'       => __( 'Thumbnail Image', 'themedraft-core' ),
		        'type'        => Controls_Manager::MEDIA,
		        'label_block' => true,
		        'default'     => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		    ]
		);

		$repeater->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-leaf-1',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => __( 'Landscape Design', 'themedraft-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'details_url',
			[
				'label'         => __( 'Details URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$repeater->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$repeater->add_control(
			'service_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->add_control(
			'services',
			[
				'label'       => __('Service List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'title'        => __('Landscape Design', 'themedraft-core'),
						'selected_icon' => 'flaticon-leaf-1',
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'column_options',
			[
				'label' => esc_html__( 'Column', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'xl_column',
			[
				'label'   => __( 'Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-xl-3',
				'options' => [
					'col-xl-12'   => __( '1 Column', 'themedraft-core' ),
					'col-xl-6'    => __( '2 Column', 'themedraft-core' ),
					'col-xl-4'    => __( '3 Column', 'themedraft-core' ),
					'col-xl-3'    => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'lg_column',
			[
				'label'   => __( 'iPad Pro', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-12'   => __( '1 Column', 'themedraft-core' ),
					'col-lg-6'    => __( '2 Column', 'themedraft-core' ),
					'col-lg-4'    => __( '3 Column', 'themedraft-core' ),
					'col-lg-3'    => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'md_column',
			[
				'label'   => __( 'iPad', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-md-6',
				'options' => [
					'col-md-12'   => __( '1 Column', 'themedraft-core' ),
					'col-md-6'    => __( '2 Column', 'themedraft-core' ),
					'col-md-4'    => __( '3 Column', 'themedraft-core' ),
					'col-md-3'    => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'sm_column',
			[
				'label'   => __( 'Mobile', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-12',
				'options' => [
					'col-12'   => __( '1 Column', 'themedraft-core' ),
					'col-6'    => __( '2 Column', 'themedraft-core' ),
					'col-4'    => __( '3 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'icon_options',
		    [
		        'label' => esc_html__( 'Icon', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_control(
		    'icon_color',
		    [
		        'label'       => esc_html__('Icon Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-primary-color' => 'color: {{VALUE}};',
		            '{{WRAPPER}} .td-primary-color svg' => 'fill: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'icon_color_on_hover',
			[
				'label'       => esc_html__('Icon Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .service-layout-one .td-service-item:hover .td-primary-color' => 'color: {{VALUE}};',
					'{{WRAPPER}} .service-layout-one .td-service-item:hover .td-primary-color svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon Size (px)', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 30,
						'max' => 150,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .service-layout-one .td-service-box-content .td-icon-wrapper' => 'height: {{SIZE}}px;width: {{SIZE}}px;font-size: {{SIZE}}px;line-height: {{SIZE}}px;',
				],
			]
		);

		$this->end_controls_section();


        $this->start_controls_section(
            'title_options',
            [
                'label' => esc_html__( 'Title', 'themedraft-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Typography', 'themedraft-core' ),
                'selector' => '{{WRAPPER}} .td-one-service-title',
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'       => esc_html__('Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-one-service-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_color_on_hover',
            [
                'label'       => esc_html__('Hover Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .service-layout-one .td-service-item:hover .td-one-service-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'details_button_options',
            [
                'label' => esc_html__( 'Details Button', 'themedraft-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'button_bg_color',
            [
                'label'       => esc_html__('Background Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-secondary-bg' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'content_color_options',
            [
                'label' => esc_html__( 'Content', 'themedraft-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_bg_color',
            [
                'label'       => esc_html__('Background Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .service-layout-one .td-service-box-content' => 'background-color: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			'content_bg_color_on_hover',
			[
				'label'       => esc_html__('Background Color On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .service-layout-one .td-service-item:hover .td-service-box-content' => 'background-color: {{VALUE}};',
				],
			]
		);

        $this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$td_column = $settings['xl_column'] .' '. $settings['lg_column']. ' '. $settings['md_column']. ' '. $settings['sm_column'];

		?>

		<div class="td-service-box-wrapper service-layout-one">
			<div class="row">
				<?php
				if ( $settings['services'] ) {
					foreach ( $settings['services'] as $service ) {
						$target   = $service['details_url']['is_external'] ? ' target="_blank"' : '';
						$nofollow = $service['details_url']['nofollow'] ? ' rel="nofollow"' : '';

						if ( $service['entrance_animation'] ) {
							$td_animation          = 'wow' . ' ' . $service['entrance_animation'];
							$td_animation_duration = $service['service_animation_duration'];
						} else {
							$td_animation          = '';
							$td_animation_duration = '';
						}

						$image_src   = wp_get_attachment_image_url( $service['thumbnail']['id'], 'onland-400' );
						$image_alt   = get_post_meta( $service['thumbnail']['id'], '_wp_attachment_image_alt', true );
						$image_title = get_the_title( $service['thumbnail']['id'] );

						$title = $service['title'];
						$details_url = $service['details_url']['url'];
						?>
							<div class="<?php echo $td_column;?> text-center">
                                <div class="td-service-item <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>

                                    <img src="<?php echo esc_url($image_src);?>" alt="<?php echo esc_attr($image_alt);?>" title="<?php echo esc_attr( $image_title );?>">

                                    <div class="td-service-box-content-wrapper">

                                        <div class="td-service-box-content td-transition">
                                            <div class="td-box-content">
                                                <div class="td-box-icon-title td-transition">
                                                    <?php if ( $service['type'] === 'image' ) :
                                                        if ( $service['image']['url'] || $service['image']['id'] ) :
                                                            ?>
                                                            <div class="td-icon-wrapper td-image-icon td-transition td-primary-color">
                                                                <img src="<?php echo $service['image']['url']; ?>"
                                                                     alt="<?php echo get_post_meta( $service['image']['id'], '_wp_attachment_image_alt', true ); ?>">
                                                            </div>
                                                        <?php endif;
                                                    elseif ( ! empty( $service['icon'] ) || ! empty( $service['selected_icon'] ) ) : ?>
                                                        <div class="td-icon-wrapper td-font-icon td-transition td-primary-color">
                                                            <?php themedraft_custom_icon_render( $service, 'icon', 'selected_icon' ); ?>
                                                        </div>
                                                    <?php endif; ?>
                                                    <div class="td-title-wrapper">
                                                        <a href="<?php echo esc_url($details_url);?>" <?php echo $target . $nofollow?>>
                                                            <h3 class="td-one-service-title td-transition"><?php echo esc_html($title);?></h3>
                                                        </a>
                                                    </div>
                                                </div>

                                                <a href="<?php echo esc_url($details_url);?>" class="td-service-details td-transition td-secondary-bg" <?php echo $target . $nofollow?> ><i class="flaticon-double-right-arrow"></i></a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
							</div>
						<?php
					}
				}
				?>
			</div>
		</div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Service_Box_One_Widget );