<?php
namespace Elementor;

class ThemeDraft_Service_Box_Two_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_service_box_two';
	}

	public function get_title() {
		return esc_html__( 'Service Two', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-posts-grid';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'service_box_two_settings',
			[
				'label' => esc_html__( 'Service Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'thumbnail',
			[
				'label'       => __( 'Thumbnail Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-tree-1',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => 'Grass Cleaning',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'details_url',
			[
				'label'         => __( 'Details URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$repeater->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$repeater->add_control(
			'service_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->add_control(
			'services',
			[
				'label'       => __('Service List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'title'        => __('Grass Cleaning', 'themedraft-core'),
						'selected_icon' => 'flaticon-tree-1',
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->add_control(
			'icon_position',
			[
				'label'   => __( 'Icon Position', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'middle',
				'options' => [
					'top-right' => __( 'Top Right', 'themedraft-core' ),
					'middle' => __( 'Middle', 'themedraft-core' ),
					'top-left' => __( 'Top Left', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
		    'enable_border',
		    [
		        'label'     => esc_html__( 'Image Border', 'themedraft-core' ),
		        'type'      => Controls_Manager::SWITCHER,
		        'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
		        'label_off' => esc_html__( 'No', 'themedraft-core' ),
		        'default'   => 'no',
		    ]
		);

		$this->add_control(
		    'enable_slider',
		    [
		        'label'     => esc_html__( 'Enable Slider', 'themedraft-core' ),
		        'type'      => Controls_Manager::SWITCHER,
		        'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
		        'label_off' => esc_html__( 'No', 'themedraft-core' ),
		        'default'   => 'yes',
		    ]
		);
		$this->end_controls_section();

		$this->start_controls_section(
		    'column_settings',
		    [
		        'label' => esc_html__( 'Column', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'enable_slider!' => 'yes',
                ],
		    ]
		);

		$this->add_control(
			'xl_column',
			[
				'label'   => __( 'Columns On Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-xl-3',
				'options' => [
					'col-xl-12' => __( '1 Column', 'themedraft-core' ),
					'col-xl-6'  => __( '2 Column', 'themedraft-core' ),
					'col-xl-4'  => __( '3 Column', 'themedraft-core' ),
					'col-xl-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'lg_column',
			[
				'label'   => __( 'Columns On Ipad Pro', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-12' => __( '1 Column', 'themedraft-core' ),
					'col-lg-6'  => __( '2 Column', 'themedraft-core' ),
					'col-lg-4'  => __( '3 Column', 'themedraft-core' ),
					'col-lg-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'md_column',
			[
				'label'   => __( 'Columns On Tablet', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-md-6',
				'options' => [
					'col-md-12' => __( '1 Column', 'themedraft-core' ),
					'col-md-6'  => __( '2 Column', 'themedraft-core' ),
					'col-md-4'  => __( '3 Column', 'themedraft-core' ),
					'col-md-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_options',
			[
				'label' => esc_html__( 'Slider Options', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
				'condition' => [
					'enable_slider' => 'yes',
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'       => __( 'Autoplay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'autoplay_interval',
			[
				'label'       => __( 'Autoplay Interval', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					2000  => __( '2 seconds', 'themedraft-core' ),
					3000  => __( '3 seconds', 'themedraft-core' ),
					4000  => __( '4 seconds', 'themedraft-core' ),
					5000  => __( '5 seconds', 'themedraft-core' ),
					6000  => __( '6 seconds', 'themedraft-core' ),
					7000  => __( '7 seconds', 'themedraft-core' ),
					8000  => __( '8 seconds', 'themedraft-core' ),
					9000  => __( '9 seconds', 'themedraft-core' ),
					10000 => __( '10 seconds', 'themedraft-core' ),
				],
				'default'     => 4000,
				'condition'   => [
					'autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'infinity_loop',
			[
				'label'       => __( 'Loop', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'arrow',
			[
				'label'       => __( 'Nav Arrow', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
		    'arrow_position',
		    [
		        'label'   => __( 'Arrow Position', 'themedraft-core' ),
		        'type'    => Controls_Manager::SELECT,
		        'default' => 'arrow-bottom-right',
		        'options' => [
		            'arrow-top-right' => __( 'Top Right ', 'themedraft-core' ),
		            'arrow-middle' => __( 'Middle', 'themedraft-core' ),
		            'arrow-bottom-right' => __( 'Bottom Right', 'themedraft-core' ),
		        ],
                'condition' => [
                    'arrow' => 'yes',
                ],
		    ]
		);

		$this->add_control(
			'xl_count',
			[
				'label'   => __( 'Columns On Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 4,
				'options' => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'lg_count',
			[
				'label'   => __( 'Columns On Ipad Pro', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 3,
				'options' => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'md_count',
			[
				'label'   => __( 'Columns On Tablet', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 2,
				'options' => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
		    'td_service_style_options',
		    [
		        'label' => esc_html__('Services', 'themedraft-core'),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->start_controls_tabs('td_service_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
		    'td_service_style_default',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

        $this->add_control(
            'icon_color',
            [
                'label'       => esc_html__('Icon Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-service-two-icon' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .td-service-two-icon svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'icon_bg_color',
            [
                'label'       => esc_html__('Icon Background Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-service-two-icon' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'       => esc_html__('Title Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-service-two-title' => 'color: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			'title_bg_color',
			[
				'label'       => esc_html__('Title Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-two-title' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'bottom_border_color',
		    [
		        'label'       => esc_html__('Bottom Border Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-service-title-wrapper' => 'border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'arrow_bg_color',
		    [
		        'label'       => esc_html__('Arrow Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .slick-arrow' => 'background-color: {{VALUE}};',
		        ],
                'condition' => [
                    'arrow' => 'yes',
                ],
		    ]
		);

		$this->add_control(
		    'image_border_color',
		    [
		        'label'       => esc_html__('Image Border Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-service-image.border-enable' => 'border-color: {{VALUE}};',
		        ],
                'condition' => [
                    'enable_border' => 'yes',
                ],
		    ]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_service_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
			'icon_hover_color',
			[
				'label'       => esc_html__('Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-two-item:hover .td-service-two-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-service-two-item:hover .td-service-two-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_hover_bg_color',
			[
				'label'       => esc_html__('Icon Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-two-item:hover .td-service-two-icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label'       => esc_html__('Title Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-two-item:hover .td-service-two-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_hover_bg_color',
			[
				'label'       => esc_html__('Title Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-two-item:hover .td-service-two-title' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'arrow_hover_bg_color',
			[
				'label'       => esc_html__('Arrow Hover Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .slick-arrow:hover' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'arrow' => 'yes',
				],
			]
		);

		$this->add_control(
			'image_border_hover_color',
			[
				'label'       => esc_html__('Image Border Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-two-item:hover .td-service-image.border-enable' => 'border-color: {{VALUE}};',
				],
				'condition' => [
					'enable_border' => 'yes',
				],
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		if($settings['enable_slider'] == 'yes'){
			$td_column = 'col-12';
		}else{
			$td_column = $settings['xl_column'] .' '. $settings['lg_column'] .' '. $settings['md_column'];
		}

		$td_id = rand(100,100000);
		?>

		<div id="service-wrapper-<?php echo $td_id;?>" class="row service-layout-two <?php echo $settings['arrow_position'];?>">

			<?php
			if ( $settings['services'] ) {
				foreach ( $settings['services'] as $service ) {
					$target   = $service['details_url']['is_external'] ? ' target="_blank"' : '';
					$nofollow = $service['details_url']['nofollow'] ? ' rel="nofollow"' : '';

					if ( $service['entrance_animation'] ) {
						$td_animation          = 'wow' . ' ' . $service['entrance_animation'];
						$td_animation_duration = $service['service_animation_duration'];
					} else {
						$td_animation          = '';
						$td_animation_duration = '';
					}

					$image_src   = wp_get_attachment_image_url( $service['thumbnail']['id'], 'onland-400' );
					$image_alt   = get_post_meta( $service['thumbnail']['id'], '_wp_attachment_image_alt', true );
					$image_title = get_the_title( $service['thumbnail']['id'] );

					$title       = $service['title'];
					$details_url = $service['details_url']['url'];
					?>
                    <div class="<?php echo $td_column;?>">
                        <div class="td-service-two-item <?php echo esc_attr($settings['icon_position']);?> <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>
                            <a href="<?php echo esc_url($details_url);?>" class="d-inline-block td-service-details-url" <?php echo $target . $nofollow?>>
                                <div class="td-service-image <?php if($settings['enable_border'] == 'yes'){echo 'border-enable';}?>">
                                    <img src="<?php echo esc_url($image_src);?>" alt="<?php echo esc_attr($image_alt);?>" title="<?php echo esc_attr( $image_title );?>">

                                    <div class="td-service-two-icon td-transition td-primary-color">
	                                    <?php if ( $service['type'] === 'image' ) :
		                                    if ( $service['image']['url'] || $service['image']['id'] ) :
			                                    ?>

                                                <img src="<?php echo $service['image']['url']; ?>"
                                                     alt="<?php echo get_post_meta( $service['image']['id'], '_wp_attachment_image_alt', true ); ?>">

		                                    <?php endif;
                                        elseif ( ! empty( $service['icon'] ) || ! empty( $service['selected_icon'] ) ) : ?>

		                                    <?php themedraft_custom_icon_render( $service, 'icon', 'selected_icon' ); ?>

	                                    <?php endif; ?>
                                    </div>
                                </div>

                                <div class="td-service-title-wrapper">
                                    <h4 class="td-service-two-title td-transition"><?php echo esc_html($title);?></h4>
                                </div>
                            </a>
                        </div>
                    </div>
					<?php
				}
			}
			?>

		</div>

		<?php if($settings['enable_slider'] == 'yes') : ?>
            <script>
                (function ($) {
                    "use strict";
                    $(document).ready(function () {
                        $("#service-wrapper-<?php echo $td_id;?>").slick({
                            slidesToShow: <?php echo $settings['xl_count'];?>,
                            autoplay: <?php echo json_encode( $settings['autoplay'] == 'yes' ? true : false ); ?>,
                            autoplaySpeed: <?php echo $settings['autoplay_interval'] == '' ? 4000:$settings['autoplay_interval'];?>,
                            speed: 1500,
                            dots: false,
                            arrows: <?php echo json_encode( $settings['arrow'] == 'yes' ? true : false ); ?>,
                            prevArrow: '<i class="slick-arrow slick-prev flaticon-double-left-chevron"></i>',
                            nextArrow: '<i class="slick-arrow slick-next flaticon-double-left-chevron"></i>',
                            infinite: <?php echo json_encode( $settings['infinity_loop'] == 'yes' ? true : false ); ?>,
                            pauseOnHover: false,
                            centerMode: false,
                            responsive: [
                                {
                                    breakpoint: 1025,
                                    settings: {
                                        slidesToShow: <?php echo $settings['lg_count'];?>,
                                    }
                                },

                                {
                                    breakpoint: 992,
                                    settings: {
                                        slidesToShow: <?php echo $settings['md_count'];?>,
                                    }
                                },

                                {
                                    breakpoint: 768,
                                    settings: {
                                        arrows: false,
                                        slidesToShow: 1,
                                    }
                                }
                            ]
                        });
                    });
                })(jQuery);
            </script>
		<?php endif; ?>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Service_Box_Two_Widget );