<?php
namespace Elementor;

class ThemeDraft_Service_Gallery_Slider_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_service_gallery_image_slider';
	}

	public function get_title() {
		return esc_html__( 'Service Gallery Slider', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-slider-push';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'gallery_image_options',
			[
				'label' => esc_html__( 'Gallery Images', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'slide_images',
			[
				'label'   => __('Add Images', 'themedraft-core'),
				'type'    => Controls_Manager::GALLERY,
				'default' => [],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'       => __('Autoplay', 'themedraft-core'),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
				'separator'     => 'before',
			]
		);

		$this->add_control(
			'dots',
			[
				'label'       => __('Navigation Dots', 'themedraft-core'),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'arrow',
			[
				'label'       => __('Navigation Arrow', 'themedraft-core'),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$this->add_control(
			'slide_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
		    'gallery_style_options',
		    [
		        'label' => esc_html__( 'Gallery', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_responsive_control(
			'slide_height',
			[
				'label'           => __('Slider Height', 'themedraft-core'),
				'type'            => Controls_Manager::SLIDER,
				'range'           => [
					'px' => [
						'min' => 300,
						'max' => 800,
					],
				],
				'devices'         => ['desktop', 'tablet', 'mobile'],

				'selectors'       => [
					'{{WRAPPER}} .single-service-gallery-slide-item,{{WRAPPER}} .single-service-gallery-slide-item.slick-slide' => 'height: {{SIZE}}{{UNIT}};',
				],
				'separator'       => 'before',
			]
		);

		$this->add_control(
			'dot_color',
			[
				'label'       => esc_html__('Navigation Dot Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-gallery-slider .slick-dots button' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'dots' => 'yes',
				],
			]
		);

		$this->add_control(
			'dot_active_color',
			[
				'label'       => esc_html__('Navigation Dot Active Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-gallery-slider .slick-dots .slick-active button,{{WRAPPER}} .td-service-gallery-slider .slick-dots button:hover' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'dots' => 'yes',
				],
			]
		);

		$this->add_control(
			'arrow_bg',
			[
				'label'       => esc_html__('Arrow Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-gallery-slider .slick-arrow' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'arrow' => 'yes',
				],
			]
		);

		$this->add_control(
			'arrow_hover_bg',
			[
				'label'       => esc_html__('Arrow Hover Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-gallery-slider .slick-arrow:hover' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'arrow' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
		    'wrapper_margin',
		    [
		        'label'      => esc_html__( 'Wrapper Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-service-gallery-slider' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$slider_id = rand(10, 1000);
		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['slide_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>
        <div id="td-service-slider-<?php echo esc_attr($slider_id); ?>" class="td-service-gallery-slider <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>
            <?php
            if ($settings['slide_images']) {
                foreach ( $settings['slide_images'] as $image ) { ?>
                    <div class="single-service-gallery-slide-item td-cover-bg" style="background-image: url(<?php echo esc_url($image['url']); ?>)"></div>
                    <?php

                }
            }
            ?>
        </div>

		<?php if ($settings['slide_images'] && count($settings['slide_images']) > 1) : ?>

            <script>
                (function ($) {
                    "use strict";
                    //Document Ready Function
                    $(document).ready(function () {
                        // slider - active
                        function serviceGallerySlider() {
                            var SliderActive = $('#td-service-slider-<?php echo esc_attr($slider_id);?>');

                            SliderActive.slick({
                                slidesToShow: 1,
                                autoplay: <?php echo json_encode($settings['autoplay'] == 'yes' ? true : false); ?>,
                                autoplaySpeed: 4000,
                                speed: 1500, // slide speed
                                dots:<?php echo json_encode($settings['dots'] == 'yes' ? true : false); ?>,
                                fade: false,
                                draggable: true,
                                pauseOnHover: false,
                                arrows: <?php echo json_encode($settings['arrow'] == 'yes' ? true : false); ?>,
                                prevArrow: '<i class="slick-arrow slick-prev flaticon-double-left-chevron"></i>',
                                nextArrow: '<i class="slick-arrow slick-next flaticon-double-left-chevron"></i>',
                            });
                        }

                        serviceGallerySlider();

                    });
                })(jQuery);
            </script>
		<?php endif; ?>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Service_Gallery_Slider_Widget );