<?php
namespace Elementor;

class ThemeDraft_Skill_Bar_Line_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_skill_bar_line';
	}

	public function get_title() {
		return esc_html__( 'Skill Bar Line', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-skill-bar';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}

	public function get_script_depends() {
		return ['counterup', 'appear'];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'add_skills_settings',
			[
				'label' => esc_html__( 'Skills', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'main_title',
			[
				'label'       => __( 'Main Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 4,
				'default'     => 'Main Title Here',
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'title',
			[
				'label'       => __('Title', 'themedraft-core'),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Bar Title Here',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'percent',
			[
				'label' => __( 'Percentage', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['%'],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 80,
				],
			]
		);

		$this->add_control(
			'skills',
			[
				'label'       => __('Skill List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'title'        => 'Bar Title Here',
						'percent' => 80
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label'        => esc_html__( 'Entrance Animation', 'themedraft-core' ),
				'type'         => Controls_Manager::ANIMATION,
			]
		);

		$this->add_control(
			'wrapper_animation_duration',
			[
				'label'     => esc_html__( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typo',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-skill-main-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-skill-main-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'title_margin',
			[
				'label'      => esc_html__( 'Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-skill-main-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'skill_style_options',
			[
				'label' => esc_html__( 'Skills', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'bar_bg_color',
			[
				'label'       => esc_html__('Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-skills-wrapper .skillbar' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'bar_fill_color',
			[
				'label'       => esc_html__('Fill Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-skills-wrapper .count-bar' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'       => esc_html__('Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .skill-title,{{WRAPPER}} .td-skills-wrapper .count-bar' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['wrapper_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>

        <div class="td-skills-wrapper <?php echo esc_attr( $td_animation ); ?>" <?php echo esc_attr( $td_animation_duration ); ?>>
            <h3 class="td-skill-main-title"><?php echo $settings['main_title'];?></h3>
			<?php
			if($settings['skills']){
				foreach($settings['skills'] as $skill){ ?>
                    <div class="skillbar" data-percent="<?php echo $skill['percent']['size'];?>%">
                        <div class="skill-title"><?php echo $skill['title'];?></div>
                        <div class="count-bar td-primary-bg">
                            <div class="skill-percent-count-wrap"><span class="skill-percent-count"><?php echo $skill['percent']['size'];?></span>%</div>
                        </div>
                    </div>
					<?php
				}
			}
			?>

        </div>
		<?php

	}

	//Template
	protected function content_template() { ?>
        <div class="td-skills-wrapper">
            <h3 class="td-skill-main-title">{{{settings.main_title}}}</h3>
            <# if ( settings.skills.length ) { #>
            <# _.each( settings.skills, function( skill ) { #>
            <div class="skillbar" data-percent="{{skill.percent.size}}%">
                <div class="skill-title">{{{skill.title}}}</div>
                <div class="count-bar td-primary-bg">
                    <div class="skill-percent-count-wrap"><span class="skill-percent-count">{{{skill.percent.size}}}</span>%</div>
                </div>
            </div>
            <# }); #>
            <# } #>
        </div>

        <script>
            (function ($) {
                "use strict";
                $(document).ready(function () {
                    $(".skillbar").each(function() {
                        $(this).appear(function() {
                            $(this).find(".count-bar").animate({
                                width:$(this).attr("data-percent")
                            },3000);
                        });
                    });

                    $(".skill-percent-count").counterUp({
                        delay: 10,
                        time: 3000
                    });
                });
            })(jQuery);
        </script>

		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Skill_Bar_Line_Widget );