<?php
namespace Elementor;

class ThemeDraft_Tabs_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_tabs';
	}

	public function get_title() {
		return esc_html__( 'Tab One', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-tabs';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'tab_content_settings',
			[
				'label' => esc_html__( 'Tabs', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'menu_text',
			[
				'label'       => esc_html__('Menu Text', 'themedraft-core'),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Menu 1',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-leaf-1',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
		    'subtitle',
		    [
		        'label'       => __( 'Subtitle', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		        'default'     => '# What Is Our Vision',
		    ]
		);

		$repeater->add_control(
		    'title',
		    [
		        'label'       => __( 'Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => 'We Give Awesome Landscape Service.',
		    ]
		);

		$repeater->add_control(
			'content_text',
			[
				'label'   => esc_html__('Content Text', 'themedraft-core'),
				'type'    => Controls_Manager::WYSIWYG,
				'default' => 'It is a long established fact that a reader will be distracted by the on thing readable content of a page when looking at its layout. There is main point of the using that it has a more-or-less normal distribution of letters, as there is opposed to using making it look like readabl on english page when we looking at its layout.is opposed too using and making it look like readable english.

<strong>It is a long established fact that a reader will be the distracted by on the readable content of a page when looking at its layout. The point that it has a more-or-less normal distribution.</strong>',
			]
		);

		$repeater->add_control(
		    'enable_count_number',
		    [
		        'label'     => esc_html__( 'Enable Count Number', 'themedraft-core' ),
		        'type'      => Controls_Manager::SWITCHER,
		        'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
		        'label_off' => esc_html__( 'No', 'themedraft-core' ),
		        'default'   => 'yes',
		        'separator'   => 'before',
		    ]
		);

		$repeater->add_control(
		    'count_one_number',
		    [
		        'label'       => __( 'Count One Number', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		        'default'     => '25',
                'condition' => [
                    'enable_count_number' => 'yes',
                ],
		    ]
		);

		$repeater->add_control(
			'count_one_symbol',
			[
				'label'       => __( 'Count One Symbol', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '+',
				'condition' => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_one_text',
			[
				'label'       => __( 'Count One Text', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Project Complete Per Month',
				'condition' => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_two_number',
			[
				'label'       => __( 'Count Two Number', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '20',
				'condition' => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_two_symbol',
			[
				'label'       => __( 'Count Two Symbol', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '+',
				'condition' => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_two_text',
			[
				'label'       => __( 'Count Two Text', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Years Practical Experience.',
				'condition' => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_three_number',
			[
				'label'       => __( 'Count Three Number', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '80',
				'condition' => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_three_symbol',
			[
				'label'       => __( 'Count Three Symbol', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '+',
				'condition' => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_three_text',
			[
				'label'       => __( 'Count Three Text', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Awesome Team Members.',
				'condition' => [
					'enable_count_number' => 'yes',
				],
			]
		);


		$this->add_control(
			'tab_items',
			[
				'label'       => esc_html__('Tab List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'menu_text'        => 'Menu 1',
						'subtitle'        => '# What Is Our Vision',
						'title'        => 'We Give Awesome Landscape Service.',
						'content_text' => 'It is a long established fact that a reader will be distracted by the on thing readable content of a page when looking at its layout. There is  main point of the using that it has a more-or-less normal distribution of letters, as there is opposed to using making it look like readabl on english page when we looking at its layout.is opposed too using and  making it look like readable english.

<strong>It is a long established fact that a reader will be the distracted by on the readable content of a page when looking at its layout. The point that it has a more-or-less normal distribution.</strong>',
					],
				],
				'title_field' => '{{{ menu_text }}}',
			]
		);

		$this->add_control(
			'open_by_default',
			[
				'label'       => esc_html__('Open By Default', 'themedraft-core'),
				'type'        => Controls_Manager::NUMBER,
				'min'         => 1,
				'max'         => 1000,
				'step'        => 1,
				'default'     => 1,
				'description' => esc_html__('Which Tab you want to open by default.', 'themedraft-core'),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'tab_menu_style',
		    [
		        'label' => esc_html__( 'Menu Button', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_control(
		    'button_bg_color',
		    [
		        'label'       => esc_html__('Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-tabs-wrapper .nav-tabs .nav-link' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_bg_color_on_hover',
		    [
		        'label'       => esc_html__('Background Color On Hover', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-tabs-wrapper .nav-tabs .nav-link.active, {{WRAPPER}} .td-tabs-wrapper .nav-tabs .nav-link:hover' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_text_color',
		    [
		        'label'       => esc_html__('Text Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-tab-menu-text' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_text_color_on_hover',
		    [
		        'label'       => esc_html__('Text Color On Hover', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-tabs-wrapper .nav-tabs .nav-link.active .td-tab-menu-text,{{WRAPPER}}  .td-tabs-wrapper .nav-tabs .nav-link:hover .td-tab-menu-text' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_icon_color',
		    [
		        'label'       => esc_html__('Icon Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-tabs-wrapper .td-icon-wrapper i' => 'color: {{VALUE}};',
		            '{{WRAPPER}} .td-tabs-wrapper .td-icon-wrapper svg' => 'fill: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'tab_subtitle_style',
		    [
		        'label' => esc_html__( 'Subtitle', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'subtitle_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-tab-layout-one .td-tab-subtitle',
		    ]
		);

		$this->add_control(
		    'subtitle_color',
		    [
		        'label'       => esc_html__('Subtitle Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-tab-layout-one .td-tab-subtitle' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'title_style_option',
		    [
		        'label' => esc_html__( 'Title', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-tab-layout-one .td-tab-title',
		    ]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-tab-layout-one .td-tab-title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'content_style',
		    [
		        'label' => esc_html__( 'Content', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'content_typography',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-tab-content-text',
		    ]
		);

		$this->add_control(
		    'strong_text_color',
		    [
		        'label'       => esc_html__('Strong Text Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-tab-content-wrapper strong' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'count_number_style',
		    [
		        'label' => esc_html__( 'Count Number', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'count_typography',
                'label' => esc_html__( 'Typography', 'themedraft-core' ),
                'selector' => '{{WRAPPER}} .td-count-number-unit span',
            ]
        );

        $this->add_control(
            'count_color',
            [
                'label'       => esc_html__('Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-tab-content-wrapper .td-count-number-unit' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$td_tab_id = rand(10, 10000);
		?>

            <div class="td-tabs-wrapper td-tab-layout-one wow fadeInUp">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="nav nav-tabs" role="tablist">
	                            <?php
	                            if ($settings['tab_items']) {
		                            $menu_count = 0;
		                            foreach ($settings['tab_items'] as $tab_menu) {
			                            $menu_count++;
			                            ?>
                                        <button class="nav-link <?php if($menu_count == $settings['open_by_default']){ echo 'active';}?>" data-bs-toggle="tab" data-bs-target="#td-tab-number-<?php echo $td_tab_id.$menu_count?>" type="button" role="tab">
                                            <?php if ( $tab_menu['type'] === 'image' ) :
                                                if ( $tab_menu['image']['url'] || $tab_menu['image']['id'] ) :
                                                    ?>
                                                    <span class="td-icon-wrapper td-image-icon">
                                                        <img src="<?php echo $tab_menu['image']['url']; ?>"
                                                             alt="<?php echo get_post_meta( $tab_menu['image']['id'], '_wp_attachment_image_alt', true ); ?>">
                                                    </span>
                                                <?php endif;
                                            elseif ( ! empty( $tab_menu['icon'] ) || ! empty( $tab_menu['selected_icon'] ) ) : ?>
                                                <span class="td-icon-wrapper td-font-icon">
                                                    <?php themedraft_custom_icon_render( $tab_menu, 'icon', 'selected_icon' ); ?>
                                                </span>
                                            <?php endif; ?>

                                            <span class="td-tab-menu-text td-secondary-font "><?php echo $tab_menu['menu_text'];?></span>
                                        </button>
		                            <?php }
	                            }
	                            ?>
                            </div>

                            <div class="tab-content">
		                        <?php
		                        if ($settings['tab_items']) {
			                        $content_count = 0;
			                        foreach ($settings['tab_items'] as $tab_content) {
				                        $content_count++;

				                        ?>
                                        <div class="tab-pane fade <?php if($content_count == $settings['open_by_default'] ){ echo 'active show';}?>" id="td-tab-number-<?php echo $td_tab_id.$content_count?>" role="tabpanel">
                                            <div class="td-tab-content-wrapper">
                                                <span class="td-tab-subtitle"><?php echo $tab_content['subtitle'];?></span>

                                                <h3 class="td-tab-title"><?php echo $tab_content['title'];?></h3>

                                                <div class="td-tab-content-text">
	                                                <?php echo $tab_content['content_text'];?>
                                                </div>

                                                <?php if($tab_content['enable_count_number'] == 'yes') : ?>
                                                    <div class="td-tab-count-box-wrapper">
                                                        <div class="row">
                                                            <?php if(!empty($tab_content['count_one_number'])) : ?>
                                                            <div class="col-lg-4 col-md-4 col-sm-4 col-6">
                                                                <div class="td-tab-counter-box">
                                                                    <div class="td-count-number-unit td-secondary-font">
                                                                        <span><?php echo $tab_content['count_one_number'];?><sup><?php echo $tab_content['count_one_symbol'];?></sup></span>
                                                                    </div>
                                                                    <span class="td-count-title"><?php echo $tab_content['count_one_text'];?></span>
                                                                </div>
                                                            </div>
                                                            <?php endif; ?>

                                                            <?php if(!empty($tab_content['count_two_number'])) : ?>
                                                            <div class="col-lg-4 col-md-4 col-sm-4 col-6">
                                                                <div class="td-tab-counter-box">
                                                                    <div class="td-count-number-unit td-secondary-font">
                                                                        <span><?php echo $tab_content['count_two_number'];?><sup><?php echo $tab_content['count_two_symbol'];?></sup></span>
                                                                    </div>
                                                                    <span class="td-count-title"><?php echo $tab_content['count_two_text'];?></span>
                                                                </div>
                                                            </div>
	                                                        <?php endif; ?>

	                                                        <?php if(!empty($tab_content['count_three_number'])) : ?>
                                                                <div class="col-lg-4 col-md-4 col-sm-4 col-6">
                                                                    <div class="td-tab-counter-box">
                                                                        <div class="td-count-number-unit td-secondary-font">
                                                                            <span><?php echo $tab_content['count_three_number'];?><sup><?php echo $tab_content['count_three_symbol'];?></sup></span>
                                                                        </div>
                                                                        <span class="td-count-title"><?php echo $tab_content['count_three_text'];?></span>
                                                                    </div>
                                                                </div>
	                                                        <?php endif; ?>
                                                        </div>
                                                    </div>
                                                <?php endif;?>
                                            </div>
                                        </div>
			                        <?php }
		                        }
		                        ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Tabs_Widget );