<?php
namespace Elementor;

class ThemeDraft_Tabs_Three_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_tabs_three';
	}

	public function get_title() {
		return esc_html__( 'Tab Three', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-tabs';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'tab_content_settings',
			[
				'label' => esc_html__( 'Tabs', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'menu_text',
			[
				'label'       => esc_html__( 'Menu Text', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Menu 1',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'label'            => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-leaf-1',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'subtitle',
			[
				'label'       => __( 'Subtitle', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '# What Is Our Vision',
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'   => __( 'Title', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXTAREA,
				'rows'    => 5,
				'default' => 'We Give Awesome Landscape Service.',
			]
		);

		$repeater->add_control(
			'content_text',
			[
				'label'   => esc_html__( 'Content Text', 'themedraft-core' ),
				'type'    => Controls_Manager::WYSIWYG,
				'default' => 'It is a long established fact that a reader will be distracted by the on thing readable content of a page when looking at its layout. There is main point of the using that it has a more-or-less normal distribution of letters, as there is opposed to using making it look like readabl on english page when we looking at its layout.is opposed too using and making it look like readable english.

<strong>It is a long established fact that a reader will be the distracted by on the readable content of a page when looking at its layout. The point that it has a more-or-less normal distribution.</strong>',
			]
		);

		$repeater->add_control(
			'enable_count_number',
			[
				'label'     => esc_html__( 'Enable Count Number', 'themedraft-core' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
				'label_off' => esc_html__( 'No', 'themedraft-core' ),
				'default'   => 'yes',
				'separator' => 'before',
			]
		);

		$repeater->add_control(
			'count_one_number',
			[
				'label'       => __( 'Count One Number', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '25',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_one_symbol',
			[
				'label'       => __( 'Count One Symbol', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '+',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_one_text',
			[
				'label'       => __( 'Count One Text', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Project Complete Per Month',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_two_number',
			[
				'label'       => __( 'Count Two Number', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '20',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_two_symbol',
			[
				'label'       => __( 'Count Two Symbol', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '+',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_two_text',
			[
				'label'       => __( 'Count Two Text', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Years Practical Experience.',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_three_number',
			[
				'label'       => __( 'Count Three Number', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '80',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_three_symbol',
			[
				'label'       => __( 'Count Three Symbol', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '+',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'count_three_text',
			[
				'label'       => __( 'Count Three Text', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Awesome Team Members.',
				'condition'   => [
					'enable_count_number' => 'yes',
				],
			]
		);


		$this->add_control(
			'tab_items',
			[
				'label'       => esc_html__( 'Tab List', 'themedraft-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'menu_text'    => 'Menu 1',
						'subtitle'     => '# What Is Our Vision',
						'title'        => 'We Give Awesome Landscape Service.',
						'content_text' => 'It is a long established fact that a reader will be distracted by the on thing readable content of a page when looking at its layout. There is  main point of the using that it has a more-or-less normal distribution of letters, as there is opposed to using making it look like readabl on english page when we looking at its layout.is opposed too using and  making it look like readable english.

<strong>It is a long established fact that a reader will be the distracted by on the readable content of a page when looking at its layout. The point that it has a more-or-less normal distribution.</strong>',
					],
				],
				'title_field' => '{{{ menu_text }}}',
			]
		);

		$this->add_control(
			'tab_nab_image',
			[
				'label'       => __( 'Tab Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'open_by_default',
			[
				'label'       => esc_html__( 'Open By Default', 'themedraft-core' ),
				'type'        => Controls_Manager::NUMBER,
				'min'         => 1,
				'max'         => 1000,
				'step'        => 1,
				'default'     => 1,
				'description' => esc_html__( 'Which Tab you want to open by default.', 'themedraft-core' ),
			]
		);

		$this->end_controls_section();


		// Start Nav Button section
		$this->start_controls_section(
			'td_nav_button_style_options',
			[
				'label' => esc_html__( 'Tab Navigation', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'nav_image_size',
			[
				'label'      => esc_html__( 'Image Size', 'themedraft-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'devices'    => [ 'desktop', 'tablet', 'mobile' ],
				'selectors'  => [
					'{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'image_margin',
			[
				'label'      => esc_html__( 'Image Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs( 'td_tab_button_style' );

		//Default style tab start
		$this->start_controls_tab(
			'td_nav_style_default',
			[
				'label' => esc_html__( 'Normal', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'nav_btn_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'nav_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label'     => esc_html__( 'Icon Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .td-icon-wrapper'     => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-tabs-three-wrapper .td-icon-wrapper svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'nav_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .td-tab-menu-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		//Hover style tab start
		$this->start_controls_tab(
			'td_nav_style_hover',
			[
				'label' => esc_html__( 'Hover', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'nav_btn_bg_hover_color',
			[
				'label'     => esc_html__( 'Background Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button.active, {{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_hover_color',
			[
				'label'     => esc_html__( 'Icon Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'.td-tabs-three-wrapper .nav.nav-tabs button:hover',
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button.active .td-icon-wrapper,{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button:hover .td-icon-wrapper'         => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button.active .td-icon-wrapper svg,{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button:hover .td-icon-wrapper svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'nav_text_hover_color',
			[
				'label'     => esc_html__( 'Text Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button.active .td-tab-menu-text,{{WRAPPER}} .td-tabs-three-wrapper .nav.nav-tabs button:hover .td-tab-menu-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section(
			'tab_subtitle_style',
			[
				'label' => esc_html__( 'Subtitle', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'subtitle_typo',
				'label'    => esc_html__( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-tabs-three-wrapper .td-tab-subtitle',
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label'     => esc_html__( 'Subtitle Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .td-tab-subtitle' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_style_option',
			[
				'label' => esc_html__( 'Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typo',
				'label'    => esc_html__( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-tabs-three-wrapper .td-tab-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tabs-three-wrapper .td-tab-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_style',
			[
				'label' => esc_html__( 'Content', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'content_typography',
				'label'    => esc_html__( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-tab-content-text',
			]
		);

		$this->add_control(
			'strong_text_color',
			[
				'label'     => esc_html__( 'Strong Text Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tab-content-wrapper strong' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'count_number_style',
			[
				'label' => esc_html__( 'Count Number', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'count_typography',
				'label'    => esc_html__( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-count-number-unit span',
			]
		);

		$this->add_control(
			'count_color',
			[
				'label'     => esc_html__( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-tab-content-wrapper .td-count-number-unit' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$td_tab_id = rand(10, 10000);
		?>

		<div class="td-tabs-three-wrapper">
			<div class="container">
				<div class="row">
					<div class="col-xl-6 td-tab-image">
						<div class="nav nav-tabs" role="tablist" style="background-image: url(<?php echo $settings['tab_nab_image']['url'];?>)">
							<?php
							if ($settings['tab_items']) {
								$menu_count = 0;
								foreach ($settings['tab_items'] as $tab_menu) {
									$menu_count++;
									?>
									<button class="nav-link <?php if($menu_count == $settings['open_by_default']){ echo 'active';}?>" data-bs-toggle="tab" data-bs-target="#td-tab-number-<?php echo $td_tab_id.$menu_count?>" type="button" role="tab">
										<?php if ( $tab_menu['type'] === 'image' ) :
											if ( $tab_menu['image']['url'] || $tab_menu['image']['id'] ) :
												?>
												<span class="td-icon-wrapper td-primary-color">
													<img src="<?php echo $tab_menu['image']['url']; ?>"
													     alt="<?php echo get_post_meta( $tab_menu['image']['id'], '_wp_attachment_image_alt', true ); ?>">
												</span>
											<?php endif;
										elseif ( ! empty( $tab_menu['icon'] ) || ! empty( $tab_menu['selected_icon'] ) ) : ?>
											<span class="td-icon-wrapper td-primary-color">
												<?php themedraft_custom_icon_render( $tab_menu, 'icon', 'selected_icon' ); ?>
											</span>
										<?php endif; ?>

										<span class="td-tab-menu-text td-secondary-font td-transition"><?php echo $tab_menu['menu_text'];?></span>
									</button>
								<?php }
							}
							?>
						</div>
					</div>
					<div class="col-xl-6">
						<div class="tab-content">
							<?php
							if ($settings['tab_items']) {
								$content_count = 0;
								foreach ($settings['tab_items'] as $tab_content) {
									$content_count++;

									?>
									<div class="tab-pane fade <?php if($content_count == $settings['open_by_default'] ){ echo 'active show';}?>" id="td-tab-number-<?php echo $td_tab_id.$content_count?>" role="tabpanel">
										<div class="td-tab-content-wrapper">
											<span class="td-tab-subtitle td-primary-color"><?php echo $tab_content['subtitle'];?></span>

											<h3 class="td-tab-title"><?php echo $tab_content['title'];?></h3>

											<div class="td-tab-content-text">
												<?php echo $tab_content['content_text'];?>
											</div>

											<?php if($tab_content['enable_count_number'] == 'yes') : ?>
												<div class="td-tab-count-box-wrapper">
													<div class="row">
														<?php if(!empty($tab_content['count_one_number'])) : ?>
															<div class="col-lg-4 col-md-4 col-sm-4 col-6">
																<div class="td-tab-counter-box">
																	<div class="td-count-number-unit td-secondary-font">
																		<span><?php echo $tab_content['count_one_number'];?><sup><?php echo $tab_content['count_one_symbol'];?></sup></span>
																	</div>
																	<span class="td-count-title"><?php echo $tab_content['count_one_text'];?></span>
																</div>
															</div>
														<?php endif; ?>

														<?php if(!empty($tab_content['count_two_number'])) : ?>
															<div class="col-lg-4 col-md-4 col-sm-4 col-6">
																<div class="td-tab-counter-box">
																	<div class="td-count-number-unit td-secondary-font">
																		<span><?php echo $tab_content['count_two_number'];?><sup><?php echo $tab_content['count_two_symbol'];?></sup></span>
																	</div>
																	<span class="td-count-title"><?php echo $tab_content['count_two_text'];?></span>
																</div>
															</div>
														<?php endif; ?>

														<?php if(!empty($tab_content['count_three_number'])) : ?>
															<div class="col-lg-4 col-md-4 col-sm-4 col-6">
																<div class="td-tab-counter-box">
																	<div class="td-count-number-unit td-secondary-font">
																		<span><?php echo $tab_content['count_three_number'];?><sup><?php echo $tab_content['count_three_symbol'];?></sup></span>
																	</div>
																	<span class="td-count-title"><?php echo $tab_content['count_three_text'];?></span>
																</div>
															</div>
														<?php endif; ?>
													</div>
												</div>
											<?php endif;?>
										</div>
									</div>
								<?php }
							}
							?>
						</div>
					</div>
				</div>
			</div>
		</div>


		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Tabs_Three_Widget );