<?php
namespace Elementor;

class ThemeDraft_Tabs_Two_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_tabs_two';
	}

	public function get_title() {
		return esc_html__( 'Tab Two', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-tabs';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'tab_content_settings',
			[
				'label' => esc_html__( 'Tabs', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'menu_text',
			[
				'label'       => esc_html__('Menu Text', 'themedraft-core'),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Menu 1',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-leaf-1',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => 'We Give Awesome Landscape Service.',
			]
		);

		$repeater->add_control(
			'content_text',
			[
				'label'   => esc_html__('Content Text', 'themedraft-core'),
				'type'    => Controls_Manager::WYSIWYG,
				'default' => 'It is a long established fact that is a reader will be distracted by the on thing readable content of a pages when looking at its layout. There is one main point of the using that it has a more-or-less normal distribution.

<strong>It is a long established fact that a reader will be the distract by on the readable content of a page when we looking at its layout. The point that it has normal distribution.</strong>',
			]
		);

		$repeater->add_control(
		    'btn_text',
		    [
		        'label'       => __( 'Button Text', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		        'default'     => 'All Services',
		    ]
		);

		$repeater->add_control(
		    'btn_url',
		    [
		        'label'         => __( 'URL', 'themedraft-core' ),
		        'type'          => Controls_Manager::URL,
		        'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
		        'show_external' => true,
		        'default'       => [
		            'url'         => '',
		            'is_external' => false,
		            'nofollow'    => false,
		        ],
		    ]
		);

		$this->add_control(
			'tab_items',
			[
				'label'       => esc_html__('Tab List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'menu_text'        => 'Menu 1',
						'title'        => 'We Give Awesome Landscape Service.',
						'content_text' => 'It is a long established fact that is a reader will be distracted by the on thing readable content of a pages when looking at its layout. There is one main point of the using that it has a more-or-less normal distribution.

<strong>It is a long established fact that a reader will be the distract by on the readable content of a page when we looking at its layout. The point that it has normal distribution.</strong>',
					],
				],
				'title_field' => '{{{ menu_text }}}',
			]
		);

		$this->add_control(
			'open_by_default',
			[
				'label'       => esc_html__('Open By Default', 'themedraft-core'),
				'type'        => Controls_Manager::NUMBER,
				'min'         => 1,
				'max'         => 1000,
				'step'        => 1,
				'default'     => 1,
				'description' => esc_html__('Which Tab you want to open by default.', 'themedraft-core'),
			]
		);

		$this->end_controls_section();

		// Start Button section
		$this->start_controls_section(
		    'tab_menu_style_options',
		    [
		        'label' => esc_html__('Nav Button', 'themedraft-core'),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'mav_typography',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-tab-two-container .td-secondary-font',
		    ]
		);

		$this->add_responsive_control(
		    'nav_padding',
		    [
		        'label'      => esc_html__( 'Padding', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-tab-two-container .nav-link' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->start_controls_tabs('td_nav_button_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
		    'td_nav_btn_style_default',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

		$this->add_control(
			'icon_color',
			[
				'label'       => esc_html__('Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-tab-two-container .td-primary-color' => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-tab-two-container .td-primary-color svg' => 'fill: {{VALUE}};',
				],
			]
		);

        $this->add_control(
            'nav_bg_color',
            [
                'label'       => esc_html__('Background Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-tab-two-container .nav-link' => 'background-color: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			'nav_text_color',
			[
				'label'       => esc_html__('Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-tab-two-container .nav-link' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_nav_btn_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
			'nav_hover_bg_color',
			[
				'label'       => esc_html__('Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-tab-two-container .nav-link:hover,{{WRAPPER}} .td-tab-two-container .nav-link.active' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'nav_hover_text_color',
			[
				'label'       => esc_html__('Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-tab-two-container .nav-link:hover,{{WRAPPER}} .td-tab-two-container .nav-link.active' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tabs();

		$this->end_controls_section();

		// Start Button section
		$this->start_controls_section(
		    'td_button_style_options',
		    [
		        'label' => esc_html__('Button', 'themedraft-core'),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->start_controls_tabs('td_button_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
		    'td_btn_style_default',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_default_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_default_text_color',
		    [
		        'label'     => esc_html__('Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_btn_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_hover_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button:hover' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_hover_text_color',
		    [
		        'label'     => esc_html__('Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button:hover' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();// End Button section

        $this->start_controls_section(
            'wrapper_style',
            [
                'label' => esc_html__( 'Wrapper', 'themedraft-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'wrapper_margin',
            [
                'label'      => esc_html__( 'Wrapper Margin', 'themedraft-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .td-tabs-two-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_responsive_control(
            'wrapper_padding',
            [
                'label'      => esc_html__( 'Wrapper Padding', 'themedraft-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .td-tab-two-container .tab-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$this->add_control(
			'tab_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

        $this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$td_tab_id = rand(10, 10000);
		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['tab_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>

		<div class="td-tabs-two-wrapper <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>

				<div class="row">
					<div class="col-lg-12">
                        <div class="td-tab-two-container">
                            <div class="nav nav-tabs" role="tablist">
                                <?php
                                if ($settings['tab_items']) {
                                    $menu_count = 0;
                                    foreach ($settings['tab_items'] as $tab_menu) {
                                        $menu_count++;
                                        ?>
                                        <button class="nav-link <?php if($menu_count == $settings['open_by_default']){ echo 'active';}?>" data-bs-toggle="tab" data-bs-target="#td-tab-number-<?php echo $td_tab_id.$menu_count?>" type="button" role="tab">
                                            <?php if ( $tab_menu['type'] === 'image' ) :
                                                if ( $tab_menu['image']['url'] || $tab_menu['image']['id'] ) :
                                                    ?>
                                                    <span class="td-icon-wrapper td-image-icon td-primary-color">
                                                        <img src="<?php echo $tab_menu['image']['url']; ?>"
                                                             alt="<?php echo get_post_meta( $tab_menu['image']['id'], '_wp_attachment_image_alt', true ); ?>">
                                                    </span>
                                                <?php endif;
                                            elseif ( ! empty( $tab_menu['icon'] ) || ! empty( $tab_menu['selected_icon'] ) ) : ?>
                                                <span class="td-icon-wrapper td-font-icon td-primary-color">
                                                    <?php themedraft_custom_icon_render( $tab_menu, 'icon', 'selected_icon' ); ?>
                                                </span>
                                            <?php endif; ?>

                                            <span class="td-tab-two-menu-text td-secondary-font "><?php echo $tab_menu['menu_text'];?></span>
                                        </button>
                                    <?php }
                                }
                                ?>
                            </div>

                            <div class="tab-content">
                                <?php
                                if ($settings['tab_items']) {
                                    $content_count = 0;
                                    foreach ($settings['tab_items'] as $tab_content) {
                                        $content_count++;

                                        ?>
                                        <div class="tab-pane fade <?php if($content_count == $settings['open_by_default'] ){ echo 'active show';}?>" id="td-tab-number-<?php echo $td_tab_id.$content_count?>" role="tabpanel">
                                            <div class="td-tab-content-wrapper">

                                                <h3 class="td-tab-title"><?php echo $tab_content['title'];?></h3>

                                                <div class="td-tab-content-text">
                                                    <?php echo $tab_content['content_text'];?>
                                                </div>

                                                <?php if($tab_content['btn_text']) :
	                                                $target = $tab_content['btn_url']['is_external'] ? ' target="_blank"' : '';
	                                                $nofollow = $tab_content['btn_url']['nofollow'] ? ' rel="nofollow"' : '';
                                                    ?>
                                                <div class="td-tab-button">
                                                    <a href="<?php echo $tab_content['btn_url']['url'];?>" class="td-button"  <?php echo  $target . $nofollow?>><?php echo $tab_content['btn_text'];?> <i class="flaticon-double-right-arrow"></i></a>
                                                </div>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    <?php }
                                }
                                ?>
                            </div>
                        </div>
					</div>
				</div>

		</div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Tabs_Two_Widget );