<?php
namespace Elementor;
use WP_Query;
class ThemeDraft_Team_One_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_team_one';
	}

	public function get_title() {
		return esc_html__( 'Team', 'themedraft-core' );
	}

	public function get_icon() {

		return 'far fa-user';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'team_member_options',
			[
				'label' => esc_html__( 'Team Members', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'member_name',
			[
				'label'       => esc_html__( 'Member Name', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Nadim Khan',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'designation',
			[
				'label'       => __( 'Designation', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Senior Gardener',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'       => __( 'Member Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'selected_member_profile',
			[
				'label'       => __( 'Social Profile & <br> Details Link', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => themedraft_team_member_list(),
				'description' => esc_html__( 'Select member name to associate his/her social profile and details page link. Make sure social profile is already added on member single page.', 'themedraft-core' ),
			]
		);

		$repeater->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$repeater->add_control(
			'team_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->add_control(
			'members',
			[
				'label'       => __( 'Member List', 'themedraft-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'member_name' => 'Nadim Khan',
						'designation' => 'Senior Gardener',
					],
				],
				'title_field' => '{{{ member_name }}}',
			]
		);

		$this->add_control(
		    'team_layout',
		    [
		        'label'   => __( 'Layout', 'themedraft-core' ),
		        'type'    => Controls_Manager::SELECT,
		        'default' => 'team-layout-one',
		        'options' => [
		            'team-layout-one' => __( 'Layout One', 'themedraft-core' ),
		            'team-layout-two' => __( 'Layout Two', 'themedraft-core' ),
		        ],
		    ]
		);


		$this->add_control(
			'enable_slider',
			[
				'label'     => esc_html__( 'Enable Slider', 'themedraft-core' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
				'label_off' => esc_html__( 'No', 'themedraft-core' ),
				'default'   => 'no',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'column_settings',
		    [
		        'label' => esc_html__( 'Column', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		        'condition' => [
			        'enable_slider!' => 'yes',
		        ],
		    ]
		);

		$this->add_control(
			'xl_column',
			[
				'label'   => __( 'Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'td-col-xl-5',
				'options' => [
					'col-xl-12'   => __( '1 Column', 'themedraft-core' ),
					'col-xl-6'    => __( '2 Column', 'themedraft-core' ),
					'col-xl-4'    => __( '3 Column', 'themedraft-core' ),
					'col-xl-3'    => __( '4 Column', 'themedraft-core' ),
					'td-col-xl-5'    => __( '5 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'lg_column',
			[
				'label'   => __( 'iPad Pro', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-lg-3',
				'options' => [
					'col-lg-12'   => __( '1 Column', 'themedraft-core' ),
					'col-lg-6'    => __( '2 Column', 'themedraft-core' ),
					'col-lg-4'    => __( '3 Column', 'themedraft-core' ),
					'col-lg-3'    => __( '4 Column', 'themedraft-core' ),
					'td-col-lg-5'    => __( '5 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'md_column',
			[
				'label'   => __( 'iPad', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-md-4',
				'options' => [
					'col-md-12'   => __( '1 Column', 'themedraft-core' ),
					'col-md-6'    => __( '2 Column', 'themedraft-core' ),
					'col-md-4'    => __( '3 Column', 'themedraft-core' ),
					'col-md-3'    => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'sm_column',
			[
				'label'   => __( 'Mobile', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-12',
				'options' => [
					'col-12'   => __( '1 Column', 'themedraft-core' ),
					'col-6'    => __( '2 Column', 'themedraft-core' ),
					'col-4'    => __( '3 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'slider_options',
			[
				'label' => esc_html__( 'Slider Options', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
				'condition' => [
					'enable_slider' => 'yes',
				],
			]
		);

		$this->add_control(
			'desktop',
			[
				'label'   => __( 'Desktop', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 5,
				'options' => [
					1   => __( '1 Column', 'themedraft-core' ),
					2    => __( '2 Column', 'themedraft-core' ),
					3    => __( '3 Column', 'themedraft-core' ),
					4    => __( '4 Column', 'themedraft-core' ),
					5    => __( '5 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'ipad_pro',
			[
				'label'   => __( 'iPad Pro', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 4,
				'options' => [
					1   => __( '1 Column', 'themedraft-core' ),
					2    => __( '2 Column', 'themedraft-core' ),
					3    => __( '3 Column', 'themedraft-core' ),
					4    => __( '4 Column', 'themedraft-core' ),
					5    => __( '5 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'ipad',
			[
				'label'   => __( 'iPad', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 3,
				'options' => [
					1   => __( '1 Column', 'themedraft-core' ),
					2    => __( '2 Column', 'themedraft-core' ),
					3    => __( '3 Column', 'themedraft-core' ),
					4    => __( '4 Column', 'themedraft-core' ),
					5    => __( '5 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'mobile',
			[
				'label'   => __( 'Mobile', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					1   => __( '1 Column', 'themedraft-core' ),
					2    => __( '2 Column', 'themedraft-core' ),
					3    => __( '3 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'       => __( 'Autoplay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'autoplay_interval',
			[
				'label'       => __( 'Autoplay Interval', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					'2000'  => __( '2 seconds', 'themedraft-core' ),
					'3000'  => __( '3 seconds', 'themedraft-core' ),
					'4000'  => __( '4 seconds', 'themedraft-core' ),
					'5000'  => __( '5 seconds', 'themedraft-core' ),
					'6000'  => __( '6 seconds', 'themedraft-core' ),
					'7000'  => __( '7 seconds', 'themedraft-core' ),
					'8000'  => __( '8 seconds', 'themedraft-core' ),
					'9000'  => __( '9 seconds', 'themedraft-core' ),
					'10000' => __( '10 seconds', 'themedraft-core' ),
				],
				'default'     => '4000',
				'condition'   => [
					'autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'infinity_loop',
			[
				'label'       => __( 'Loop', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'join_now_section',
		    [
		        'label' => esc_html__( 'Join Now', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		    ]
		);

		$this->add_control(
		    'enable_join_now',
		    [
		        'label'     => esc_html__( 'Enable Join Now', 'themedraft-core' ),
		        'type'      => Controls_Manager::SWITCHER,
		        'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
		        'label_off' => esc_html__( 'No', 'themedraft-core' ),
		        'default'   => 'no',
		        'description'   => esc_html__( 'If YES, Last item will be a join now button.', 'themedraft-core' ),
		    ]
		);

		$this->add_control(
		    'join_bg_image',
		    [
		        'label'       => __( 'Image', 'themedraft-core' ),
		        'type'        => Controls_Manager::MEDIA,
		        'label_block' => true,
		        'default'     => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
                'condition' => [
                    'enable_join_now' => 'yes',
                ],
		    ]
		);

		$this->add_control(
		    'join_title',
		    [
		        'label'       => __( 'Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => 'You Can Easily Join With Us.',
		        'condition' => [
			        'enable_join_now' => 'yes',
		        ],
		    ]
		);

		$this->add_control(
		    'join_btn_text',
		    [
		        'label'       => __( 'Button Text', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		        'default'     => 'join Now',
		        'condition' => [
			        'enable_join_now' => 'yes',
		        ],
		    ]
		);

		$this->add_control(
		    'join_btn_url',
		    [
		        'label'         => __( 'Button URL', 'themedraft-core' ),
		        'type'          => Controls_Manager::URL,
		        'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
		        'show_external' => true,
		        'default'       => [
		            'url'         => '',
		            'is_external' => false,
		            'nofollow'    => false,
		        ],
		        'condition' => [
			        'enable_join_now' => 'yes',
		        ],
		    ]
		);

		$this->add_responsive_control(
		    'height',
		    [
		        'label' => esc_html__( 'Height', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['px'],
		        'range' => [
		            'px' => [
		                'min' => 300,
		                'max' => 800,
		            ],
		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],
		        'selectors' => [
		            '{{WRAPPER}} .td-join-team' => 'height: {{SIZE}}{{UNIT}};',
		        ],
		        'condition' => [
			        'enable_join_now' => 'yes',
		        ],
		    ]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
				'condition' => [
					'enable_join_now' => 'yes',
				],
			]
		);

		$this->add_control(
			'join_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
					'enable_join_now' => 'yes',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'name_designation_style',
		    [
		        'label' => esc_html__( 'Name & Designation', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'team_layout' => 'team-layout-one',
                ],
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'name_typo',
		        'label' => esc_html__( 'Name Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-member-name',
		    ]
		);

		$this->add_control(
		    'name_color',
		    [
		        'label'       => esc_html__('Name Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}}  .td-member-name' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'designation_typo',
		        'label' => esc_html__( 'Designation Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-designation',
                'separator' => 'before',
		    ]
		);

		$this->add_control(
		    'designation_color',
		    [
		        'label'       => esc_html__('Designation Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}}  .td-designation' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'name_desig_bg',
		    [
		        'label'       => esc_html__('Designation Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .team-layout-one .td-name-designation-wrapper' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();


		$this->start_controls_section(
		    'member_social_style',
		    [
		        'label' => esc_html__( 'Social Icon', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		        'condition' => [
			        'team_layout' => 'team-layout-one',
		        ],
		    ]
		);

		$this->add_control(
		    'social_icon_container_bg',
		    [
		        'label'       => esc_html__('Social Icon Container Background', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-member-social' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'social_icon_bg',
			[
				'label'       => esc_html__('Social Icon Background', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-member-social a' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'social_icon_color',
			[
				'label'       => esc_html__('Social Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-member-social a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'social_icon_color_on_hover',
			[
				'label'       => esc_html__('Social Icon Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-member-social a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'join_now_style',
		    [
		        'label' => esc_html__( 'Join Now', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'enable_join_now' => 'yes',
                ],
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'join_title_style',
		        'label' => esc_html__( 'Title Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-join-title',
		    ]
		);

		$this->add_control(
		    'join_now_title_color',
		    [
		        'label'       => esc_html__('Title Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}}  .td-join-title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'overlay_color',
		    [
		        'label'       => esc_html__('Overlay Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-join-team-overlay' => 'background-color: {{VALUE}};',
		        ],
                'separator' => 'after',
		    ]
		);


		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'btn_typo',
		        'label' => esc_html__( 'Button Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-button',
		        'separator' => 'before',
		    ]
		);

		$this->add_responsive_control(
		    'btn_padding',
		    [
		        'label'      => esc_html__( 'Button Padding', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);


		$this->start_controls_tabs('td_button_style_tabs');

		//Default style tab start
		$this->start_controls_tab(
		    'td_btn_style_default',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_default_bg',
		    [
		        'label'     => esc_html__('Button Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_default_text_color',
		    [
		        'label'     => esc_html__('Button Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_btn_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_hover_bg',
		    [
		        'label'     => esc_html__('Button Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button:hover' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_hover_text_color',
		    [
		        'label'     => esc_html__('Button Text Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td-button:hover' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->add_responsive_control(
			'Join_now_padding',
			[
				'label'      => esc_html__( 'Wrapper Padding', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-join-team-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
                'separator' => 'before',
			]
		);

		$this->end_controls_section();


		// Team Layout Two Style

        $this->start_controls_section(
            'td_team_two_style_options',
            [
                'label' => esc_html__('Team', 'themedraft-core'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
	                'team_layout' => 'team-layout-two',
                ],
            ]
        );

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 't2_name_typo',
				'label' => esc_html__( 'Name Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-member-name',
			]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 't2_designation_typo',
		        'label' => esc_html__( 'Designation Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-designation',
		    ]
		);

        $this->start_controls_tabs('td_t2_style_tabs');

        //Default style tab start
        $this->start_controls_tab(
            'td_t2_style_default',
            [
                'label' => esc_html__('Normal', 'themedraft-core'),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 't2_normal_bg',
                'label' => esc_html__( 'Background', 'themedraft-core' ),
                'types' => [ 'classic', 'gradient'],
                'selector' => '{{WRAPPER}} .team-layout-two .td-single-team-member',
                'exclude' => [
	                'position',
	                'attachment',
	                'repeat',
	                'size',
                ],
            ]
        );

        $this->add_control(
            't2_title_color',
            [
                'label'       => esc_html__('Title Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .team-layout-two .td-member-name' => 'color: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			't2_designation_color',
			[
				'label'       => esc_html__('Designation Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .team-layout-two .td-designation' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    't2_icon_wrapper_bg',
		    [
		        'label'       => esc_html__('Icon Wrapper Background', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .team-layout-two .td-member-social' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    't2_icon_bg',
		    [
		        'label'       => esc_html__('Icon Background', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .team-layout-two .td-member-social a' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);
		$this->add_control(
			't2_icon_color',
			[
				'label'       => esc_html__('Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .team-layout-two .td-member-social a' => 'color: {{VALUE}};',
				],
			]
		);


        $this->end_controls_tab();//Default style tab end

        //Hover style tab start
        $this->start_controls_tab(
            'td_t2_style_hover',
            [
                'label' => esc_html__('Hover', 'themedraft-core'),
            ]
        );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 't2_hover_bg',
				'label' => esc_html__( 'Background', 'themedraft-core' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .team-layout-two .td-single-team-member:hover',
                'exclude' => [
                        'position',
                        'attachment',
                        'repeat',
                        'size',
                ],
			]
		);

		$this->add_control(
			't2_title_hover_color',
			[
				'label'       => esc_html__('Title Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .team-layout-two .td-single-team-member:hover .td-member-name' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			't2_designation_hover_color',
			[
				'label'       => esc_html__('Designation Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .team-layout-two .td-single-team-member:hover .td-designation' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			't2_icon_wrapper_hover_bg',
			[
				'label'       => esc_html__('Icon Wrapper Background', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .team-layout-two .td-single-team-member:hover .td-member-social' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			't2_icon_hover_bg',
			[
				'label'       => esc_html__('Icon Background', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .team-layout-two .td-single-team-member:hover .td-member-social a' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			't2_icon_hover_color',
			[
				'label'       => esc_html__('Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .team-layout-two .td-single-team-member:hover .td-member-social a' => 'color: {{VALUE}};',
				],
			]
		);

        $this->end_controls_tabs();

        $this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();

		if($settings['enable_slider'] == 'yes'){
		    $td_column = 'col-12';
        }else{

		    $td_column = $settings['xl_column'] .' '. $settings['lg_column']. ' '. $settings['md_column']. ' '. $settings['sm_column'];
        }
		$td_id = rand(10, 100000);
		?>

		<div class="td-team-wrapper <?php echo $settings['team_layout']; if($settings['enable_slider'] == 'yes'){echo ' td-slider-enable';}?>">
            <div class="container">
                <div id="td-team-wrapper-<?php echo $td_id;?>" class="row">
                    <?php
                        if($settings['members']){
                            foreach ( $settings['members'] as $member ) {
                                $name = $member['member_name'];
                                $designation = $member['designation'];
                                $image_src   = $member['image']['url'];
                                $image_alt   = get_post_meta( $member['image']['id'], '_wp_attachment_image_alt', true );
                                $image_title = get_the_title( $member['image']['id'] );

	                            if ( $member['entrance_animation'] ) {
		                            $td_animation          = 'wow' . ' ' . $member['entrance_animation'];
		                            $td_animation_duration = $member['team_animation_duration'];
	                            } else {
		                            $td_animation          = '';
		                            $td_animation_duration = '';
	                            }

                                $member_query = new WP_Query(
                                    array(
                                        'posts_per_page' => 1,
                                        'post_type'      => 'onland_team',
                                        'p'              => $member['selected_member_profile'],
                                    )
                                );

                                while ( $member_query->have_posts() ) :
                                    $member_query->the_post();
                                    if ( get_post_meta( get_the_ID(), 'onland_team_meta', true ) ) {
                                        $team_meta = get_post_meta( get_the_ID(), 'onland_team_meta', true );
                                    } else {
                                        $team_meta = array();
                                    }

                                    if ( array_key_exists( 'member_social_profile', $team_meta ) ) {
                                        $member_social = $team_meta['member_social_profile'];
                                    } else {
                                        $member_social = array();
                                    }

                                ?>

                                <div class="<?php echo $td_column;?> text-center <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>
                                    <div class="td-single-team-member">
                                        <div class="td-member-image">
                                            <?php if($member['selected_member_profile']) : ?>
                                            <a href="<?php the_permalink(); ?>">
                                            <?php endif; ?>
                                                <img src="<?php echo esc_url($image_src);?>" alt="<?php echo esc_attr($image_alt);?>" title="<?php echo esc_attr( $image_title );?>">
                                            <?php if($member['selected_member_profile']) : ?>
                                            </a>
                                            <?php endif; ?>

                                            <?php if(!empty($member_social) && $member['selected_member_profile'] && $settings['team_layout'] == 'team-layout-one') : ?>
                                            <div class="td-member-social td-primary-bg">
                                                <ul class="td-list-style td-list-inline">
                                                    <?php
                                                    foreach ( $member_social as $social ) {
                                                        $icon = $social['site_icon'];
                                                        $url  = $social['site_url']; ?>
                                                        <li>
                                                            <a class="td-primary-color td-hover" target="_blank" href="<?php echo esc_url($url); ?>">
                                                                <i class="<?php echo $icon; ?>"></i>
                                                            </a>
                                                        </li>
                                                        <?php
                                                    }
                                                    ?>
                                                </ul>
                                            </div>
                                            <?php endif; ?>
                                        </div>

                                        <div class="td-name-designation-wrapper">
                                            <?php if($member['selected_member_profile']) : ?>
                                            <a href="<?php the_permalink(); ?>">
                                            <?php endif; ?>
                                                <h3 class="td-member-name"><?php echo $name;?></h3>
                                            <?php if($member['selected_member_profile']) : ?>
                                            </a>
                                            <?php endif; ?>
                                            <span class="td-designation td-primary-color"><?php echo $designation;?></span>
                                        </div>

	                                    <?php if(!empty($member_social) && $member['selected_member_profile'] && $settings['team_layout'] == 'team-layout-two') : ?>
                                            <div class="td-member-social td-primary-bg">
                                                <ul class="td-list-style td-list-inline">
				                                    <?php
				                                    foreach ( $member_social as $social ) {
					                                    $icon = $social['site_icon'];
					                                    $url  = $social['site_url']; ?>
                                                        <li>
                                                            <a class="td-primary-color td-hover" target="_blank" href="<?php echo esc_url($url); ?>">
                                                                <i class="<?php echo $icon; ?>"></i>
                                                            </a>
                                                        </li>
					                                    <?php
				                                    }
				                                    ?>
                                                </ul>
                                            </div>
	                                    <?php endif; ?>
                                    </div>
                                </div>
                        <?php
                                endwhile;
                                wp_reset_query();
                            }
                        }
                    ?>

                    <?php if($settings['enable_join_now'] == 'yes') :
                        $image_src = $settings['join_bg_image']['url'];
                        $title = $settings['join_title'];
                        $btn_text = $settings['join_btn_text'];
	                    $target   = $settings['join_btn_url']['is_external'] ? ' target="_blank"' : '';
	                    $nofollow = $settings['join_btn_url']['nofollow'] ? ' rel="nofollow"' : '';
	                    $details_url = $settings['join_btn_url']['url'];

	                    if ( $settings['entrance_animation'] ) {
		                    $join_animation          = 'wow' . ' ' . $settings['entrance_animation'];
		                    $join_animation_duration = $settings['join_animation_duration'];
	                    } else {
		                    $join_animation          = '';
		                    $join_animation_duration = '';
	                    }
                    ?>

                    <div class="<?php echo $td_column.' '. $join_animation;?> text-center" <?php echo $join_animation_duration;?>>
                        <div class="td-join-team td-cover-bg" style="background-image: url(<?php echo esc_url($image_src);?>)">
                            <div class="td-join-team-overlay"></div>
                            <div class="td-join-team-content">
                                <h3 class="td-join-title"><?php echo $title;?></h3>
                                <a href="<?php echo esc_url($details_url);?>" class="td-button" <?php echo $target . $nofollow?>><?php echo $btn_text;?> <i class="flaticon-double-right-arrow"></i></a>
                            </div>
                        </div>
                    </div>
                    <?php endif; ?>
                </div>

                <?php if($settings['enable_slider'] == 'yes') : ?>
                <script>
                    (function ($) {
                        "use strict";
                        $(document).ready(function () {
                            $("#td-team-wrapper-<?php echo $td_id;?>").slick({
                                slidesToShow: <?php echo json_encode( $settings['desktop'] )?>,
                                autoplay: <?php echo json_encode( $settings['autoplay'] == 'yes' ? true : false ); ?>,
                                autoplaySpeed: <?php echo json_encode( $settings['autoplay_interval'] )?>, //interval
                                speed: 1500, // slide speed
                                dots: false,
                                arrows: false,
                                infinite: <?php echo json_encode( $settings['infinity_loop'] == 'yes' ? true : false ); ?>,
                                pauseOnHover: false,
                                centerMode: false,
                                responsive: [
                                    {
                                        breakpoint: 1025,
                                        settings: {
                                            slidesToShow: <?php echo json_encode( $settings['ipad_pro'] )?>,
                                        }
                                    },

                                    {
                                        breakpoint: 992,
                                        settings: {
                                            slidesToShow: <?php echo json_encode( $settings['ipad'] )?>,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: <?php echo json_encode( $settings['mobile'] )?>,
                                        }
                                    }
                                ]
                            });
                        });
                    })(jQuery);
                </script>
                <?php endif; ?>
            </div>
		</div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Team_One_Widget );