<?php
namespace Elementor;

class ThemeDraft_Testimonial_One_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_testimonial';
	}

	public function get_title() {
		return esc_html__( 'Testimonial', 'themedraft-core' );
	}

	public function get_icon() {
		return 'eicon-testimonial';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'testimonial_settings',
			[
				'label' => esc_html__( 'Testimonials', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'person_image',
			[
				'label'       => esc_html__( 'Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'type',
			[
				'label'       => __( 'Image Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-leaf-1',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'name',
			[
				'label'       => esc_html__( 'Name', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Md Nadim Khan',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'designation',
			[
				'label'       => esc_html__( 'Designation', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Senior Gardener',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'description',
			[
				'label'   => esc_html__( 'Description', 'themedraft-core' ),
				'type'    => Controls_Manager::WYSIWYG,
				'default' => '<p>Lorem Ipsum is simply dummy text printing and this type setting industry. Lorem Ipsum is there been the industry standard text and ever since the main from 1500. When there unknown specimen book.</p>',
			]
		);

		$repeater->add_control(
			'rating',
			[
				'label' => esc_html__( 'Rating', 'themedraft-core' ),
				'type' => Controls_Manager::SELECT,
				'show_label' => true,
				'label_block' => false,
				'options' => [
					'1'  => esc_html__( '1 Star', 'themedraft-core' ),
					'2'  => esc_html__( '2 Star', 'themedraft-core' ),
					'3'  => esc_html__( '3 Star', 'themedraft-core' ),
					'4'  => esc_html__( '4 Star', 'themedraft-core' ),
					'5'  => esc_html__( '5 Star', 'themedraft-core' ),
				],

				'default' => '5',
			]
		);

		$this->add_control(
			'testimonials',
			[
				'label'       => esc_html__( 'Testimonials List', 'themedraft-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'name'        => 'Md Nadim Khan',
						'designation' => 'Senior Gardener',
						'description' => '<p>Lorem Ipsum is simply dummy text printing and this type setting industry. Lorem Ipsum is there been the industry standard text and ever since the main from 1500. When there unknown specimen book.</p>',
					],
				],
				'title_field' => '{{{ name }}}',
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'separator' => 'before ',
			]
		);

		$this->add_control(
			'testi_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_options',
			[
				'label' => esc_html__( 'Slider Options', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'       => __( 'Autoplay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'autoplay_interval',
			[
				'label'       => __( 'Autoplay Interval', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					'2000'  => __( '2 seconds', 'themedraft-core' ),
					'3000'  => __( '3 seconds', 'themedraft-core' ),
					'4000'  => __( '4 seconds', 'themedraft-core' ),
					'5000'  => __( '5 seconds', 'themedraft-core' ),
					'6000'  => __( '6 seconds', 'themedraft-core' ),
					'7000'  => __( '7 seconds', 'themedraft-core' ),
					'8000'  => __( '8 seconds', 'themedraft-core' ),
					'9000'  => __( '9 seconds', 'themedraft-core' ),
					'10000' => __( '10 seconds', 'themedraft-core' ),
				],
				'default'     => '4000',
				'condition' => [
					'autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'infinity_loop',
			[
				'label'       => __( 'Loop', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'center_mode',
			[
				'label'       => __( 'Center Mode', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'desktop_count',
			[
				'label'       => __( 'Column On Desktop', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
				'default'     => 3,
			]
		);

		$this->add_control(
			'ipp_count',
			[
				'label'       => __( 'Column On iPad Pro', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
				'default'     => 2,
			]
		);

		$this->add_control(
			'tab_count',
			[
				'label'       => __( 'Column On iPad', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
				'default'     => 2,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item_style',
			[
				'label' => esc_html__( 'Item Style', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'item_background_color',
            [
                'label'       => esc_html__('Background Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-single-testimonial-item' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'item_padding',
            [
                'label'      => esc_html__( 'Padding', 'themedraft-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .td-single-testimonial-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
		    'name_style',
		    [
		        'label' => esc_html__( 'Name', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'name_typography',
				'label' => esc_html__( 'Name Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-testimonial-name',
			]
		);

		$this->add_control(
			'name_color',
			[
				'label'       => esc_html__('Name Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-name' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();



        $this->start_controls_section(
            'designation_style',
            [
                'label' => esc_html__( 'Designation', 'themedraft-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'designation_typography',
				'label' => esc_html__( 'Designation Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-testimonial-designation',

			]
		);

		$this->add_control(
			'designation_color',
			[
				'label'       => esc_html__('Designation Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-designation' => 'color: {{VALUE}};',
				],
			]
		);

        $this->end_controls_section();

		$this->start_controls_section(
			'description_style',
			[
				'label' => esc_html__( 'Description', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'label' => esc_html__( 'Description Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-testimonial-description',

			]
		);

		$this->add_control(
			'description_color',
			[
				'label'       => esc_html__('Description Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'image_icon_style',
		    [
		        'label' => esc_html__( 'Image & Icon', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_control(
		    'icon_color',
		    [
		        'label'       => esc_html__('Icon Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-testimonial-icon' => 'color: {{VALUE}};',
		            '{{WRAPPER}} .td-testimonial-icon svg' => 'fill: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'icon_bg_color',
			[
				'label'       => esc_html__('Icon Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'star_icon_color',
		    [
		        'label'       => esc_html__('Star Icon Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-testimonial-rating' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'center_item_style',
		    [
		        'label' => esc_html__( 'Center Item', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

        $this->add_control(
            'center_item_bg',
            [
                'label'       => esc_html__('Background Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-testimonial-slider .slick-center .td-single-testimonial-item' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'center_item_name_color',
            [
                'label'       => esc_html__('Name Color', 'themedraft-core'),
                'type'        => Controls_Manager::COLOR,
                'selectors'   => [
                    '{{WRAPPER}} .td-testimonial-slider .slick-center .td-testimonial-name' => 'color: {{VALUE}};',
                ],
            ]
        );

		$this->add_control(
			'center_item_designation_color',
			[
				'label'       => esc_html__('Designation Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-slider .slick-center .td-testimonial-designation' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'center_item_desc_color',
			[
				'label'       => esc_html__('Description Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-slider .slick-center .td-testimonial-description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'center_item_star_color',
		    [
		        'label'       => esc_html__('Star Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-testimonial-slider .slick-center .td-testimonial-rating' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'center_icon_bg_color',
			[
				'label'       => esc_html__('Icon Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-slider .slick-center .td-testimonial-icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['testi_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>
		<div class="td-testimonial-wrapper">
			<div class="container-fluid">
				<div class="row td-testimonial-slider <?php echo $td_animation;?>" <?php echo $td_animation_duration;?>>

					<?php
                    if ( $settings['testimonials'] ) {
                        foreach ( $settings['testimonials'] as $testimonial ) { ?>
                            <div class="col-lg-4">
                                <div class="td-single-testimonial-item">
                                    <div class="td-testimonial-header">
                                        <div class="td-testimonial-image td-cover-bg" style="background-image: url(<?php echo esc_url($testimonial['person_image']['url']);?>)">
                                            <div class="td-testimonial-icon td-primary-bg">
                                                <?php if ( $testimonial['type'] === 'image' ) :
                                                    if ( $testimonial['image']['url'] || $testimonial['image']['id'] ) :
                                                        ?>

                                                            <img src="<?php echo $testimonial['image']['url']; ?>"
                                                                 alt="<?php echo get_post_meta( $testimonial['image']['id'], '_wp_attachment_image_alt', true ); ?>">

                                                    <?php endif;
                                                elseif ( ! empty( $testimonial['icon'] ) || ! empty( $testimonial['selected_icon'] ) ) :
                                                    themedraft_custom_icon_render( $testimonial, 'icon', 'selected_icon' );
                                                endif; ?>
                                            </div>
                                        </div>
                                        <div class="td-name-designation">
                                            <h6 class="td-testimonial-name"><?php echo $testimonial['name'];?></h6>
                                            <span class="td-testimonial-designation td-primary-color"><?php echo $testimonial['designation'];?></span>
                                        </div>
                                    </div>

                                    <div class="td-testimonial-description">
	                                    <?php echo $testimonial['description'];?>
                                    </div>

                                    <div class="td-testimonial-rating td-primary-color">
                                        <ul class="td-list-style td-list-inline">
	                                        <?php
	                                        $star = $testimonial['rating'];

	                                        for($x = 1; $x <= $star; $x++){ ?>
                                                <li>
                                                    <i class="fas fa-star"></i>
                                                </li>
	                                        <?php }
	                                        ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                    <?php    }
                    }?>

				</div>
			</div>
		</div>

        <script>
            (function ($) {
                "use strict";
                $(document).ready(function () {
                    $(".td-testimonial-slider").slick({
                        slidesToShow: <?php echo json_encode( $settings['desktop_count'] )?>,
                        autoplay: <?php echo json_encode( $settings['autoplay'] == 'yes' ? true : false ); ?>,
                        autoplaySpeed: <?php echo json_encode( $settings['autoplay_interval'] )?>, //interval
                        speed: 1500, // slide speed
                        dots: false,
                        arrows: false,
                        infinite: <?php echo json_encode( $settings['infinity_loop'] == 'yes' ? true : false ); ?>,
                        pauseOnHover: false,
                        centerMode: <?php echo json_encode( $settings['center_mode'] == 'yes' ? true : false ); ?>,
                        centerPadding: '0px',
                        responsive: [
                            {
                                breakpoint: 1025,
                                settings: {
                                    slidesToShow: <?php echo json_encode( $settings['ipp_count'] )?>, //1024
                                }
                            },
                            {
                                breakpoint: 992,
                                settings: {
                                    slidesToShow: <?php echo json_encode( $settings['tab_count'] )?>, //768-991
                                }
                            },
                            {
                                breakpoint: 768,
                                settings: {
                                    slidesToShow: 1, // 0 -767
                                }
                            }
                        ]
                    });
                });
            })(jQuery);
        </script>
		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Testimonial_One_Widget );