<?php
namespace Elementor;

class ThemeDraft_Testimonial_Two_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_testimonial_two';
	}

	public function get_title() {
		return esc_html__( 'Testimonial Two', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-testimonial';
	}

	public function get_categories() {
		return [ 'themedraft_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'testimonial_settings',
			[
				'label' => esc_html__( 'Testimonials', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'person_image',
			[
				'label'       => esc_html__( 'Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'type',
			[
				'label'       => __( 'Image Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-leaf-1',
					'library' => 'themedraft-garden-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'name',
			[
				'label'       => esc_html__( 'Name', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Md Nadim Khan',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'designation',
			[
				'label'       => esc_html__( 'Designation', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Senior Gardener',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'description',
			[
				'label'   => esc_html__( 'Description', 'themedraft-core' ),
				'type'    => Controls_Manager::WYSIWYG,
				'default' => '<p>Lorem Ipsum is simply dummy text printing and typesetting industry. Lorem Ipsum been the industry standard dummy text ever since the 1500s, when unknown printer took galley type and scrambled it to make specimen book.</p>',
			]
		);

		$this->add_control(
			'testimonials',
			[
				'label'       => esc_html__( 'Testimonials List', 'themedraft-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'name'        => 'Md Nadim Khan',
						'designation' => 'Senior Gardener',
						'description' => '<p>Lorem Ipsum is simply dummy text printing and typesetting industry. Lorem Ipsum been the industry standard dummy text ever since the 1500s, when unknown printer took galley type and scrambled it to make specimen book.</p>',
					],
				],
				'title_field' => '{{{ name }}}',
			]
		);

		$this->add_control(
			'entrance_animation',
			[
				'label' => __( 'Entrance Animation', 'themedraft-core' ),
				'type' => Controls_Manager::ANIMATION,
			]
		);

		$this->add_control(
			'testimonial_animation_duration',
			[
				'label'     => __( 'Animation Duration', 'themedraft-core' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'data-wow-duration="1.25s"',
				'options'   => [
					'data-wow-duration="2s"'    => __( 'Slow', 'themedraft-core' ),
					'data-wow-duration="1.25s"' => __( 'Normal', 'themedraft-core' ),
					'data-wow-duration=".75s"'  => __( 'Fast', 'themedraft-core' ),
				],
				'condition' => [
					'entrance_animation!' => '',
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_options',
			[
				'label' => esc_html__( 'Slider Options', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'vertical_slide',
			[
				'label'       => __( 'Vertical Slide', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'no',
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'       => __( 'Autoplay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'autoplay_interval',
			[
				'label'       => __( 'Autoplay Interval', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					'2000'  => __( '2 seconds', 'themedraft-core' ),
					'3000'  => __( '3 seconds', 'themedraft-core' ),
					'4000'  => __( '4 seconds', 'themedraft-core' ),
					'5000'  => __( '5 seconds', 'themedraft-core' ),
					'6000'  => __( '6 seconds', 'themedraft-core' ),
					'7000'  => __( '7 seconds', 'themedraft-core' ),
					'8000'  => __( '8 seconds', 'themedraft-core' ),
					'9000'  => __( '9 seconds', 'themedraft-core' ),
					'10000' => __( '10 seconds', 'themedraft-core' ),
				],
				'default'     => '4000',
				'condition' => [
					'autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'infinity_loop',
			[
				'label'       => __( 'Loop', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'arrow',
			[
				'label'       => __( 'Arrow', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'desktop_count',
			[
				'label'       => __( 'Column On Desktop', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
				],
				'default'     => 2,
			]
		);

		$this->add_control(
			'ipp_count',
			[
				'label'       => __( 'Column On iPad Pro', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
				],
				'default'     => 2,
			]
		);

		$this->add_control(
			'tab_count',
			[
				'label'       => __( 'Column On iPad', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
				],
				'default'     => 2,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'testimonial_style',
		    [
		        'label' => esc_html__( 'Testimonial', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'name_typo',
		        'label' => esc_html__( 'Name Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-testimonial-name',
		    ]
		);

		$this->add_control(
		    'name_color',
		    [
		        'label'       => esc_html__('Name Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-testimonial-name' => 'color: {{VALUE}};',
		        ],
		        'separator' => 'after',
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'content_typo',
		        'label' => esc_html__( 'Content Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-testimonial-two-desc.td-secondary-font',
		    ]
		);

		$this->add_control(
			'content_color',
			[
				'label'       => esc_html__('Content Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-two-desc.td-secondary-font' => 'color: {{VALUE}};',
				],
				'separator' => 'after',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'designation_typo',
				'label' => esc_html__( 'Designation Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-testimonial-designation',
			]
		);

		$this->add_control(
			'designation_color',
			[
				'label'       => esc_html__('Designation Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-designation' => 'color: {{VALUE}};',
				],
				'separator' => 'after',
			]
		);

		$this->add_control(
			'small_icon_color',
			[
				'label'       => esc_html__('Small Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-testimonial-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'big_icon_color',
			[
				'label'       => esc_html__('Big Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-content-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-testimonial-content-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'small_icon_bg',
			[
				'label'       => esc_html__('Small Icon Background', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-testimonial-icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label'       => esc_html__('Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .testimonial-two-content' => 'background-color: {{VALUE}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_control(
			'left_border_color',
			[
				'label'       => esc_html__('Left Border Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .testimonial-two-content' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
        $id = rand(100, 100000);
		if ( $settings['entrance_animation'] ) {
			$td_animation          = 'wow' . ' ' . $settings['entrance_animation'];
			$td_animation_duration = $settings['testimonial_animation_duration'];
		} else {
			$td_animation          = '';
			$td_animation_duration = '';
		}
		?>


        <div id="td-testimonial-<?php echo $id;?>" class="row td-testimonial-slider-two <?php echo $td_animation;?> <?php if ($settings['vertical_slide'] == 'yes'){echo ' td-vertical-slide';}?>" <?php echo $td_animation_duration;?>>

	        <?php
	        if ( $settings['testimonials'] ) {
	        foreach ( $settings['testimonials'] as $testimonial ) { ?>

            <div class="col-lg-6">
                <div class="td-testimonial-item">
                    <div class="td-testimonial-image td-cover-bg" style="background-image: url(<?php echo esc_url($testimonial['person_image']['url']);?>)">
                        <div class="td-testimonial-icon td-primary-bg">
		                    <?php if ( $testimonial['type'] === 'image' ) :
			                    if ( $testimonial['image']['url'] || $testimonial['image']['id'] ) :
				                    ?>

                                    <img src="<?php echo $testimonial['image']['url']; ?>"
                                         alt="<?php echo get_post_meta( $testimonial['image']['id'], '_wp_attachment_image_alt', true ); ?>">

			                    <?php endif;
                            elseif ( ! empty( $testimonial['icon'] ) || ! empty( $testimonial['selected_icon'] ) ) :
			                    themedraft_custom_icon_render( $testimonial, 'icon', 'selected_icon' );
		                    endif; ?>
                        </div>
                    </div>

                    <div class="testimonial-two-content">
                        <div class="td-testimonial-two-desc td-secondary-font">
	                        <?php echo $testimonial['description'];?>
                        </div>

                        <div class="td-name-designation">
                            <h6 class="td-testimonial-name"><?php echo $testimonial['name'];?></h6>
                            <span class="td-testimonial-designation td-primary-color"><?php echo $testimonial['designation'];?></span>
                        </div>

                        <div class="td-testimonial-content-icon">
                            <i class="flaticon-vegan"></i>
                        </div>
                    </div>
                </div>
            </div>

	        <?php    }
	        }?>
        </div>


		<script>
            (function ($) {
                "use strict";
                $(document).ready(function () {
                    $("#td-testimonial-<?php echo $id;?>").slick({
                        slidesToShow: <?php echo json_encode( $settings['desktop_count'] )?>,
                        autoplay: <?php echo json_encode( $settings['autoplay'] == 'yes' ? true : false ); ?>,
                        autoplaySpeed: <?php echo json_encode( $settings['autoplay_interval'] )?>, //interval
                        speed: 1500, // slide speed
                        dots: false,
                        arrows: <?php echo json_encode( $settings['arrow'] == 'yes' ? true : false ); ?>,
                        prevArrow: '<i class="slick-arrow slick-prev flaticon-double-left-chevron"></i>',
                        nextArrow: '<i class="slick-arrow slick-next flaticon-double-left-chevron"></i>',
                        infinite: <?php echo json_encode( $settings['infinity_loop'] == 'yes' ? true : false ); ?>,
                        pauseOnHover: false,
                        <?php if ($settings['vertical_slide'] == 'yes'){echo 'vertical: true,verticalSwiping: true,';}?>
                        responsive: [
                            {
                                breakpoint: 1025,
                                settings: {
                                    slidesToShow: <?php echo json_encode( $settings['ipp_count'] )?>,
	                                <?php if ($settings['vertical_slide'] == 'yes'){echo 'vertical: false,verticalSwiping: false,';}?>
                                }
                            },
                            {
                                breakpoint: 992,
                                settings: {
                                    slidesToShow: <?php echo json_encode( $settings['tab_count'] )?>, //768-991
	                                <?php if ($settings['vertical_slide'] == 'yes'){echo 'vertical: false,verticalSwiping: false,';}?>
                                }
                            },
                            {
                                breakpoint: 768,
                                settings: {
                                    slidesToShow: 1, // 0 -767
                                    arrows: false,
	                                <?php if ($settings['vertical_slide'] == 'yes'){echo 'vertical: false,verticalSwiping: false,';}?>
                                }
                            }
                        ]
                    });
                });
            })(jQuery);
		</script>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Testimonial_Two_Widget );